diff --git a/books/bookvol10.3.pamphlet b/books/bookvol10.3.pamphlet
index 3d20015..b306b68 100644
--- a/books/bookvol10.3.pamphlet
+++ b/books/bookvol10.3.pamphlet
@@ -21873,6 +21873,15 @@ complex number.)
 
 
 \end{quote}
+
+A key difficulty is creating test suites which generate DoubleFloats.
+We need to be bit-exact in the results. This can be achieved using the
+common lisp {\tt integer-decode-float} function. We cover that function
+in two different ways, with {\tt machineFraction} which translates the
+results into an Axiom {\bf Fraction(Integer)} and {\tt integerDecode}
+which just returns a list of the multiple values from the
+{\tt integer-decode-float} function.
+
 <<DoubleFloat.input>>=
 )set break resume
 )sys rm -f DoubleFloat.output
@@ -21880,7 +21889,8 @@ complex number.)
 )set message test on
 )set message auto off
 )clear all
---S 1 of 10
+
+--S 1 of 13
 2.71828
 --R 
 --R
@@ -21888,7 +21898,7 @@ complex number.)
 --R                                                                  Type: Float
 --E 1
 
---S 2 of 10
+--S 2 of 13
 2.71828@DoubleFloat
 --R 
 --R
@@ -21896,7 +21906,7 @@ complex number.)
 --R                                                            Type: DoubleFloat
 --E 2
 
---S 3 of 10
+--S 3 of 13
 2.71828 :: DoubleFloat
 --R 
 --R
@@ -21904,7 +21914,7 @@ complex number.)
 --R                                                            Type: DoubleFloat
 --E 3
 
---S 4 of 10
+--S 4 of 13
 eApprox : DoubleFloat := 2.71828
 --R 
 --R
@@ -21912,13 +21922,13 @@ eApprox : DoubleFloat := 2.71828
 --R                                                            Type: DoubleFloat
 --E 4
 
---S 5 of 10
+--S 5 of 13
 avg : List DoubleFloat -> DoubleFloat
 --R 
 --R                                                                   Type: Void
 --E 5
 
---S 6 of 10
+--S 6 of 13
 avg l ==
   empty? l => 0 :: DoubleFloat
   reduce(_+,l) / #l
@@ -21926,7 +21936,7 @@ avg l ==
 --R                                                                   Type: Void
 --E 6
 
---S 7 of 10
+--S 7 of 13
 avg []
 --R 
 --R   Compiling function avg with type List DoubleFloat -> DoubleFloat 
@@ -21935,7 +21945,7 @@ avg []
 --R                                                            Type: DoubleFloat
 --E 7
 
---S 8 of 10
+--S 8 of 13
 avg [3.4,9.7,-6.8]
 --R 
 --R
@@ -21943,7 +21953,7 @@ avg [3.4,9.7,-6.8]
 --R                                                            Type: DoubleFloat
 --E 8
 
---S 9 of 10
+--S 9 of 13
 cos(3.1415926)$DoubleFloat
 --R 
 --R
@@ -21951,15 +21961,43 @@ cos(3.1415926)$DoubleFloat
 --R                                                            Type: DoubleFloat
 --E 9
 
---S 10 of 10
+--S 10 of 13
 cos(3.1415926 :: DoubleFloat)
 --R 
 --R
 --R   (10)  - 0.99999999999999856
 --R                                                            Type: DoubleFloat
 --E 10
+
+--S 11 of 13
+a:DFLOAT := -1.0/3.0
+--R 
+--R
+--R   (11)  - 0.33333333333333331
+--R                                                            Type: DoubleFloat
+--E 11
+
+--S 12 of 13
+integerDecode a
+--R 
+--R
+--R   (12)  [6004799503160661,- 54,- 1]
+--R                                                           Type: List Integer
+--E 12
+
+--S 13 of 13
+machineFraction a
+--R 
+--R
+--R            6004799503160661
+--R   (13)  - -----------------
+--R           18014398509481984
+--R                                                       Type: Fraction Integer
+--E 13
+ 
 )spool
 )lisp (bye)
+
 @
 
 <<DoubleFloat.help>>=
@@ -22044,6 +22082,33 @@ arguments themselves are already of type DoubleFloat.
 By far, the most common usage of DoubleFloat is for functions to be
 graphed.
 
+You can get the exact machine-specific bits of a DoubleFloat in two ways.
+The first is to use the integerDecode function to break the DoubleFloat
+into components.
+
+  a := -1.0/3.0
+
+    -0.33333333333333331
+
+  integerDecode a
+
+    [6004799503160661,- 54,- 1]
+
+This is the mantissa, exact to 54 bits, the power of 2, and the sign.
+Thus it is:
+
+    6004799503160661 * 2^-54
+
+You can get the same information as a fraction with 
+
+   machineFraction a
+
+     6004799503160661
+  - -----------------
+    18014398509481984
+
+where the denominator 18014398509481984 is 2^54
+
 
 See Also:
 0 )help Float
@@ -22113,68 +22178,70 @@ o )show DoubleFloat
 \cross{DFLOAT}{gcdPolynomial} \\
 \cross{DFLOAT}{hash} &
 \cross{DFLOAT}{increasePrecision} &
-\cross{DFLOAT}{inv} &
-\cross{DFLOAT}{latex} \\
+\cross{DFLOAT}{integerDecode} &
+\cross{DFLOAT}{inv} \\
+\cross{DFLOAT}{latex} &
 \cross{DFLOAT}{lcm} &
 \cross{DFLOAT}{log} &
-\cross{DFLOAT}{log10} &
-\cross{DFLOAT}{log2} \\
+\cross{DFLOAT}{log10} \\
+\cross{DFLOAT}{log2} &
+\cross{DFLOAT}{machineFraction} &
 \cross{DFLOAT}{mantissa} &
-\cross{DFLOAT}{max} &
+\cross{DFLOAT}{max} \\
 \cross{DFLOAT}{min} &
-\cross{DFLOAT}{multiEuclidean} \\
+\cross{DFLOAT}{multiEuclidean} &
 \cross{DFLOAT}{negative?} &
-\cross{DFLOAT}{norm} &
+\cross{DFLOAT}{norm} \\
 \cross{DFLOAT}{nthRoot} &
-\cross{DFLOAT}{OMwrite} \\
+\cross{DFLOAT}{OMwrite} &
 \cross{DFLOAT}{one?} &
-\cross{DFLOAT}{order} &
+\cross{DFLOAT}{order} \\
 \cross{DFLOAT}{patternMatch} &
-\cross{DFLOAT}{pi} \\
+\cross{DFLOAT}{pi} &
 \cross{DFLOAT}{polygamma} &
-\cross{DFLOAT}{positive?} &
+\cross{DFLOAT}{positive?} \\
 \cross{DFLOAT}{precision} &
-\cross{DFLOAT}{prime?} \\
+\cross{DFLOAT}{prime?} &
 \cross{DFLOAT}{principalIdeal} &
-\cross{DFLOAT}{rationalApproximation} &
+\cross{DFLOAT}{rationalApproximation} \\
 \cross{DFLOAT}{recip} &
-\cross{DFLOAT}{retract} \\
+\cross{DFLOAT}{retract} &
 \cross{DFLOAT}{retractIfCan} &
-\cross{DFLOAT}{round} &
+\cross{DFLOAT}{round} \\
 \cross{DFLOAT}{sample} &
-\cross{DFLOAT}{sec} \\
+\cross{DFLOAT}{sec} &
 \cross{DFLOAT}{sech} &
-\cross{DFLOAT}{sign} &
+\cross{DFLOAT}{sign} \\
 \cross{DFLOAT}{sin} &
-\cross{DFLOAT}{sinh} \\
+\cross{DFLOAT}{sinh} &
 \cross{DFLOAT}{sizeLess?} &
-\cross{DFLOAT}{sqrt} &
+\cross{DFLOAT}{sqrt} \\
 \cross{DFLOAT}{squareFree} &
-\cross{DFLOAT}{squareFreePart} \\
+\cross{DFLOAT}{squareFreePart} &
 \cross{DFLOAT}{subtractIfCan} &
-\cross{DFLOAT}{tan} &
+\cross{DFLOAT}{tan} \\
 \cross{DFLOAT}{tanh} &
-\cross{DFLOAT}{truncate} \\
+\cross{DFLOAT}{truncate} &
 \cross{DFLOAT}{unit?} &
-\cross{DFLOAT}{unitCanonical} &
+\cross{DFLOAT}{unitCanonical} \\
 \cross{DFLOAT}{unitNormal} &
-\cross{DFLOAT}{wholePart} \\
+\cross{DFLOAT}{wholePart} &
 \cross{DFLOAT}{zero?} &
-\cross{DFLOAT}{?*?} &
+\cross{DFLOAT}{?*?} \\
 \cross{DFLOAT}{?**?} &
-\cross{DFLOAT}{?+?} \\
+\cross{DFLOAT}{?+?} &
 \cross{DFLOAT}{?-?} &
-\cross{DFLOAT}{-?} &
+\cross{DFLOAT}{-?} \\
 \cross{DFLOAT}{?/?} &
-\cross{DFLOAT}{?$<$?} \\
+\cross{DFLOAT}{?$<$?} &
 \cross{DFLOAT}{?$<=$?} &
-\cross{DFLOAT}{?=?} &
+\cross{DFLOAT}{?=?} \\
 \cross{DFLOAT}{?$>$?} &
-\cross{DFLOAT}{?$>=$?} \\
+\cross{DFLOAT}{?$>=$?} &
 \cross{DFLOAT}{?\^{}?} &
-\cross{DFLOAT}{?quo?} &
+\cross{DFLOAT}{?quo?} \\
 \cross{DFLOAT}{?rem?} &
-\cross{DFLOAT}{?\~{}=?} 
+\cross{DFLOAT}{?\~{}=?} &&
 \end{tabular}
 
 <<domain DFLOAT DoubleFloat>>=
@@ -22235,10 +22302,29 @@ DoubleFloat(): Join(FloatingPointSystem, DifferentialRing, OpenMath,
       rationalApproximation: (%, NonNegativeInteger) -> Fraction Integer
         ++ rationalApproximation(f, n) computes a rational approximation
         ++ r to f with relative error \spad{< 10**(-n)}.
-      rationalApproximation: (%, NonNegativeInteger, NonNegativeInteger) -> Fraction Integer
-         ++ rationalApproximation(f, n, b) computes a rational
-         ++ approximation r to f with relative error \spad{< b**(-n)}
-         ++ (that is, \spad{|(r-f)/f| < b**(-n)}).
+      rationalApproximation: (%, NonNegativeInteger, NonNegativeInteger) -> _
+            Fraction Integer
+        ++ rationalApproximation(f, n, b) computes a rational
+        ++ approximation r to f with relative error \spad{< b**(-n)}
+        ++ (that is, \spad{|(r-f)/f| < b**(-n)}).
+      machineFraction : % -> Fraction Integer
+        ++ machineFraction(x) returns a bit-exact fraction of the machine
+        ++ floating point number using the common lisp integer-decode-float 
+        ++ function. See Steele, ISBN 0-13-152414-3 p354
+        ++ This function can be used to print results which do not depend
+        ++ on binary-to-decimal conversions
+        ++
+        ++X a:DFLOAT:=-1.0/3.0
+        ++X machineFraction a
+      integerDecode : % -> List Integer
+        ++ integerDecode(x) returns the multiple values of the  common 
+        ++ lisp integer-decode-float function. 
+        ++ See Steele, ISBN 0-13-152414-3 p354. This function can be used
+        ++ to ensure that the results are bit-exact and do not depend on
+        ++ the binary-to-decimal conversions.
+        ++
+        ++X a:DFLOAT:=-1.0/3.0
+        ++X integerDecode a
 
  == add
    format: String := "~G"
@@ -22292,6 +22378,18 @@ DoubleFloat(): Join(FloatingPointSystem, DifferentialRing, OpenMath,
    -- complex to get the correct behaviour.
    --makeComplex(x: %):% == COMPLEX(x, 0$%)$Lisp
 
+   machineFraction(df:%):Fraction(Integer) ==
+     numer:Integer:=INTEGER_-DECODE_-FLOAT_-NUMERATOR(df)$Lisp
+     denom:Integer:=INTEGER_-DECODE_-FLOAT_-DENOMINATOR(df)$Lisp
+     sign:Integer:=INTEGER_-DECODE_-FLOAT_-SIGN(df)$Lisp
+     sign*numer/denom
+
+   integerDecode(df:%):List(Integer) ==
+     numer:Integer:=INTEGER_-DECODE_-FLOAT_-NUMERATOR(df)$Lisp
+     exp:Integer:=INTEGER_-DECODE_-FLOAT_-EXPONENT(df)$Lisp
+     sign:Integer:=INTEGER_-DECODE_-FLOAT_-SIGN(df)$Lisp
+     [numer,exp,sign]
+
    base()           == FLOAT_-RADIX(0$%)$Lisp
    mantissa x       == manexp(x).MANTISSA
    exponent x       == manexp(x).EXPONENT
diff --git a/books/bookvol5.pamphlet b/books/bookvol5.pamphlet
index 59b112a..404e339 100644
--- a/books/bookvol5.pamphlet
+++ b/books/bookvol5.pamphlet
@@ -29028,6 +29028,41 @@ See Steele Common Lisp 1990 p308
 
 @
 
+\defun{integer-decode-float-numerator}{Machine specific float numerator}
+This is used in the DoubleFloat integerDecode function
+<<defun integer-decode-float-numerator>>=
+(defun integer-decode-float-numerator (x)
+ (integer-decode-float x))
+
+@
+
+\defun{integer-decode-float-denominator}{Machine specific float denominator}
+This is used in the DoubleFloat integerDecode function
+<<defun integer-decode-float-denominator>>=
+(defun integer-decode-float-denominator (x)
+ (multiple-value-bind (mantissa exponent sign) (integer-decode-float x)
+  (expt 2 (abs exponent))))
+
+@
+
+\defun{integer-decode-float-sign}{Machine specific float sign}
+This is used in the DoubleFloat integerDecode function
+<<defun integer-decode-float-sign>>=
+(defun integer-decode-float-sign (x)
+ (multiple-value-bind (mantissa exponent sign) (integer-decode-float x)
+  sign))
+
+@
+
+\defun{integer-decode-float-exponent}{Machine specific float bit length}
+This is used in the DoubleFloat integerDecode function
+<<defun integer-decode-float-exponent>>=
+(defun integer-decode-float-exponent (x)
+ (multiple-value-bind (mantissa exponent sign) (integer-decode-float x)
+  exponent))
+
+@
+
 \defun{manexp}{Decode floating-point values}
 This function is used by DoubleFloat to implement the ``mantissa'' and
 ``exponent'' functions.
@@ -29473,6 +29508,10 @@ See Steele Common Lisp 1990 pp305-307
 <<defun initToWhere>>
 <<defun insertpile>>
 <<defun insertPos>>
+<<defun integer-decode-float-denominator>>
+<<defun integer-decode-float-exponent>>
+<<defun integer-decode-float-numerator>>
+<<defun integer-decode-float-sign>>
 <<defun InterpExecuteSpadSystemCommand>>
 <<defun interpFunctionDepAlists>>
 <<defun interpOpen>>
diff --git a/changelog b/changelog
index c389367..8949c10 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,7 @@
+20090101 tpd src/axiom-website/patches.html 20090101.01.tpd.patch
+20100101 tpd src/input/ei.input rewrite using machineFraction
+20100101 tpd books/bookvol5 support dfloat machineFraction, integerDecode
+20100101 tpd books/bookvol10.3 add dfloat machineFraction, integerDecode
 20091231 tpd src/axiom-website/patches.html 20091231.02.tpd.patch
 20091231 tpd src/interp/i-syscmd.lisp remove dead code
 20091231 tpd books/bookvol5 add banner and cleanup globals
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 97562f1..34c102f 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -2346,5 +2346,7 @@ books/bookvol5 treeshake i-syscmd<br/>
 books/bookvol5 treeshake i-syscmd<br/>
 <a href="patches/20091231.01.tpd.patch">20091231.01.tpd.patch</a>
 books/bookvol5 add banner and cleanup globals<br/>
+<a href="patches/20090101.01.tpd.patch">20090101.01.tpd.patch</a>
+books/bookvol10.3 add dfloat machineFraction, integerDecode<br/>
  </body>
 </html>
diff --git a/src/input/ei.input.pamphlet b/src/input/ei.input.pamphlet
index 04bed32..941a023 100644
--- a/src/input/ei.input.pamphlet
+++ b/src/input/ei.input.pamphlet
@@ -40,7 +40,7 @@ with the scaling factor $t=(-20/x)-1$
 \begin{chunk}{*}
 
 --S 2 of 20
-aChebyshev:=_
+aChebyshev:List Fraction Integer:=[machineFraction (x::DFLOAT) for x in _
 [0.191217322586055345391519326510E1,_
 -0.420835505286848437550974986680E-01,_
  0.172281962728432678337118157835E-02,_
@@ -81,54 +81,147 @@ aChebyshev:=_
 -0.165272509838212659649744302314E-28,_
  0.459223035877302702795636377166E-29,_
 -0.129006276721326384737453212670E-29,_
- 0.366271848103200259081177078922E-30]
+ 0.366271848103200259081177078922E-30]]
 --R 
 --R
 --R   (3)
---R   [1.9121732258 6055345391 51932651, - 0.0420835505 2868484375 5097498668,
---R    0.0017228196 2728432678 3371181578 35,
---R    - 0.0000991578 2173444563 6455984232 2973,
---R    0.0000071760 9316802277 5052655906 65592,
---R    - 0.6152733145 0951269682 7956791331 E -6,
---R    0.6024857106 5627583129 399970161 E -7,
---R    - 0.6573848845 2883048229 5894189637 E -8,
---R    0.7853167541 8323998199 4810079871 E -9,
---R    - 0.1013730288 0038789855 4202774257 E -9,
---R    0.1399770413 2267686027 7823488623 E -10,
---R    - 0.2051008376 7838189961 8962318711 E -11,
---R    0.3168388726 0024778181 4907985818 E -12,
---R    - 0.5132760082 8391806541 5984751899 E -13,
---R    0.8680933040 7665493418 7433687383 E -14,
---R    - 0.1527015040 9030849719 8572355351 E -14,
---R    0.2784686251 6493573965 0105251453 E -15,
---R    - 0.5249890437 4217669680 8472933696 E -16,
---R    0.1020717991 2485612924 7455787226 E -16,
---R    - 0.2042264679 8997184130 8462421876 E -17,
---R    0.4197064172 7264847440 8827228562 E -18,
---R    - 0.8844508176 1728105081 6483737536 E -19,
---R    0.1908272629 5947174199 5060168262 E -19,
---R    - 0.4209746222 9351995033 6450865676 E -20,
---R    0.9483904058 1983732764 1500214512 E -21,
---R    - 0.2179467860 1366743199 4032574014 E -21,
---R    0.5103936869 0714509499 3452562741 E -22,
---R    - 0.1216883113 3344150908 9746779693 E -22,
---R    0.2951289166 4478751929 4773757144 E -23,
---R    - 0.7275353763 7728468971 443895092 E -24,
---R    0.1821639048 6230739612 1667115976 E -24,
---R    - 0.4629629963 1633171661 2753482064 E -25,
---R    0.1193539790 9715779152 3052371292 E -25,
---R    - 0.3119493285 2201424493 1062147473 E -26,
---R    0.8261419734 5334664228 4170028518 E -27,
---R    - 0.2215803373 6609829830 2591177697 E -27,
---R    0.6016031671 6542638904 5303124429 E -28,
---R    - 0.1652725098 3821265964 9744302314 E -28,
---R    0.4592230358 7730270279 5636377166 E -29,
---R    - 0.1290062767 2132638473 745321267 E -29,
---R    0.3662718481 0320025908 1177078922 E -30]
---R                                                             Type: List Float
+--R    8611662627453427     379054924958825    7945103187419413
+--R   [----------------, - ----------------, -------------------,
+--R    4503599627370496    9007199254740992  4611686018427387904
+--R        1829138960441833       4236017731827575         5811092156487673
+--R    - --------------------, ---------------------, - ----------------------,
+--R      18446744073709551616  590295810358705651712    9444732965739290427392
+--R        4552253322257753            7947295603312847
+--R    -----------------------, - -------------------------,
+--R    75557863725914323419136    1208925819614629174706176
+--R         7595117605664589             3921679101738443
+--R    -------------------------, - --------------------------,
+--R    9671406556917033397649408    38685626227668133590597632
+--R          4332079600851147               5078050781060809
+--R    ---------------------------, - ----------------------------,
+--R    309485009821345068724781056    2475880078570760549798248448
+--R           6275640422302181                 8133182999798229
+--R    -----------------------------, - ------------------------------,
+--R    19807040628566084398385987584    158456325028528675187087900672
+--R           687774373729299                   7742886132633319
+--R    -----------------------------, - -------------------------------,
+--R    79228162514264337593543950336    5070602400912917605986812821504
+--R            5648014717360969                     8518434258086585
+--R    --------------------------------, - ---------------------------------,
+--R    20282409603651670423947251286016    162259276829213363391578010288128
+--R             6624838524262355                     5302022240869971
+--R    ---------------------------------, - ----------------------------------,
+--R    649037107316853453566312041152512    2596148429267413814265248164610048
+--R              8512657468405                       7347729922948429
+--R    --------------------------------, - -----------------------------------,
+--R    20282409603651670423947251286016    83076749736557242056487941267521536
+--R              6341323507118493
+--R    ------------------------------------,
+--R    332306998946228968225951765070086144
+--R                2797856267337637
+--R    - ------------------------------------,
+--R      664613997892457936451903530140172288
+--R               5042508313398181
+--R    -------------------------------------,
+--R    5316911983139663491615228241121378304
+--R                 4635215512971377
+--R    - --------------------------------------,
+--R      21267647932558653966460912964485513216
+--R               4341949296056693
+--R    --------------------------------------,
+--R    85070591730234615865843651857942052864
+--R                  8281677321431107
+--R    - ---------------------------------------,
+--R      680564733841876926926749214863536422912
+--R                8034173304216051
+--R    ----------------------------------------,
+--R    2722258935367507707706996859454145691648
+--R                   990269839569513
+--R    - ----------------------------------------,
+--R      1361129467683753853853498429727072845824
+--R                 3967178541702823
+--R    -----------------------------------------,
+--R    21778071482940061661655974875633165533184
+--R                   4032976491093275
+--R    - -----------------------------------------,
+--R      87112285931760246646623899502532662132736
+--R                 2079439590840989
+--R    ------------------------------------------,
+--R    174224571863520493293247799005065324265472
+--R                    8695878112777701
+--R    - -------------------------------------------,
+--R      2787593149816327892691964784081045188247552
+--R                  4605895411948583
+--R    -------------------------------------------,
+--R    5575186299632655785383929568162090376495104
+--R                    1235351661151453
+--R    - -------------------------------------------,
+--R      5575186299632655785383929568162090376495104
+--R                  5366479576634079
+--R    --------------------------------------------,
+--R    89202980794122492566142873090593446023921664
+--R                     5897120208357801
+--R    - ---------------------------------------------,
+--R      356811923176489970264571492362373784095686656
+--R                   6554250183933065
+--R    ----------------------------------------------,
+--R    1427247692705959881058285969449495136382746624
+--R                     3682478215901993
+--R    - ----------------------------------------------,
+--R      2854495385411919762116571938898990272765493248
+--R                    4182085200867523
+--R    -----------------------------------------------]
+--R    11417981541647679048466287755595961091061972992
+--R                                                  Type: List Fraction Integer
 --E 2
 
 \end{chunk}
+
+The actual tables value from above are: 
+\begin{verbatim}
+   1.9121732258 6055345391 51932651 
+  -0.0420835505 2868484375 5097498668
+   0.0017228196 2728432678 3371181578 35
+  -0.0000991578 2173444563 6455984232 2973
+   0.0000071760 9316802277 5052655906 65592
+  -0.6152733145 0951269682 7956791331 E -6
+   0.6024857106 5627583129 399970161 E -7
+  -0.6573848845 2883048229 5894189637 E -8
+   0.7853167541 8323998199 4810079871 E -9
+  -0.1013730288 0038789855 4202774257 E -9
+   0.1399770413 2267686027 7823488623 E -10
+  -0.2051008376 7838189961 8962318711 E -11
+   0.3168388726 0024778181 4907985818 E -12
+  -0.5132760082 8391806541 5984751899 E -13
+   0.8680933040 7665493418 7433687383 E -14
+  -0.1527015040 9030849719 8572355351 E -14
+   0.2784686251 6493573965 0105251453 E -15
+  -0.5249890437 4217669680 8472933696 E -16
+   0.1020717991 2485612924 7455787226 E -16
+  -0.2042264679 8997184130 8462421876 E -17
+   0.4197064172 7264847440 8827228562 E -18
+  -0.8844508176 1728105081 6483737536 E -19
+   0.1908272629 5947174199 5060168262 E -19
+  -0.4209746222 9351995033 6450865676 E -20
+   0.9483904058 1983732764 1500214512 E -21
+  -0.2179467860 1366743199 4032574014 E -21
+   0.5103936869 0714509499 3452562741 E -22
+  -0.1216883113 3344150908 9746779693 E -22
+   0.2951289166 4478751929 4773757144 E -23
+  -0.7275353763 7728468971 443895092 E -24
+   0.1821639048 6230739612 1667115976 E -24
+  -0.4629629963 1633171661 2753482064 E -25
+   0.1193539790 9715779152 3052371292 E -25
+  -0.3119493285 2201424493 1062147473 E -26
+   0.8261419734 5334664228 4170028518 E -27
+  -0.2215803373 6609829830 2591177697 E -27
+   0.6016031671 6542638904 5303124429 E -28
+  -0.1652725098 3821265964 9744302314 E -28
+   0.4592230358 7730270279 5636377166 E -29
+  -0.1290062767 2132638473 745321267 E -29
+   0.3662718481 0320025908 1177078922 E -30
+\end{verbatim}
+
 In the following table there are 4 columns. The first column
 is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
 column is the exact value shown in the table. Column 3 is the
@@ -136,7 +229,10 @@ value returned by Axiom and column 4 is the difference.
 See special.spad.dvi for details.
 
 \begin{chunk}{*}
+
 --S 3 of 20
+t1:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[-160.,0.993826695674061273878797850088,_
  Ei1(-160.0),Ei1(-160.0)-0.993826695674061273878797850088],_
 [-80.0,0.987801333094288773564522608410,_
@@ -168,53 +264,127 @@ See special.spad.dvi for details.
 [-10.0-2.0/3.0,0.920170654249445676202148012149,_
  Ei1(-10.0-2.0/3.0),Ei1(-10.0-2.0/3.0)-0.920170654249445676202148012149],_
 [-10.0,0.915633339397880818760698157666,_
- Ei1(-10.0),Ei1(-10.0)-0.915633339397880818760698157666]]
+ Ei1(-10.0),Ei1(-10.0)-0.915633339397880818760698157666]]]
 --R 
 --R
 --R   (4)
---R   [[- 160.,0.99382669567406123,0.99382669567406123,0.],
---R    [- 80.,0.98780133309428875,0.98780133309428886,1.1102230246251565E-16],
---R    [- 53.333333333333336,0.98191629014319448,0.98191629014319448,0.],
---R    [- 40.,0.97616460318514309,0.97616460318514309,0.],
---R    [- 32.,0.97053988407466396,0.97053988407466363,- 3.3306690738754696E-16],
---R    [- 26.666666666666668,0.96503625112337699,0.96503625112337699,0.],
---R
---R     [- 22.857142857142858, 0.95964827107936723, 0.95964827107936734,
---R      1.1102230246251565E-16]
---R     ,
---R    [- 20.,0.9543709099192168,0.95437090991921691,1.1102230246251565E-16],
---R    [- 17.777777777777779,0.94919949077974575,0.94919949077974575,0.],
---R    [- 16.,0.94412965773690294,0.94412965773690294,0.],
---R
---R     [- 14.545454545454545, 0.93915734441928422, 0.93915734441928411,
---R      - 1.1102230246251565E-16]
---R     ,
---R
---R     [- 13.333333333333334, 0.93427874665341049, 0.9342787466534106,
---R      1.1102230246251565E-16]
---R     ,
---R
---R     [- 12.307692307692308, 0.92949029849721398, 0.92949029849721387,
---R      - 1.1102230246251565E-16]
---R     ,
---R    [- 11.428571428571429,0.92478865114084174,0.92478865114084174,0.],
---R
---R     [- 10.666666666666666, 0.92017065424944566, 0.92017065424944577,
---R      1.1102230246251565E-16]
---R     ,
---R    [- 10.,0.91563333939788083,0.91563333939788094,1.1102230246251565E-16]]
---R                               Type: List List OnePointCompletion DoubleFloat
+--R           8951595072617107 4475797536308553           1
+--R   [[- 160,----------------,----------------,- ----------------],
+--R           9007199254740992 4503599627370496   9007199254740992
+--R          2224330857819759 2224330857819759
+--R    [- 80,----------------,----------------,0],
+--R          2251799813685248 2251799813685248
+--R       3752999689475413 2211078919198955 2211078919198955
+--R    [- ----------------,----------------,----------------,0],
+--R        70368744177664  2251799813685248 2251799813685248
+--R          2198127271578439 2198127271578439
+--R    [- 40,----------------,----------------,0],
+--R          2251799813685248 2251799813685248
+--R          8741846120533721 4370923060266859           3
+--R    [- 32,----------------,----------------,- ----------------],
+--R          9007199254740992 4503599627370496   9007199254740992
+--R       3752999689475413 4346136900958261 8692273801916521           1
+--R    [- ----------------,----------------,----------------,- ----------------],
+--R        140737488355328 4503599627370496 9007199254740992   9007199254740992
+--R       3216856876693211 4321871596039779 4321871596039779
+--R    [- ----------------,----------------,----------------,0],
+--R        140737488355328 4503599627370496 4503599627370496
+--R          2149052237142713 2149052237142713
+--R    [- 20,----------------,----------------,0],
+--R          2251799813685248 2251799813685248
+--R       5003999585967217 4274814472975927 4274814472975927
+--R    [- ----------------,----------------,----------------,0],
+--R        281474976710656 4503599627370496 4503599627370496
+--R          2125990987386675 8503963949546699           1
+--R    [- 16,----------------,----------------,- ----------------],
+--R          2251799813685248 9007199254740992   9007199254740992
+--R       8188362958855447 4229588666368953 528698583296119           1
+--R    [- ----------------,----------------,---------------,- ----------------],
+--R        562949953421312 4503599627370496 562949953421312   4503599627370496
+--R       3752999689475413 4207617415288473 8415234830576947         1
+--R    [- ----------------,----------------,----------------,----------------],
+--R        281474976710656 4503599627370496 9007199254740992 9007199254740992
+--R       866076851417403 65407065030571 4186052161956543           1
+--R    [- ---------------,--------------,----------------,- ----------------],
+--R        70368744177664 70368744177664 4503599627370496   4503599627370496
+--R       3216856876693211 2082438912337179 2082438912337179
+--R    [- ----------------,----------------,----------------,0],
+--R        281474976710656 2251799813685248 2251799813685248
+--R       6004799503160661 4144080215595069 4144080215595069
+--R    [- ----------------,----------------,----------------,0],
+--R        562949953421312 4503599627370496 4503599627370496
+--R          8247291932240597 4123645966120299         1
+--R    [- 10,----------------,----------------,----------------]]
+--R          9007199254740992 4503599627370496 9007199254740992
+--R                                             Type: List List Fraction Integer
 --E 3
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+ 
+ [-160.,               0.99382669567406123,
+                       0.99382669567406123,
+                       0.],
+ [-80.,                0.98780133309428875,
+                       0.98780133309428886,
+                       1.1102230246251565E-16],
+ [-53.333333333333336, 0.98191629014319448,
+                       0.98191629014319448,
+                       0.],
+ [-40.,                0.97616460318514309,
+                       0.97616460318514309,
+                       0.],
+ [-32.,                0.97053988407466396,
+                       0.97053988407466363,
+                      -3.3306690738754696E-16],
+ [-26.666666666666668, 0.96503625112337699,
+                       0.96503625112337699,
+                       0.],
+ [-22.857142857142858, 0.95964827107936723, 
+                       0.95964827107936734,
+                       1.1102230246251565E-16]
+ [-20.,                0.9543709099192168,
+                       0.95437090991921691,
+                       1.1102230246251565E-16],
+ [-17.777777777777779, 0.94919949077974575,
+                       0.94919949077974575,
+                       0.],
+ [-16.,                0.94412965773690294,
+                       0.94412965773690294,
+                       0.],
+ [-14.545454545454545, 0.93915734441928422, 
+                       0.93915734441928411,
+                      -1.1102230246251565E-16]
+ [-13.333333333333334, 0.93427874665341049, 
+                       0.9342787466534106,
+                       1.1102230246251565E-16]
+ [-12.307692307692308, 0.92949029849721398, 
+                       0.92949029849721387,
+                      -1.1102230246251565E-16]
+ [-11.428571428571429, 0.92478865114084174,
+                       0.92478865114084174,
+                       0.],
+ [-10.666666666666666, 0.92017065424944566, 
+                       0.92017065424944577,
+                       1.1102230246251565E-16]
+ [-10.,                0.91563333939788083,
+                       0.91563333939788094,
+                       1.1102230246251565E-16]
+
+\end{verbatim}
+
 These are the Chebyshev coefficients used by Axiom in the range
 $(-10 \le x \le -4)$ in the polynomial
 $$\sum_{k=0}^{43}\ ^{'}{A_kT_k(t)}$$
 with the scaling factor $t=(x+7)/3$
 
 \begin{chunk}{*}
+
 --S 4 of 20
-bChebyshev:=[_
+bChebyshev:List Fraction Integer:= [machineFraction (x::DFLOAT) for x in _
+[_
  0.175755649606129373848762834691E1,_
 -0.435854151773616611705001867964E-01,_
 -0.797950713955842540133217027492E-02,_
@@ -258,57 +428,155 @@ bChebyshev:=[_
 -0.750270777550246547010642233720E-28,_
 -0.161845436449591026807612330206E-28,_
 -0.349436677170516166749482836452E-29,_
--0.755103690612616785856037026797E-30]
+-0.755103690612616785856037026797E-30]]
 --R 
 --R
 --R   (5)
---R   [1.7575564960 6129373848 762834691, - 0.0435854151 7736166117 0500186796 4,
---R    - 0.0079795071 3955842540 1332170274 92,
---R    - 0.0014843723 2730371213 8509702100 01,
---R    - 0.0002800301 9843775145 7486203954 948,
---R    - 0.0000534864 8512865793 2303917736 1553,
---R    - 0.0000103286 7243573554 8661023326 646,
---R    - 0.0000020140 8331300553 6877322261 98639,
---R    - 0.3961758434 2738664582 23384435 E -6,
---R    - 0.7853872767 0966316306 7607656069 E -7,
---R    - 0.1567925981 0074698262 4616270279 E -7,
---R    - 0.3150055939 3763998825 0007372851 E -8,
---R    - 0.6365096822 5242037304 0380263972 E -9,
---R    - 0.1292888113 2805631835 6593121259 E -9,
---R    - 0.2638690999 6592557613 2149942808 E -10,
---R    - 0.5408958287 0450687349 1922207896 E -11,
---R    - 0.1113222784 6010898999 7676692708 E -11,
---R    - 0.2299624726 0744624618 4338864145 E -12,
---R    - 0.4766682389 4951902622 3913482091 E -13,
---R    - 0.9911756747 3352709450 6246643371 E -14,
---R    - 0.2067103580 4957072400 0900805021 E -14,
---R    - 0.4322776783 3833850564 5764394579 E -15,
---R    - 0.9063014799 6650172551 4905603356 E -16,
---R    - 0.1904669979 5816613974 4015963342 E -16,
---R    - 0.4011792326 3502786634 674422752 E -17,
---R    - 0.8467772130 0168322313 4166334685 E -18,
---R    - 0.1790842733 6586966555 5826492204 E -18,
---R    - 0.3794490638 1714782440 1106175166 E -19,
---R    - 0.8053999236 7982798526 0999654058 E -20,
---R    - 0.1712339011 2362012974 3228671244 E -20,
---R    - 0.3646274058 7749686208 6576562816 E -21,
---R    - 0.7775969638 8939479435 3098157647 E -22,
---R    - 0.1660628498 4484020566 2531950966 E -22,
---R    - 0.3551178625 7882509300 5927145352 E -23,
---R    - 0.7603722685 9413580929 5734653294 E -24,
---R    - 0.1630074137 2584900288 9638374755 E -24,
---R    - 0.3498575202 7286322350 7538497255 E -25,
---R    - 0.7517179627 8900988246 0645145143 E -26,
---R    - 0.1616877440 0527227629 8777317918 E -26,
---R    - 0.3481270085 7247569174 8202271565 E -27,
---R    - 0.7502707775 5024654701 064223372 E -28,
---R    - 0.1618454364 4959102680 7612330206 E -28,
---R    - 0.3494366771 7051616674 9482836452 E -29,
---R    - 0.7551036906 1261678585 6037026797 E -30]
---R                                                             Type: List Float
+--R    7915330780744237     3140660152824869     1149968172170097
+--R   [----------------, - -----------------, - ------------------,
+--R    4503599627370496    72057594037927936    144115188075855872
+--R        6845459107967051       5165645403491301        3946606010282499
+--R    - -------------------, - --------------------, - --------------------,
+--R      4611686018427387904    18446744073709551616    73786976294838206464
+--R         6096972065382141         4755619765522199
+--R    - ---------------------, - ----------------------,
+--R      590295810358705651712    2361183241434822606848
+--R         1870887524324103           5934218482569569
+--R    - ----------------------, - -----------------------,
+--R      4722366482869645213696    75557863725914323419136
+--R          4738765504211317             7616367916685089
+--R    - ------------------------, - -------------------------,
+--R      302231454903657293676544    2417851639229258349412352
+--R           6155943914477235             1250404657614173
+--R    - -------------------------, - -------------------------,
+--R      9671406556917033397649408    9671406556917033397649408
+--R           2041588274862599               6695966034357555
+--R    - --------------------------, - ----------------------------,
+--R      77371252455336267181195264    1237940039285380274899124224
+--R            2756206115404907                 4554876037981203
+--R    - ----------------------------, - -----------------------------,
+--R      2475880078570760549798248448    19807040628566084398385987584
+--R             7553109740176135                  6282322195037879
+--R    - ------------------------------, - ------------------------------,
+--R      158456325028528675187087900672    633825300114114700748351602688
+--R              2620365094549305                   2191908233643441
+--R    - -------------------------------, - -------------------------------,
+--R      1267650600228229401496703205376    5070602400912917605986812821504
+--R              3676395568215259                     6181007469704659
+--R    - --------------------------------, - ---------------------------------,
+--R      40564819207303340847894502572032    324518553658426726783156020576256
+--R               5207604173300669                      1099179665736879
+--R    - ----------------------------------, - ----------------------------------,
+--R      1298074214633706907132624082305024    1298074214633706907132624082305024
+--R                3719434840042389
+--R    - -----------------------------------,
+--R      20769187434139310514121985316880384
+--R                6304678982501625
+--R    - ------------------------------------,
+--R      166153499473114484112975882535043072
+--R                5352800631791309
+--R    - ------------------------------------,
+--R      664613997892457936451903530140172288
+--R                 569022238002455
+--R    - ------------------------------------,
+--R      332306998946228968225951765070086144
+--R                 7754767294764771
+--R    - --------------------------------------,
+--R      21267647932558653966460912964485513216
+--R                 6615063384570469
+--R    - --------------------------------------,
+--R      85070591730234615865843651857942052864
+--R                  2825412980141931
+--R    - ---------------------------------------,
+--R      170141183460469231731687303715884105728
+--R                  2416806936284543
+--R    - ---------------------------------------,
+--R      680564733841876926926749214863536422912
+--R                   8279720809544195
+--R    - -----------------------------------------,
+--R      10889035741470030830827987437816582766592
+--R                   7099974216741449
+--R    - -----------------------------------------,
+--R      43556142965880123323311949751266331066368
+--R                   6095377668277253
+--R    - ------------------------------------------,
+--R      174224571863520493293247799005065324265472
+--R                   5238709609161323
+--R    - ------------------------------------------,
+--R      696898287454081973172991196020261297061888
+--R                    2253598237991765
+--R    - -------------------------------------------,
+--R      1393796574908163946345982392040522594123776
+--R                    3881745857450733
+--R    - --------------------------------------------,
+--R      11150372599265311570767859136324180752990208
+--R                    6692638976020599
+--R    - --------------------------------------------,
+--R      89202980794122492566142873090593446023921664
+--R                     360927383980731
+--R    - --------------------------------------------,
+--R      22300745198530623141535718272648361505980416
+--R                     4987326912384565
+--R    - ----------------------------------------------,
+--R      1427247692705959881058285969449495136382746624
+--R                     4310880000722449
+--R    - ----------------------------------------------]
+--R      5708990770823839524233143877797980545530986496
+--R                                                  Type: List Fraction Integer
 --E 4
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+      1.7575564960 6129373848 762834691
+     -0.0435854151 7736166117 0500186796 4
+     -0.0079795071 3955842540 1332170274 92
+     -0.0014843723 2730371213 8509702100 01
+     -0.0002800301 9843775145 7486203954 948
+     -0.0000534864 8512865793 2303917736 1553
+     -0.0000103286 7243573554 8661023326 646
+     -0.0000020140 8331300553 6877322261 98639
+     -0.3961758434 2738664582 23384435 E -6
+     -0.7853872767 0966316306 7607656069 E -7
+     -0.1567925981 0074698262 4616270279 E -7
+     -0.3150055939 3763998825 0007372851 E -8
+     -0.6365096822 5242037304 0380263972 E -9
+     -0.1292888113 2805631835 6593121259 E -9
+     -0.2638690999 6592557613 2149942808 E -10
+     -0.5408958287 0450687349 1922207896 E -11
+     -0.1113222784 6010898999 7676692708 E -11
+     -0.2299624726 0744624618 4338864145 E -12
+     -0.4766682389 4951902622 3913482091 E -13
+     -0.9911756747 3352709450 6246643371 E -14
+     -0.2067103580 4957072400 0900805021 E -14
+     -0.4322776783 3833850564 5764394579 E -15
+     -0.9063014799 6650172551 4905603356 E -16
+     -0.1904669979 5816613974 4015963342 E -16
+     -0.4011792326 3502786634 674422752 E -17
+     -0.8467772130 0168322313 4166334685 E -18
+     -0.1790842733 6586966555 5826492204 E -18
+     -0.3794490638 1714782440 1106175166 E -19
+     -0.8053999236 7982798526 0999654058 E -20
+     -0.1712339011 2362012974 3228671244 E -20
+     -0.3646274058 7749686208 6576562816 E -21
+     -0.7775969638 8939479435 3098157647 E -22
+     -0.1660628498 4484020566 2531950966 E -22
+     -0.3551178625 7882509300 5927145352 E -23
+     -0.7603722685 9413580929 5734653294 E -24
+     -0.1630074137 2584900288 9638374755 E -24
+     -0.3498575202 7286322350 7538497255 E -25
+     -0.7517179627 8900988246 0645145143 E -26
+     -0.1616877440 0527227629 8777317918 E -26
+     -0.3481270085 7247569174 8202271565 E -27
+     -0.7502707775 5024654701 064223372 E -28
+     -0.1618454364 4959102680 7612330206 E -28
+     -0.3494366771 7051616674 9482836452 E -29
+     -0.7551036906 1261678585 6037026797 E -30
+
+\end{verbatim}
+
 In the following table there are 4 columns. The first column
 is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
 column is the exact value shown in the table. Column 3 is the
@@ -316,7 +584,10 @@ value returned by Axiom and column 4 is the difference.
 See special.spad.dvi for details.
 
 \begin{chunk}{*}
+
 --S 5 of 20
+t2:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[-10.000,0.915633339397880818760698157661,_
   Ei2(-10.000),Ei2(-10.000)-0.915633339397880818760698157661],_
 [ -9.625,0.912844461467993418856575662217,_
@@ -350,39 +621,99 @@ See special.spad.dvi for details.
 [ -4.375,0.836498754556298741742152267582,_
   Ei2( -4.375),Ei2( -4.375)-0.836498754556298741742152267582],_
 [ -4.000,0.825382599604223332408183035504,_
-  Ei2( -4.000),Ei2( -4.000)-0.825382599604223332408183035504]]
+  Ei2( -4.000),Ei2( -4.000)-0.825382599604223332408183035504]]]
 --R 
 --R
 --R   (6)
---R   [[- 10.,0.91563333939788083,0.91563333939788083,0.],
---R    [- 9.625,0.91284446146799347,0.91284446146799336,- 1.1102230246251565E-16],
---R    [- 9.25,0.90986275152542417,0.90986275152542395,- 2.2204460492503131E-16],
---R    [- 8.875,0.90666727065475383,0.90666727065475394,1.1102230246251565E-16],
---R    [- 8.5,0.90323390197320785,0.90323390197320796,1.1102230246251565E-16],
---R    [- 8.125,0.89953471768847382,0.89953471768847415,3.3306690738754696E-16],
---R    [- 7.75,0.89553718708753915,0.89553718708753927,1.1102230246251565E-16],
---R    [- 7.375,0.89120317632125434,0.89120317632125423,- 1.1102230246251565E-16],
---R    [- 7.,0.88648767253642935,0.88648767253642924,- 1.1102230246251565E-16],
---R    [- 6.625,0.88133713846821016,0.88133713846821005,- 1.1102230246251565E-16],
---R    [- 6.25,0.87568736478846598,0.87568736478846598,0.],
---R    [- 5.875,0.8694606294541134,0.86946062945411307,- 3.3306690738754696E-16],
---R    [- 5.5,0.86256188469070139,0.86256188469070139,0.],
---R    [- 5.125,0.85487355389019959,0.85487355389019937,- 2.2204460492503131E-16],
---R    [- 4.75,0.84624829910358734,0.84624829910358745,1.1102230246251565E-16],
---R    [- 4.375,0.83649875455629874,0.83649875455629874,0.],
---R    [- 4.,0.82538259960422333,0.82538259960422322,- 1.1102230246251565E-16]]
---R                               Type: List List OnePointCompletion DoubleFloat
+--R          8247291932240597 4123645966120299         1
+--R   [[- 10,----------------,----------------,----------------],
+--R          9007199254740992 4503599627370496 9007199254740992
+--R       77 1027771494128619 1027771494128619
+--R    [- --,----------------,----------------,0],
+--R        8 1125899906842624 1125899906842624
+--R       37 2048828774364097 8195315097456387           1
+--R    [- --,----------------,----------------,- ----------------],
+--R        4 2251799813685248 9007199254740992   9007199254740992
+--R       71 2041633191134887 8166532764539549         1
+--R    [- --,----------------,----------------,----------------],
+--R        8 2251799813685248 9007199254740992 9007199254740992
+--R       17 8135607728709875 8135607728709877         1
+--R    [- --,----------------,----------------,----------------],
+--R        2 9007199254740992 9007199254740992 4503599627370496
+--R       65 4051144219388635 8102288438777273         3
+--R    [- --,----------------,----------------,----------------],
+--R        8 4503599627370496 9007199254740992 9007199254740992
+--R       31 8066281884127727 504142617757983         1
+--R    [- --,----------------,---------------,----------------],
+--R        4 9007199254740992 562949953421312 9007199254740992
+--R       59 4013622292791803 8027244585583605           1
+--R    [- --,----------------,----------------,- ----------------],
+--R        8 4503599627370496 9007199254740992   9007199254740992
+--R         7984771103407203 3992385551703601           1
+--R    [- 7,----------------,----------------,- ----------------],
+--R         9007199254740992 4503599627370496   9007199254740992
+--R       53 7938379216786421 1984594804196605           1
+--R    [- --,----------------,----------------,- ----------------],
+--R        8 9007199254740992 2251799813685248   9007199254740992
+--R       25 7887490579508773 3943745289754387         1
+--R    [- --,----------------,----------------,----------------],
+--R        4 9007199254740992 4503599627370496 9007199254740992
+--R       47 1957851283411431 7831405133645721           3
+--R    [- --,----------------,----------------,- ----------------],
+--R        8 2251799813685248 9007199254740992   9007199254740992
+--R       11 7769266764954071 7769266764954071
+--R    [- --,----------------,----------------,0],
+--R        2 9007199254740992 9007199254740992
+--R       41 1925004109374397 7700016437497587           1
+--R    [- --,----------------,----------------,- ----------------],
+--R        8 2251799813685248 9007199254740992   9007199254740992
+--R       19 476395440563229 7622327049011665         1
+--R    [- --,---------------,----------------,----------------],
+--R        4 562949953421312 9007199254740992 9007199254740992
+--R       35 3767255479315631 3767255479315631
+--R    [- --,----------------,----------------,0],
+--R        8 4503599627370496 4503599627370496
+--R         3717192768015671 3717192768015671
+--R    [- 4,----------------,----------------,0]]
+--R         4503599627370496 4503599627370496
+--R                                             Type: List List Fraction Integer
 --E 5
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+ - 10.,   0.91563333939788083, 0.91563333939788083,  0.
+ - 9.625, 0.91284446146799347, 0.91284446146799336, -1.1102230246251565E-16
+ - 9.25,  0.90986275152542417, 0.90986275152542395, -2.2204460492503131E-16
+ - 8.875, 0.90666727065475383, 0.90666727065475394,  1.1102230246251565E-16
+ - 8.5,   0.90323390197320785, 0.90323390197320796,  1.1102230246251565E-16
+ - 8.125, 0.89953471768847382, 0.89953471768847415,  3.3306690738754696E-16
+ - 7.75,  0.89553718708753915, 0.89553718708753927,  1.1102230246251565E-16
+ - 7.375, 0.89120317632125434, 0.89120317632125423, -1.1102230246251565E-16
+ - 7.,    0.88648767253642935, 0.88648767253642924, -1.1102230246251565E-16
+ - 6.625, 0.88133713846821016, 0.88133713846821005, -1.1102230246251565E-16
+ - 6.25,  0.87568736478846598, 0.87568736478846598,  0.
+ - 5.875, 0.8694606294541134,  0.86946062945411307, -3.3306690738754696E-16
+ - 5.5,   0.86256188469070139, 0.86256188469070139,  0.
+ - 5.125, 0.85487355389019959, 0.85487355389019937, -2.2204460492503131E-16
+ - 4.75,  0.84624829910358734, 0.84624829910358745,  1.1102230246251565E-16
+ - 4.375, 0.83649875455629874, 0.83649875455629874,  0.
+ - 4.,    0.82538259960422333, 0.82538259960422322, -1.1102230246251565E-16
+
+\end{verbatim}
+
 These are the Chebyshev coefficients used by Axiom in the range
 $(-4 \le x \le 4)$ in the polynomial
 $$\sum_{k=0}^{33}\ ^{'}{A_kT_k(t)}$$
 with the scaling factor $t=x/4$
 
 \begin{chunk}{*}
+
 --S 6 of 20
-cChebyshev:=[_
+cChebyshev:List Fraction Integer:= [machineFraction (x::DFLOAT) for x in _
+[_
 0.329370010376739129393905231421E1,_
 0.167983505237130291565505796064E1,_
 0.722043610567875435240299679644E0,_
@@ -416,45 +747,109 @@ cChebyshev:=[_
 0.943908972224487442925310405245E-26,_
 0.569722755950369211989581737831E-27,_
 0.333833362779543303156597939562E-28,_
-0.190062601281619148526680482237E-29]
+0.190062601281619148526680482237E-29]]
 --R 
 --R
 --R   (7)
---R   [3.2937001037 6739129393 905231421, 1.6798350523 7130291565 505796064,
---R    0.7220436105 6787543524 0299679644, 0.2600312360 5480956171 3740181192,
---R    0.0801049430 8173750223 9474288923 7, 0.0215140366 3976333754 8055248300 5,
---R    0.0051162077 8993033120 6219689108 94,
---R    0.0010909328 6100739135 6050661990 14,
---R    0.0002107415 3202393891 6318348675 226,
---R    0.0000371990 4516651888 5709594081 5956,
---R    0.0000060434 9163712387 8757047670 32866,
---R    0.9092954273 9626095264 9596541772 E -6,
---R    0.1273805160 6592647886 5567184969 E -6,
---R    0.1669185748 4109890739 0896143814 E -7,
---R    0.2054417026 4010479254 7612484551 E -8,
---R    0.2383584444 4668176591 4052321417 E -9,
---R    0.2615386378 8854429666 9068664148 E -10,
---R    0.2721858622 8541670644 6550268995 E -11,
---R    0.2693750031 9835792992 5326427442 E -12,
---R    0.2541220946 7072635546 7884089307 E -13,
---R    0.2290130406 8650370941 8510620516 E -14,
---R    0.1975465739 0746229940 1057650412 E -15,
---R    0.1634024551 9289317406 8635419984 E -16,
---R    0.1298235437 0796376099 1961293204 E -17,
---R    0.9922587925 0737105964 4632581302 E -19,
---R    0.7306252806 7221032944 7230880087 E -20,
---R    0.5189676834 6043451272 0780080019 E -21,
---R    0.3560409454 0997068112 8043162227 E -22,
---R    0.2361979432 5793864237 0187203948 E -23,
---R    0.1516837767 7214529754 9624516819 E -24,
---R    0.9439089722 2448744292 5310405245 E -26,
---R    0.5697227559 5036921198 9581737831 E -27,
---R    0.3338333627 7954330315 6597939562 E -28,
---R    0.1900626012 8161914852 6680482237 E -29]
---R                                                             Type: List Float
+--R    7416753279998493  7565304515903297  3251795335498731   4684306311204519
+--R   [----------------, ----------------, ----------------, -----------------,
+--R    2251799813685248  4503599627370496  4503599627370496  18014398509481984
+--R     1443042367253791   6200998873220695    1474646495761937
+--R    -----------------, ------------------, ------------------,
+--R    18014398509481984  288230376151711744  288230376151711744
+--R      5031039822150775     7774990213894133       5489610127785089
+--R    -------------------, --------------------, ---------------------,
+--R    4611686018427387904  36893488147419103232  147573952589676412928
+--R       7134895586664201        8588052498725463        1203074959280739
+--R    ----------------------, ----------------------, ----------------------,
+--R    1180591620717411303424  9444732965739290427392  9444732965739290427392
+--R        630600546558379           310454723434017
+--R    -----------------------, ------------------------,
+--R    37778931862957161709568  151115727451828646838272
+--R         1152630711259091            4047114395779867
+--R    -------------------------, ---------------------------,
+--R    4835703278458516698824704  154742504910672534362390528
+--R          6738995541010677              2667760816334997
+--R    ----------------------------, ----------------------------,
+--R    2475880078570760549798248448  9903520314283042199192993792
+--R           4026725323007515                 2903085184863383
+--R    ------------------------------, -------------------------------,
+--R    158456325028528675187087900672  1267650600228229401496703205376
+--R            8013441055578395                   5302712842343357
+--R    --------------------------------, ---------------------------------,
+--R    40564819207303340847894502572032  324518553658426726783156020576256
+--R             6740823781587191                     4121681768951667
+--R    ----------------------------------, -----------------------------------,
+--R    5192296858534827628530496329220096  41538374868278621028243970633760768
+--R              606979735936071                       344913186881627
+--R    -----------------------------------, ------------------------------------,
+--R    83076749736557242056487941267521536  664613997892457936451903530140172288
+--R                6057722781243673
+--R    ---------------------------------------,
+--R    170141183460469231731687303715884105728
+--R                3214959807746755
+--R    ----------------------------------------,
+--R    1361129467683753853853498429727072845824
+--R                 6606760266692207
+--R    -----------------------------------------,
+--R    43556142965880123323311949751266331066368
+--R                 6578085462557879
+--R    ------------------------------------------,
+--R    696898287454081973172991196020261297061888
+--R                  6352621007126915
+--R    --------------------------------------------,
+--R    11150372599265311570767859136324180752990208
+--R                   5955786209692185
+--R    ---------------------------------------------,
+--R    178405961588244985132285746181186892047843328
+--R                   2712664091488837
+--R    ----------------------------------------------]
+--R    1427247692705959881058285969449495136382746624
+--R                                                  Type: List Fraction Integer
 --E 6
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+    3.2937001037 6739129393 905231421 
+    1.6798350523 7130291565 505796064
+    0.7220436105 6787543524 0299679644 
+    0.2600312360 5480956171 3740181192
+    0.0801049430 8173750223 9474288923 7 
+    0.0215140366 3976333754 8055248300 5
+    0.0051162077 8993033120 6219689108 94
+    0.0010909328 6100739135 6050661990 14
+    0.0002107415 3202393891 6318348675 226
+    0.0000371990 4516651888 5709594081 5956
+    0.0000060434 9163712387 8757047670 32866
+    0.9092954273 9626095264 9596541772 E -6
+    0.1273805160 6592647886 5567184969 E -6
+    0.1669185748 4109890739 0896143814 E -7
+    0.2054417026 4010479254 7612484551 E -8
+    0.2383584444 4668176591 4052321417 E -9
+    0.2615386378 8854429666 9068664148 E -10
+    0.2721858622 8541670644 6550268995 E -11
+    0.2693750031 9835792992 5326427442 E -12
+    0.2541220946 7072635546 7884089307 E -13
+    0.2290130406 8650370941 8510620516 E -14
+    0.1975465739 0746229940 1057650412 E -15
+    0.1634024551 9289317406 8635419984 E -16
+    0.1298235437 0796376099 1961293204 E -17
+    0.9922587925 0737105964 4632581302 E -19
+    0.7306252806 7221032944 7230880087 E -20
+    0.5189676834 6043451272 0780080019 E -21
+    0.3560409454 0997068112 8043162227 E -22
+    0.2361979432 5793864237 0187203948 E -23
+    0.1516837767 7214529754 9624516819 E -24
+    0.9439089722 2448744292 5310405245 E -26
+    0.5697227559 5036921198 9581737831 E -27
+    0.3338333627 7954330315 6597939562 E -28
+    0.1900626012 8161914852 6680482237 E -29
+
+\end{verbatim}
+
 In the following table there are 4 columns. The first column
 is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
 column is the exact value shown in the table. Column 3 is the
@@ -462,7 +857,10 @@ value returned by Axiom and column 4 is the difference.
 See special.spad.dvi for details.
 
 \begin{chunk}{*}
+
 --S 7 of 20
+t3:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[-4.0,0.491822344607818096479962798267,_
   Ei3(-4.0),Ei3(-4.0)-0.491822344607818096479962798267],_
 [-3.5,0.524842506644128356918258753311,_
@@ -496,39 +894,94 @@ See special.spad.dvi for details.
 [3.5,3.45582153193012412437300898811,_
   Ei3(3.5),Ei3(3.5)-3.45582153193012412437300898811],_
 [4.0,4.41684111100869913580118598668,_
-  Ei3(4.0),Ei3(4.0)-4.41684111100869913580118598668]]
+  Ei3(4.0),Ei3(4.0)-4.41684111100869913580118598668]]]
 --R 
 --R
 --R   (8)
---R   [[- 4.,0.4918223446078181,0.49182234460781826,1.6653345369377348E-16],
---R    [- 3.5,0.52484250664412835,0.52484250664412835,0.],
---R    [- 3.,0.56295877822127982,0.56295877822128015,3.3306690738754696E-16],
---R    [- 2.5,0.60736852585838308,0.60736852585838341,3.3306690738754696E-16],
---R    [- 2.,0.65963167808476963,0.65963167808476975,1.1102230246251565E-16],
---R    [- 1.5,0.72180023694421991,0.72180023694422013,2.2204460492503131E-16],
---R    [- 1.,0.79659959929705315,0.79659959929705293,- 2.2204460492503131E-16],
---R    [- 0.5,0.88768415823549673,0.88768415823549696,2.2204460492503131E-16],
---R    [0.,1.,1.,0.],
---R    [0.5,1.1403028410431721,1.1403028410431715,- 6.6613381477509392E-16],
---R    [1.,1.3179021514544038,1.3179021514544034,- 4.4408920985006262E-16],
---R    [1.5,1.5457364507467337,1.5457364507467335,- 2.2204460492503131E-16],
---R    [2.,1.841935755270206,1.8419357552702071,1.1102230246251565E-15],
---R    [2.5,2.2321037991211652,2.2321037991211647,- 4.4408920985006262E-16],
---R    [3.,2.7526682056852581,2.7526682056852589,8.8817841970012523E-16],
---R    [3.5,3.4558215319301242,3.4558215319301238,- 4.4408920985006262E-16],
---R    [4.,4.4168411110086989,4.4168411110087007,1.7763568394002505E-15]]
---R                               Type: List List OnePointCompletion DoubleFloat
+--R          8859883711633013 4429941855816505           3
+--R   [[- 4,-----------------,----------------,- -----------------],
+--R         18014398509481984 9007199254740992   18014398509481984
+--R       7 4727361034701387 4727361034701385           1
+--R    [- -,----------------,----------------,- ----------------],
+--R       2 9007199254740992 9007199254740992   4503599627370496
+--R         5070681887644611 1267670471911153         1
+--R    [- 3,----------------,----------------,----------------],
+--R         9007199254740992 2251799813685248 9007199254740992
+--R       5 2735344666732381 1367672333366191         1
+--R    [- -,----------------,----------------,----------------],
+--R       2 4503599627370496 2251799813685248 4503599627370496
+--R         5941433959248687 5941433959248687
+--R    [- 2,----------------,----------------,0],
+--R         9007199254740992 9007199254740992
+--R       3 6501398556275849 6501398556275849
+--R    [- -,----------------,----------------,0],
+--R       2 9007199254740992 9007199254740992
+--R         7175131317115389 7175131317115389
+--R    [- 1,----------------,----------------,0],
+--R         9007199254740992 9007199254740992
+--R       1 3997774044252075 3997774044252075
+--R    [- -,----------------,----------------,0], [0,1,1,0],
+--R       2 4503599627370496 4503599627370496
+--R     1 5135467450011547 5135467450011543           1
+--R    [-,----------------,----------------,- ----------------],
+--R     2 4503599627370496 4503599627370496   1125899906842624
+--R       1483825909550207 2967651819100413           1
+--R    [1,----------------,----------------,- ----------------],
+--R       1125899906842624 2251799813685248   2251799813685248
+--R     3 6961378103595983 1740344525898995           3
+--R    [-,----------------,----------------,- ----------------],
+--R     2 4503599627370496 1125899906842624   4503599627370496
+--R       2073835295268823 259229411908603         1
+--R    [2,----------------,---------------,----------------],
+--R       1125899906842624 140737488355328 1125899906842624
+--R     5 5026250918987173 1256562729746793           1
+--R    [-,----------------,----------------,- ----------------],
+--R     2 2251799813685248  562949953421312   2251799813685248
+--R       6198457752699369 6198457752699371         1
+--R    [3,----------------,----------------,----------------],
+--R       2251799813685248 2251799813685248 1125899906842624
+--R     7 7781818281729721 972727285216215           1
+--R    [-,----------------,---------------,- ----------------],
+--R     2 2251799813685248 281474976710656   2251799813685248
+--R       2486460497711683 4972920995423367         1
+--R    [4,----------------,----------------,----------------]]
+--R        562949953421312 1125899906842624 1125899906842624
+--R                                             Type: List List Fraction Integer
 --E 7
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+  -4.,  0.4918223446078181,  0.49182234460781826,  1.6653345369377348E-16
+  -3.5, 0.52484250664412835, 0.52484250664412835,  0.
+  -3.,  0.56295877822127982, 0.56295877822128015,  3.3306690738754696E-16
+  -2.5, 0.60736852585838308, 0.60736852585838341,  3.3306690738754696E-16
+  -2.,  0.65963167808476963, 0.65963167808476975,  1.1102230246251565E-16
+  -1.5, 0.72180023694421991, 0.72180023694422013,  2.2204460492503131E-16
+  -1.,  0.79659959929705315, 0.79659959929705293, -2.2204460492503131E-16
+  -0.5, 0.88768415823549673, 0.88768415823549696,  2.2204460492503131E-16
+   0.,  1.,                  1.,                   0.
+   0.5, 1.1403028410431721,  1.1403028410431715,  -6.6613381477509392E-16
+   1.,  1.3179021514544038,  1.3179021514544034,  -4.4408920985006262E-16
+   1.5, 1.5457364507467337,  1.5457364507467335,  -2.2204460492503131E-16
+   2.,  1.841935755270206,   1.8419357552702071,   1.1102230246251565E-15
+   2.5, 2.2321037991211652,  2.2321037991211647,  -4.4408920985006262E-16
+   3.,  2.7526682056852581,  2.7526682056852589,   8.8817841970012523E-16
+   3.5, 3.4558215319301242,  3.4558215319301238,  -4.4408920985006262E-16
+   4.,  4.4168411110086989,  4.4168411110087007,   1.7763568394002505E-15
+\end{verbatim}
+
 These are the Chebyshev coefficients used by Axiom in the range
 $(4 \le x \le 12)$ in the polynomial
 $$\sum_{k=0}^{49}\ ^{'}{A_kT_k(t)}$$
 with the scaling factor $t=(x-8)/4$
 
 \begin{chunk}{*}
+
 --S 8 of 20
-dChebyshev:=[_
+dChebyshev:List Fraction Integer:=[machineFraction (x::DFLOAT) for x in _
+[_
  0.245513353878129528673420457043E1,_
 -0.162438379130376524396002276856E0,_
  0.449575308093572641480785417193E-01,_
@@ -578,63 +1031,170 @@ dChebyshev:=[_
  0.466312873522730486582600122073E-28,_
 -0.118595958891902887946724005478E-28,_
  0.302029059055671310731137614875E-29,_
--0.770165054816636606098827057102E-30]
+-0.770165054816636606098827057102E-30]]
 --R 
 --R
 --R   (9)
---R   [2.4551335387 8129528673 420457043, - 0.1624383791 3037652439 6002276856,
---R    0.0449575308 0935726414 8078541719 3,
---R    - 0.0067415786 7998922998 8487188350 5,
---R    - 0.0013066971 4280329428 0515993413 87,
---R    0.0013810831 4600072576 0202020898 2,
---R    - 0.0005850228 7901596579 8687368242 394,
---R    0.0001749299 3410789197 0038740976 432,
---R    - 0.0000404728 1499052930 3552286933 38,
---R    0.0000072171 0241217099 7500357526 00049,
---R    - 0.8612776970 1986775241 4815450193 E -6,
---R    - 0.2514475296 5322559777 9084739054 E -9,
---R    0.3794747138 2014951081 4074505574 E -7,
---R    - 0.1442117969 5211980616 0265640172 E -7,
---R    0.3935049295 9761013108 7190848042 E -8,
---R    - 0.9284689401 0633175304 7289210353 E -9,
---R    0.2031789568 0065461336 6090995698 E -9,
---R    - 0.4292498504 9923683142 7918026902 E -10,
---R    0.8992647177 7812393526 8001544182 E -11,
---R    - 0.1900869118 4121097524 2396635722 E -11,
---R    0.4092198912 2237383452 6121178338 E -12,
---R    - 0.8999253437 2931901982 5435824585 E -13,
---R    0.2019654670 8242638335 4948543451 E -13,
---R    - 0.4612930261 3830820719 4950531726 E -14,
---R    0.1069023072 9386369566 8857256409 E -14,
---R    - 0.2507030070 5700729569 2572254042 E -15,
---R    0.5937322503 7915516070 6073763509 E -16,
---R    - 0.1417734582 4376625234 4732005648 E -16,
---R    0.3409203754 3608089342 6806402093 E -17,
---R    - 0.8248290269 5054937928 8702529656 E -18,
---R    0.2006369712 6214423139 8824095937 E -18,
---R    - 0.4903851667 9674222440 3498152027 E -19,
---R    0.1203734482 3483321716 6664609324 E -19,
---R    - 0.2966282447 1413682538 1453572575 E -20,
---R    0.7335512384 2880759924 2142328436 E -21,
---R    - 0.1819924142 9085112734 4263485604 E -21,
---R    0.4528629374 2957606021 7359526404 E -22,
---R    - 0.1129980043 7506096133 8906717853 E -22,
---R    0.2826681251 2901165692 3764408445 E -23,
---R    - 0.7087717977 1690496166 6732640699 E -24,
---R    0.1781104524 0187095153 4401530034 E -24,
---R    - 0.4485004076 6189635731 2006142358 E -25,
---R    0.1131540292 5754766224 505309084 E -25,
---R    - 0.2859957899 7793216379 0414326136 E -26,
---R    0.7240775806 9226736175 8172726753 E -27,
---R    - 0.1836132234 1257789805 0666710105 E -27,
---R    0.4663128735 2273048658 2600122073 E -28,
---R    - 0.1185959588 9190288794 6724005478 E -28,
---R    0.3020290590 5567131073 1137614875 E -29,
---R    - 0.7701650548 1663660609 8827057102 E -30]
---R                                                             Type: List Float
+--R    1382117311300031     731557423722231   3239531504008303
+--R   [----------------, - ----------------, -----------------,
+--R     562949953421312    4503599627370496  72057594037927936
+--R       242890969848707       753259617973121     6369121834697257
+--R    - -----------------, - ------------------, -------------------,
+--R      36028797018963968    576460752303423488  4611686018427387904
+--R        5395883663236133     6453775450638317        1493183320145779
+--R    - -------------------, --------------------, - --------------------,
+--R      9223372036854775808  36893488147419103232    36893488147419103232
+--R       532528164604281         8134537857699561
+--R    --------------------, - ----------------------,
+--R    73786976294838206464    9444732965739290427392
+--R           607962821752199           2867229871425319
+--R    - -------------------------, -----------------------,
+--R      2417851639229258349412352  75557863725914323419136
+--R          8717068241421995           4757182695361877
+--R    - ------------------------, -------------------------,
+--R      604462909807314587353088  1208925819614629174706176
+--R           8979600595238185           3930052590058827
+--R    - -------------------------, --------------------------,
+--R      9671406556917033397649408  19342813113834066795298816
+--R            830289963734795             5566179000271035
+--R    - --------------------------, ---------------------------,
+--R      19342813113834066795298816  618970019642690137449562112
+--R            2353161991123453              1013179376432369
+--R    - ----------------------------, ----------------------------,
+--R      1237940039285380274899124224  2475880078570760549798248448
+--R             445621446148073               800067642413789
+--R    - ----------------------------, -----------------------------,
+--R      4951760157141521099596496896  39614081257132168796771975168
+--R              5847583814653227                 5420590960273957
+--R    - -------------------------------, -------------------------------,
+--R      1267650600228229401496703205376  5070602400912917605986812821504
+--R              5084861077997397                  4816928278835157
+--R    - --------------------------------, --------------------------------,
+--R      20282409603651670423947251286016  81129638414606681695789005144064
+--R               4600811761642037                   69146866968253
+--R    - ---------------------------------, --------------------------------,
+--R      324518553658426726783156020576256  20282409603651670423947251286016
+--R               1070689291365919                     8334133724722991
+--R    - ----------------------------------, -----------------------------------,
+--R      1298074214633706907132624082305024  41538374868278621028243970633760768
+--R                4073960577649283
+--R    - -----------------------------------,
+--R      83076749736557242056487941267521536
+--R              8000187867145333
+--R    ------------------------------------,
+--R    664613997892457936451903530140172288
+--R                 7885731344291393
+--R    - -------------------------------------,
+--R      2658455991569831745807614120560689152
+--R               7800454739698135
+--R    --------------------------------------,
+--R    10633823966279326983230456482242756608
+--R                 1935275296767089
+--R    - --------------------------------------,
+--R      10633823966279326983230456482242756608
+--R                7705063611965249
+--R    ---------------------------------------,
+--R    170141183460469231731687303715884105728
+--R                  1922561419304415
+--R    - ---------------------------------------,
+--R      170141183460469231731687303715884105728
+--R                7694958293760327
+--R    ----------------------------------------,
+--R    2722258935367507707706996859454145691648
+--R                  241182544933917
+--R    - ---------------------------------------,
+--R      340282366920938463463374607431768211456
+--R                 7757804328533477
+--R    -----------------------------------------,
+--R    43556142965880123323311949751266331066368
+--R                   7813979150550829
+--R    - ------------------------------------------,
+--R      174224571863520493293247799005065324265472
+--R                 7885684920811405
+--R    ------------------------------------------,
+--R    696898287454081973172991196020261297061888
+--R                    7972399050187929
+--R    - -------------------------------------------,
+--R      2787593149816327892691964784081045188247552
+--R                  8073734815493375
+--R    --------------------------------------------,
+--R    11150372599265311570767859136324180752990208
+--R                    4094711710404777
+--R    - --------------------------------------------,
+--R      22300745198530623141535718272648361505980416
+--R                   8319299660180039
+--R    ---------------------------------------------,
+--R    178405961588244985132285746181186892047843328
+--R                     8463290434635963
+--R    - ---------------------------------------------,
+--R      713623846352979940529142984724747568191373312
+--R                   8621405553347179
+--R    ----------------------------------------------,
+--R    2854495385411919762116571938898990272765493248
+--R                      8793730379918429
+--R    - -----------------------------------------------]
+--R      11417981541647679048466287755595961091061972992
+--R                                                  Type: List Fraction Integer
 --E 8
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+     2.4551335387 8129528673 420457043
+    -0.1624383791 3037652439 6002276856
+     0.0449575308 0935726414 8078541719 3
+    -0.0067415786 7998922998 8487188350 5
+    -0.0013066971 4280329428 0515993413 87
+     0.0013810831 4600072576 0202020898 2
+    -0.0005850228 7901596579 8687368242 394
+     0.0001749299 3410789197 0038740976 432
+    -0.0000404728 1499052930 3552286933 38
+     0.0000072171 0241217099 7500357526 00049
+    -0.8612776970 1986775241 4815450193 E -6
+    -0.2514475296 5322559777 9084739054 E -9
+     0.3794747138 2014951081 4074505574 E -7
+    -0.1442117969 5211980616 0265640172 E -7
+     0.3935049295 9761013108 7190848042 E -8
+    -0.9284689401 0633175304 7289210353 E -9
+     0.2031789568 0065461336 6090995698 E -9
+    -0.4292498504 9923683142 7918026902 E -10
+     0.8992647177 7812393526 8001544182 E -11
+    -0.1900869118 4121097524 2396635722 E -11
+     0.4092198912 2237383452 6121178338 E -12
+    -0.8999253437 2931901982 5435824585 E -13
+     0.2019654670 8242638335 4948543451 E -13
+    -0.4612930261 3830820719 4950531726 E -14
+     0.1069023072 9386369566 8857256409 E -14
+    -0.2507030070 5700729569 2572254042 E -15
+     0.5937322503 7915516070 6073763509 E -16
+    -0.1417734582 4376625234 4732005648 E -16
+     0.3409203754 3608089342 6806402093 E -17
+    -0.8248290269 5054937928 8702529656 E -18
+     0.2006369712 6214423139 8824095937 E -18
+    -0.4903851667 9674222440 3498152027 E -19
+     0.1203734482 3483321716 6664609324 E -19
+    -0.2966282447 1413682538 1453572575 E -20
+     0.7335512384 2880759924 2142328436 E -21
+    -0.1819924142 9085112734 4263485604 E -21
+     0.4528629374 2957606021 7359526404 E -22
+    -0.1129980043 7506096133 8906717853 E -22
+     0.2826681251 2901165692 3764408445 E -23
+    -0.7087717977 1690496166 6732640699 E -24
+     0.1781104524 0187095153 4401530034 E -24
+    -0.4485004076 6189635731 2006142358 E -25
+     0.1131540292 5754766224 505309084 E -25
+    -0.2859957899 7793216379 0414326136 E -26
+     0.7240775806 9226736175 8172726753 E -27
+    -0.1836132234 1257789805 0666710105 E -27
+     0.4663128735 2273048658 2600122073 E -28
+    -0.1185959588 9190288794 6724005478 E -28
+     0.3020290590 5567131073 1137614875 E -29
+    -0.7701650548 1663660609 8827057102 E -30
+
+\end{verbatim}
+
 In the following table there are 4 columns. The first column
 is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
 column is the exact value shown in the table. Column 3 is the
@@ -642,7 +1202,10 @@ value returned by Axiom and column 4 is the difference.
 See special.spad.dvi for details.
 
 \begin{chunk}{*}
+
 --S 9 of 20
+t4:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[4.0,1.43820803145448278470968670330,_
   Ei4(4.0),Ei4(4.0)-1.43820803145448278470968670330],_
 [4.5,1.39641902962974607100674523183,_
@@ -676,39 +1239,99 @@ See special.spad.dvi for details.
 [11.5,1.10883292630507730586855234934,_
   Ei4(11.5),Ei4(11.5)-1.10883292630507730586855234934],_
 [12.0,1.10297454490675907267241234953,_
-  Ei4(12.0),Ei4(12.0)-1.10297454490675907267241234953]]
+  Ei4(12.0),Ei4(12.0)-1.10297454490675907267241234953]]]
 --R 
 --R
 --R   (10)
---R   [[4.,1.4382080314544827,1.4382080314544827,0.],
---R    [4.5,1.3964190296297461,1.3964190296297465,4.4408920985006262E-16],
---R    [5.,1.3538312774552861,1.3538312774552856,- 4.4408920985006262E-16],
---R    [5.5,1.3141435657421192,1.314143565742119,- 2.2204460492503131E-16],
---R    [6.,1.2788838604895616,1.2788838604895618,2.2204460492503131E-16],
---R    [6.5,1.2483911550017015,1.2483911550017011,- 4.4408920985006262E-16],
---R    [7.,1.222408052360531,1.222408052360531,0.],
---R    [7.5,1.2004214995996307,1.2004214995996305,- 2.2204460492503131E-16],
---R    [8.,1.1818479869872081,1.1818479869872081,0.],
---R    [8.5,1.1661265258117486,1.1661265258117477,- 8.8817841970012523E-16],
---R    [9.,1.1527592087089249,1.1527592087089251,2.2204460492503131E-16],
---R    [9.5,1.1413234759526243,1.1413234759526236,- 6.6613381477509392E-16],
---R    [10.,1.1314702047341079,1.1314702047341079,0.],
---R    [10.5,1.1229155700177607,1.1229155700177604,- 2.2204460492503131E-16],
---R    [11.,1.1154309389980384,1.115430938998039,6.6613381477509392E-16],
---R    [11.5,1.1088329263050773,1.1088329263050771,- 2.2204460492503131E-16],
---R    [12.,1.1029745449067592,1.1029745449067592,0.]]
---R                               Type: List List OnePointCompletion DoubleFloat
+--R       6477113154539663 6477113154539663
+--R   [[4,----------------,----------------,0],
+--R       4503599627370496 4503599627370496
+--R     9 3144456110746797 1572228055373399         1
+--R    [-,----------------,----------------,----------------],
+--R     2 2251799813685248 1125899906842624 2251799813685248
+--R       1524278509167537 6097114036670147           1
+--R    [5,----------------,----------------,- ----------------],
+--R       1125899906842624 4503599627370496   4503599627370496
+--R     11 5918376472987543 5918376472987543
+--R    [--,----------------,----------------,0],
+--R      2 4503599627370496 4503599627370496
+--R       5759580877550931 1439895219387733         1
+--R    [6,----------------,----------------,----------------],
+--R       4503599627370496 1125899906842624 4503599627370496
+--R     13 5622253940478285 1405563485119571           1
+--R    [--,----------------,----------------,- ----------------],
+--R      2 4503599627370496 1125899906842624   4503599627370496
+--R       5505236449105581 5505236449105581
+--R    [7,----------------,----------------,0],
+--R       4503599627370496 4503599627370496
+--R     15 5406217818284429 1351554454571107           1
+--R    [--,----------------,----------------,- ----------------],
+--R      2 4503599627370496 1125899906842624   4503599627370496
+--R       41582579326595 5322570153804161         1
+--R    [8,--------------,----------------,----------------],
+--R       35184372088832 4503599627370496 4503599627370496
+--R     17 5251766987112641 2625883493556319           3
+--R    [--,----------------,----------------,- ----------------],
+--R      2 4503599627370496 2251799813685248   4503599627370496
+--R       5191565942789421 5191565942789423         1
+--R    [9,----------------,----------------,----------------],
+--R       4503599627370496 4503599627370496 2251799813685248
+--R     19 5140063981009437 5140063981009435           1
+--R    [--,----------------,----------------,- ----------------],
+--R      2 4503599627370496 4503599627370496   2251799813685248
+--R        2547844396210673 5095688792421347         1
+--R    [10,----------------,----------------,----------------],
+--R        2251799813685248 4503599627370496 4503599627370496
+--R     21 2528581071350257 2528581071350257
+--R    [--,----------------,----------------,0],
+--R      2 2251799813685248 2251799813685248
+--R        156982948788409 5023454361229091         3
+--R    [11,---------------,----------------,----------------],
+--R        140737488355328 4503599627370496 4503599627370496
+--R     23 2496869776861841 2496869776861841
+--R    [--,----------------,----------------,0],
+--R      2 2251799813685248 2251799813685248
+--R        2483677874720611 4967355749441223         1
+--R    [12,----------------,----------------,----------------]]
+--R        2251799813685248 4503599627370496 4503599627370496
+--R                                             Type: List List Fraction Integer
 --E 9
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+    4.,   1.4382080314544827, 1.4382080314544827,  0.
+    4.5,  1.3964190296297461, 1.3964190296297465,  4.4408920985006262E-16
+    5.,   1.3538312774552861, 1.3538312774552856, -4.4408920985006262E-16
+    5.5,  1.3141435657421192, 1.314143565742119,  -2.2204460492503131E-16
+    6.,   1.2788838604895616, 1.2788838604895618,  2.2204460492503131E-16
+    6.5,  1.2483911550017015, 1.2483911550017011, -4.4408920985006262E-16
+    7.,   1.222408052360531,  1.222408052360531,   0.
+    7.5,  1.2004214995996307, 1.2004214995996305, -2.2204460492503131E-16
+    8.,   1.1818479869872081, 1.1818479869872081,  0.
+    8.5,  1.1661265258117486, 1.1661265258117477, -8.8817841970012523E-16
+    9.,   1.1527592087089249, 1.1527592087089251,  2.2204460492503131E-16
+    9.5,  1.1413234759526243, 1.1413234759526236, -6.6613381477509392E-16
+    10.,  1.1314702047341079, 1.1314702047341079,  0.
+    10.5, 1.1229155700177607, 1.1229155700177604, -2.2204460492503131E-16
+    11.,  1.1154309389980384, 1.115430938998039,   6.6613381477509392E-16
+    11.5, 1.1088329263050773, 1.1088329263050771, -2.2204460492503131E-16
+    12.,  1.1029745449067592, 1.1029745449067592,  0.
+
+\end{verbatim}
+
 These are the Chebyshev coefficients used by Axiom in the range
 $(12 \le x \le 32)$ in the polynomial
 $$\sum_{k=0}^{47}\ ^{'}{A_kT_k(t)}$$
 with the scaling factor $t=(x-22)/10$
 
 \begin{chunk}{*}
+
 --S 10 of 20
-eChebyshev:=[_
+eChebyshev:List Fraction Integer:=[machineFraction (x::DFLOAT) for x in _
+[_
  0.211702864043698668329789991614E1,_
 -0.320423727375485794990618303177E-01,_
  0.889173207735316835890182400335E-02,_
@@ -756,61 +1379,162 @@ eChebyshev:=[_
  0.464065690883818114338414829515E-28,_
 -0.101144734921151390948461800780E-28,_
  0.221721152271007711093046878345E-29,_
--0.488489046924378553224914645512E-30]
+-0.488489046924378553224914645512E-30]]
 --R 
 --R
 --R   (11)
---R   [2.1170286404 3698668329 789991614, - 0.0320423727 3754857949 9061830317 7,
---R    0.0088917320 7735316835 8901824003 35,
---R    - 0.0025079528 0518929937 0883524420 63,
---R    0.0007202789 4659598754 8875760902 487,
---R    - 0.0002103490 0585011305 3423531441 256,
---R    0.0000620573 2318276932 1658885773 0842,
---R    - 0.0000182656 6749816702 6544915568 9733,
---R    0.0000052706 5157528936 3758077882 96811,
---R    - 0.0000014596 6654761994 5753230667 19367,
---R    0.3781719973 5896367198 0484193981 E -6,
---R    - 0.8842581282 8407192007 7971589012 E -7,
---R    0.1741749198 5383936137 7350309156 E -7,
---R    - 0.2313517747 0436906350 6474480152 E -8,
---R    - 0.1228609819 1808623883 210483523 E -9,
---R    0.2349966236 3228637047 8311381926 E -9,
---R    - 0.1100719401 0272628769 0738963049 E -9,
---R    0.3848275157 8612071114 9705563369 E -10,
---R    - 0.1148440967 4900158965 8439301603 E -10,
---R    0.3056876293 0885208263 08936262 E -11,
---R    - 0.7388278729 2847356645 4163131431 E -12,
---R    0.1630933094 1659411056 4148013749 E -12,
---R    - 0.3276989373 3127124965 7111774748 E -13,
---R    0.5898114347 0713196171 1164283918 E -14,
---R    - 0.9099707635 9564920464 3554720718 E -15,
---R    0.1040752382 6695538658 5405697541 E -15,
---R    - 0.1809815426 0592279322 7163355935 E -17,
---R    - 0.3777098842 5639477336 9593494417 E -17,
---R    0.1580332901 0284795713 675988842 E -17,
---R    - 0.4684291758 8088273064 8433752957 E -18,
---R    0.1199516852 5919809370 7533478542 E -18,
---R    - 0.2823594749 8418651767 9349931117 E -19,
---R    0.6293738065 6446352262 7520190349 E -20,
---R    - 0.1352410249 5047975630 5343973177 E -20,
---R    0.2837106053 8552914159 098042621 E -21,
---R    - 0.5867007420 2463832353 1936371015 E -22,
---R    0.1205247636 0954731111 2449686917 E -22,
---R    - 0.2474446616 9988486972 8416011246 E -23,
---R    0.5099962585 8378500814 2986465688 E -24,
---R    - 0.1058382578 7754224088 7093294733 E -24,
---R    0.2215276245 0704827856 6429387155 E -25,
---R    - 0.4679278754 7569625867 1852546231 E -26,
---R    0.9972872990 6020770482 4269828079 E -27,
---R    - 0.2143267945 2167880459 1907805844 E -27,
---R    0.4640656908 8381811433 8414829515 E -28,
---R    - 0.1011447349 2115139094 846180078 E -28,
---R    0.2217211522 7100771109 3046878345 E -29,
---R    - 0.4884890469 2437855322 4914645512 E -30]
---R                                                             Type: List Float
+--R    1191781174525585     2308896286734245   5125734562591489
+--R   [----------------, - -----------------, ------------------,
+--R     562949953421312    72057594037927936  576460752303423488
+--R        5782945443283619     6643400694768645       7760508554152537
+--R    - -------------------, -------------------, - --------------------,
+--R      2305843009213693952  9223372036854775808    36893488147419103232
+--R      4579022234608113        1347768374696647       3111243542753823
+--R    --------------------, - --------------------, ---------------------,
+--R    73786976294838206464    73786976294838206464  590295810358705651712
+--R         430817523790405         892933382543919           6681265515541997
+--R    - ---------------------, ----------------------, - -----------------------,
+--R      295147905179352825856  2361183241434822606848    75557863725914323419136
+--R        5264113943515377             349608917317223
+--R    ------------------------, - ------------------------,
+--R    302231454903657293676544    151115727451828646838272
+--R           4752954024447377            4545495773301317
+--R    - --------------------------, --------------------------,
+--R      38685626227668133590597632  19342813113834066795298816
+--R           8516403865936687             5954917375129569
+--R    - --------------------------, ---------------------------,
+--R      77371252455336267181195264  154742504910672534362390528
+--R            1777126320514413             3784229558356551
+--R    - ---------------------------, ----------------------------,
+--R      154742504910672534362390528  1237940039285380274899124224
+--R            1829249212076417               3230395805861779
+--R    - ----------------------------, -----------------------------,
+--R      2475880078570760549798248448  19807040628566084398385987584
+--R             324537308282921                7476748192279689
+--R    - ----------------------------, -------------------------------,
+--R      9903520314283042199192993792  1267650600228229401496703205376
+--R              4614099938648659                 8443586448512127
+--R    - -------------------------------, --------------------------------,
+--R      5070602400912917605986812821504  81129638414606681695789005144064
+--R               4698549475627599                      4902954613655079
+--R    - ----------------------------------, - ----------------------------------,
+--R      2596148429267413814265248164610048    1298074214633706907132624082305024
+--R             8205557557449405                       4864446676744731
+--R    ----------------------------------, - -----------------------------------,
+--R    5192296858534827628530496329220096    10384593717069655257060992658440192
+--R              4982598068378341
+--R    -----------------------------------,
+--R    41538374868278621028243970633760768
+--R                4691501487801391
+--R    - ------------------------------------,
+--R      166153499473114484112975882535043072
+--R               8365812834992051
+--R    -------------------------------------,
+--R    1329227995784915872903807060280344576
+--R                112353847839265
+--R    - -----------------------------------,
+--R      83076749736557242056487941267521536
+--R               94279019844883
+--R    ------------------------------------,
+--R    332306998946228968225951765070086144
+--R                 2495548964630185
+--R    - --------------------------------------,
+--R      42535295865117307932921825928971026432
+--R                8202490366728669
+--R    ---------------------------------------,
+--R    680564733841876926926749214863536422912
+--R                  842010551651877
+--R    - ---------------------------------------,
+--R      340282366920938463463374607431768211456
+--R                2776683743867413
+--R    ----------------------------------------,
+--R    5444517870735015415413993718908291383296
+--R                   2304953145686959
+--R    - -----------------------------------------,
+--R      21778071482940061661655974875633165533184
+--R                 7719111107136643
+--R    ------------------------------------------,
+--R    348449143727040986586495598010130648530944
+--R                    815245337677599
+--R    - ------------------------------------------,
+--R      174224571863520493293247799005065324265472
+--R                  5560062486518125
+--R    -------------------------------------------,
+--R    5575186299632655785383929568162090376495104
+--R                    1194911808461447
+--R    - -------------------------------------------,
+--R      5575186299632655785383929568162090376495104
+--R                  4139604291112041
+--R    --------------------------------------------,
+--R    89202980794122492566142873090593446023921664
+--R                     3608964738639231
+--R    - ---------------------------------------------,
+--R      356811923176489970264571492362373784095686656
+--R                   6329020060058051
+--R    ----------------------------------------------,
+--R    2854495385411919762116571938898990272765493248
+--R                      5577558921079621
+--R    - -----------------------------------------------]
+--R      11417981541647679048466287755595961091061972992
+--R                                                  Type: List Fraction Integer
 --E 10
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+     2.1170286404 3698668329 789991614
+    -0.0320423727 3754857949 9061830317 7
+     0.0088917320 7735316835 8901824003 35
+    -0.0025079528 0518929937 0883524420 63
+     0.0007202789 4659598754 8875760902 487
+    -0.0002103490 0585011305 3423531441 256
+     0.0000620573 2318276932 1658885773 0842
+    -0.0000182656 6749816702 6544915568 9733
+     0.0000052706 5157528936 3758077882 96811
+    -0.0000014596 6654761994 5753230667 19367
+     0.3781719973 5896367198 0484193981 E -6
+    -0.8842581282 8407192007 7971589012 E -7
+     0.1741749198 5383936137 7350309156 E -7
+    -0.2313517747 0436906350 6474480152 E -8
+    -0.1228609819 1808623883 210483523 E -9
+     0.2349966236 3228637047 8311381926 E -9
+    -0.1100719401 0272628769 0738963049 E -9
+     0.3848275157 8612071114 9705563369 E -10
+    -0.1148440967 4900158965 8439301603 E -10
+     0.3056876293 0885208263 08936262 E -11
+    -0.7388278729 2847356645 4163131431 E -12
+     0.1630933094 1659411056 4148013749 E -12
+    -0.3276989373 3127124965 7111774748 E -13
+     0.5898114347 0713196171 1164283918 E -14
+    -0.9099707635 9564920464 3554720718 E -15
+     0.1040752382 6695538658 5405697541 E -15
+    -0.1809815426 0592279322 7163355935 E -17
+    -0.3777098842 5639477336 9593494417 E -17
+     0.1580332901 0284795713 675988842 E -17
+    -0.4684291758 8088273064 8433752957 E -18
+     0.1199516852 5919809370 7533478542 E -18
+    -0.2823594749 8418651767 9349931117 E -19
+     0.6293738065 6446352262 7520190349 E -20
+    -0.1352410249 5047975630 5343973177 E -20
+     0.2837106053 8552914159 098042621 E -21
+    -0.5867007420 2463832353 1936371015 E -22
+     0.1205247636 0954731111 2449686917 E -22
+    -0.2474446616 9988486972 8416011246 E -23
+     0.5099962585 8378500814 2986465688 E -24
+    -0.1058382578 7754224088 7093294733 E -24
+     0.2215276245 0704827856 6429387155 E -25
+    -0.4679278754 7569625867 1852546231 E -26
+     0.9972872990 6020770482 4269828079 E -27
+    -0.2143267945 2167880459 1907805844 E -27
+     0.4640656908 8381811433 8414829515 E -28
+    -0.1011447349 2115139094 846180078 E -28
+     0.2217211522 7100771109 3046878345 E -29
+    -0.4884890469 2437855322 4914645512 E -30
+
+\end{verbatim}
+
 In the following table there are 4 columns. The first column
 is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
 column is the exact value shown in the table. Column 3 is the
@@ -818,7 +1542,10 @@ value returned by Axiom and column 4 is the difference.
 See special.spad.dvi for details.
 
 \begin{chunk}{*}
+
 --S 11 of 20
+t5:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[12.00,1.10297454490675907267241234952,_
   Ei5(12.00),Ei5(12.00)-1.10297454490675907267241234952],_
 [13.25,1.09084489821547569266468614954,_
@@ -852,31 +1579,89 @@ See special.spad.dvi for details.
 [30.75,1.03487414989647969472990938990,_
   Ei5(30.75),Ei5(30.75)-1.03487414989647969472990938990],_
 [32.00,1.03341356421624104943493552567,_
-  Ei5(32.00),Ei5(32.00)-1.03341356421624104943493552567]]
+  Ei5(32.00),Ei5(32.00)-1.03341356421624104943493552567]]]
 --R 
 --R
 --R   (12)
---R   [[12.,1.1029745449067592,1.1029745449067585,- 6.6613381477509392E-16],
---R    [13.25,1.0908448982154757,1.090844898215475,- 6.6613381477509392E-16],
---R    [14.5,1.0813513957351912,1.0813513957351915,2.2204460492503131E-16],
---R    [15.75,1.0737013841997571,1.0737013841997574,2.2204460492503131E-16],
---R    [17.,1.0673936919585378,1.0673936919585385,6.6613381477509392E-16],
---R    [18.25,1.0620966086221502,1.0620966086221502,0.],
---R    [19.5,1.057581342158725,1.0575813421587252,2.2204460492503131E-16],
---R    [20.75,1.0536844512894095,1.0536844512894095,0.],
---R    [22.,1.0502857196851898,1.0502857196851898,0.],
---R    [23.25,1.0472945517053249,1.0472945517053245,- 4.4408920985006262E-16],
---R    [24.5,1.0446412679046437,1.0446412679046437,0.],
---R    [25.75,1.0422713372023202,1.04227133720232,- 2.2204460492503131E-16],
---R    [27.,1.0401414383230105,1.0401414383230101,- 4.4408920985006262E-16],
---R    [28.25,1.0382167003601459,1.0382167003601459,0.],
---R    [29.5,1.0364687262924119,1.0364687262924113,- 6.6613381477509392E-16],
---R    [30.75,1.0348741498964797,1.0348741498964795,- 2.2204460492503131E-16],
---R    [32.,1.033413564216241,1.0334135642162412,2.2204460492503131E-16]]
---R                               Type: List List OnePointCompletion DoubleFloat
+--R        2483677874720611 1241838937360305           1
+--R   [[12,----------------,----------------,- ----------------],
+--R        2251799813685248 1125899906842624   2251799813685248
+--R     53 2456364338561111 1228182169280555           1
+--R    [--,----------------,----------------,- ----------------],
+--R      4 2251799813685248 1125899906842624   2251799813685248
+--R     29 4869973742889573 2434986871444787         1
+--R    [--,----------------,----------------,----------------],
+--R      2 4503599627370496 2251799813685248 4503599627370496
+--R     63 1208880288447303 4835521153789213         1
+--R    [--,----------------,----------------,----------------],
+--R      4 1125899906842624 4503599627370496 4503599627370496
+--R        600889229170261 1201778458340523         1
+--R    [17,---------------,----------------,----------------],
+--R        562949953421312 1125899906842624 1125899906842624
+--R     73 4783257890822183 4783257890822183
+--R    [--,----------------,----------------,0],
+--R      4 4503599627370496 4503599627370496
+--R     39 4762922938460023 595365367307503         1
+--R    [--,----------------,---------------,----------------],
+--R      2 4503599627370496 562949953421312 4503599627370496
+--R     83 4745372902193069 2372686451096535         1
+--R    [--,----------------,----------------,----------------],
+--R      4 4503599627370496 2251799813685248 4503599627370496
+--R        4730066375806773 2365033187903387         1
+--R    [22,----------------,----------------,----------------],
+--R        4503599627370496 2251799813685248 4503599627370496
+--R     93 4716595352807251 2358297676403625           1
+--R    [--,----------------,----------------,- ----------------],
+--R      4 4503599627370496 2251799813685248   4503599627370496
+--R     49 4704646024871195 1176161506217799         1
+--R    [--,----------------,----------------,----------------],
+--R      2 4503599627370496 1125899906842624 4503599627370496
+--R     103 2346986402921659 4693972805843317           1
+--R    [---,----------------,----------------,- ----------------],
+--R      4  2251799813685248 4503599627370496   4503599627370496
+--R        4684380594044121 585547574255515           1
+--R    [27,----------------,---------------,- ----------------],
+--R        4503599627370496 562949953421312   4503599627370496
+--R     113 2337856172435889 4675712344871779         1
+--R    [---,----------------,----------------,----------------],
+--R      4  2251799813685248 4503599627370496 4503599627370496
+--R     59 2333920084755839 1166960042377919           1
+--R    [--,----------------,----------------,- ----------------],
+--R      2 2251799813685248 1125899906842624   2251799813685248
+--R     123 582582354481143 582582354481143
+--R    [---,---------------,---------------,0],
+--R      4  562949953421312 562949953421312
+--R        4654080942723879 581760117840485         1
+--R    [32,----------------,---------------,----------------]]
+--R        4503599627370496 562949953421312 4503599627370496
+--R                                             Type: List List Fraction Integer
 --E 11
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+ 12.,   1.1029745449067592, 1.1029745449067585, -6.6613381477509392E-16
+ 13.25, 1.0908448982154757, 1.090844898215475,  -6.6613381477509392E-16
+ 14.5,  1.0813513957351912, 1.0813513957351915,  2.2204460492503131E-16
+ 15.75, 1.0737013841997571, 1.0737013841997574,  2.2204460492503131E-16
+ 17.,   1.0673936919585378, 1.0673936919585385,  6.6613381477509392E-16
+ 18.25, 1.0620966086221502, 1.0620966086221502,  0.
+ 19.5,  1.057581342158725,  1.0575813421587252,  2.2204460492503131E-16
+ 20.75, 1.0536844512894095, 1.0536844512894095,  0.
+ 22.,   1.0502857196851898, 1.0502857196851898,  0.
+ 23.25, 1.0472945517053249, 1.0472945517053245, -4.4408920985006262E-16
+ 24.5,  1.0446412679046437, 1.0446412679046437,  0.
+ 25.75, 1.0422713372023202, 1.04227133720232,   -2.2204460492503131E-16
+ 27.,   1.0401414383230105, 1.0401414383230101, -4.4408920985006262E-16
+ 28.25, 1.0382167003601459, 1.0382167003601459,  0.
+ 29.5,  1.0364687262924119, 1.0364687262924113, -6.6613381477509392E-16
+ 30.75, 1.0348741498964797, 1.0348741498964795, -2.2204460492503131E-16
+ 32.,   1.033413564216241,  1.0334135642162412,  2.2204460492503131E-16
+
+\end{verbatim}
+
 These are the Chebyshev coefficients used by Axiom in the range
 $(32 \le x < \infty)$ in the polynomial
 $$\sum_{k=0}^{46}\ ^{'}{A_kT_k(t)}$$
@@ -885,7 +1670,8 @@ with the scaling factor $t=(64/X)-1$
 \begin{chunk}{*}
 
 --S 12 of 20
-fChebyshev:=[_
+fChebyshev:List Fraction Integer:=[machineFraction (x::DFLOAT) for x in _
+[_
  0.203284394579616699087873844202E1,_
  0.166992045203136285147618434339E-01,_
  0.284528472436134680742489985325E-03,_
@@ -932,60 +1718,173 @@ fChebyshev:=[_
  0.845381406448938089437361193598E-29,_
  0.356575515120151526590791715785E-29,_
 -0.138365242347797751810195772006E-29,_
--0.606214265320934505767865286306E-30]
+-0.606214265320934505767865286306E-30]]
 --R 
 --R
 --R   (13)
---R   [2.0328439457 9616699087 873844202, 0.0166992045 2031362851 4761843433 9,
---R    0.0002845284 7243613468 0742489985 325,
---R    0.0000075639 4435851620 6489487866 93854,
---R    0.2798971289 4508591575 048431809 E -6,
---R    0.1357901828 5345310695 2556392593 E -7,
---R    0.8343596202 0404692558 5610289412 E -9,
---R    0.6370971727 6402484382 7524337306 E -10,
---R    0.6007247608 8118612357 608308485 E -11,
---R    0.7022876174 6797735907 5059216588 E -12,
---R    0.1018302673 7036876930 9667322152 E -12,
---R    0.1761812903 4308800404 0656741554 E -13,
---R    0.3250828614 2353606942 4072007647 E -14,
---R    0.5071770025 5058186788 1479300685 E -15,
---R    0.1665177387 0432942985 3520036957 E -16,
---R    - 0.3166753890 7975144007 2410018963 E -16,
---R    - 0.1588403763 6641415154 8423134074 E -16,
---R    - 0.4175513256 1380188308 9626455063 E -17,
---R    - 0.2892347749 7071418820 2868862358 E -18,
---R    0.2800625903 3966080728 9978777339 E -18,
---R    0.1322938639 5392708914 0532005364 E -18,
---R    0.1804447444 1773019958 5334811191 E -19,
---R    - 0.7905384086 5226165620 2021080364 E -20,
---R    - 0.4435711366 3695734471 8167314045 E -20,
---R    - 0.4264103994 9781026176 0579779746 E -21,
---R    0.3920101766 9371439072 5625388636 E -21,
---R    0.1527378051 3439636447 2804486402 E -21,
---R    - 0.1024849527 0494906078 6953149788 E -22,
---R    - 0.2134907874 7710893794 8904287231 E -22,
---R    - 0.3239139475 1602368761 4279789345 E -23,
---R    0.2142183762 2964597029 6249355934 E -23,
---R    0.8234609419 6189955316 9207838151 E -24,
---R    - 0.1524652829 6206721081 1495038147 E -24,
---R    - 0.1378208282 4882440129 0438126477 E -24,
---R    0.2131311201 4287370679 1513005998 E -26,
---R    0.2012649651 8713266585 9213006507 E -25,
---R    0.1995535662 0563740232 0607178286 E -26,
---R    - 0.2798995812 2017971142 6020884464 E -26,
---R    - 0.5534511830 5070025094 978494256 E -27,
---R    0.3884995422 6845525312 9749000696 E -27,
---R    0.1121304407 2330701254 0043264712 E -27,
---R    - 0.5566568286 7445948805 7823816866 E -28,
---R    - 0.2045482612 4651357628 8865878722 E -28,
---R    0.8453814064 4893808943 7361193598 E -29,
---R    0.3565755151 2015152659 0791715785 E -29,
---R    - 0.1383652423 4779775181 0195772006 E -29,
---R    - 0.6062142653 2093450576 7865286306 E -30]
---R                                                             Type: List Float
+--R    4577557618394993   2406609000162181     2624311956356449
+--R   [----------------, ------------------, -------------------,
+--R    2251799813685248  144115188075855872  9223372036854775808
+--R       1116241166154621        5287107281526867         4104006452543279
+--R    ---------------------, -----------------------, ------------------------,
+--R    147573952589676412928  18889465931478580854784  302231454903657293676544
+--R         8069431101668225           4929300619250635
+--R    -------------------------, --------------------------,
+--R    9671406556917033397649408  77371252455336267181195264
+--R          3718306170424781             108673745094743
+--R    ---------------------------, ---------------------------,
+--R    618970019642690137449562112  154742504910672534362390528
+--R           8067824972090565               2791703980654993
+--R    -----------------------------, ------------------------------,
+--R    79228162514264337593543950336  158456325028528675187087900672
+--R           2060457422037279                 2571692926820797
+--R    ------------------------------, -------------------------------,
+--R    633825300114114700748351602688  5070602400912917605986812821504
+--R             5403809572280081                     5138351962169023
+--R    ---------------------------------, - ---------------------------------,
+--R    324518553658426726783156020576256    162259276829213363391578010288128
+--R               2577332460049443                     5420126090653991
+--R    - ---------------------------------, - ----------------------------------,
+--R      162259276829213363391578010288128    1298074214633706907132624082305024
+--R               1501792813459467                    1454168108013747
+--R    - ----------------------------------, ----------------------------------,
+--R      5192296858534827628530496329220096  5192296858534827628530496329220096
+--R              5495272113691275                     2998152574653761
+--R    -----------------------------------, ------------------------------------,
+--R    41538374868278621028243970633760768  166153499473114484112975882535043072
+--R                1313507230654803
+--R    - ------------------------------------,
+--R      166153499473114484112975882535043072
+--R                2948035864699899
+--R    - ------------------------------------,
+--R      664613997892457936451903530140172288
+--R                 4534373125650557
+--R    - --------------------------------------,
+--R      10633823966279326983230456482242756608
+--R               8337134423902027
+--R    --------------------------------------,
+--R    21267647932558653966460912964485513216
+--R               3248373865590091
+--R    --------------------------------------,
+--R    21267647932558653966460912964485513216
+--R                  1743691114011025
+--R    - ---------------------------------------,
+--R      170141183460469231731687303715884105728
+--R                  7264715047852567
+--R    - ---------------------------------------,
+--R      340282366920938463463374607431768211456
+--R                  4408888189578287
+--R    - ----------------------------------------,
+--R      1361129467683753853853498429727072845824
+--R                2915789444055361
+--R    ----------------------------------------,
+--R    1361129467683753853853498429727072845824
+--R                4483347814363851
+--R    ----------------------------------------,
+--R    5444517870735015415413993718908291383296
+--R                   3320399831014583
+--R    - -----------------------------------------,
+--R      21778071482940061661655974875633165533184
+--R                   6002943698881805
+--R    - -----------------------------------------,
+--R      43556142965880123323311949751266331066368
+--R                  5941228505229555
+--R    -------------------------------------------,
+--R    2787593149816327892691964784081045188247552
+--R                 7013060478170909
+--R    ------------------------------------------,
+--R    348449143727040986586495598010130648530944
+--R                  2781370770881269
+--R    -------------------------------------------,
+--R    1393796574908163946345982392040522594123776
+--R                    3901230776229159
+--R    - -------------------------------------------,
+--R      1393796574908163946345982392040522594123776
+--R                    3085593453259749
+--R    - -------------------------------------------,
+--R      5575186299632655785383929568162090376495104
+--R                  4331914650937299
+--R    --------------------------------------------,
+--R    11150372599265311570767859136324180752990208
+--R                  5001184775138823
+--R    --------------------------------------------,
+--R    44601490397061246283071436545296723011960832
+--R                    2482772419858247
+--R    - --------------------------------------------,
+--R      44601490397061246283071436545296723011960832
+--R                     912315730972195
+--R    - --------------------------------------------,
+--R      44601490397061246283071436545296723011960832
+--R                   3016421654526915
+--R    ---------------------------------------------,
+--R    356811923176489970264571492362373784095686656
+--R                   5089215812306753
+--R    ----------------------------------------------,
+--R    1427247692705959881058285969449495136382746624
+--R                     1974814728915953
+--R    - ----------------------------------------------,
+--R      1427247692705959881058285969449495136382746624
+--R                     3460871645858969
+--R    - ----------------------------------------------]
+--R      5708990770823839524233143877797980545530986496
+--R                                                  Type: List Fraction Integer
 --E 12
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+     2.0328439457 9616699087 873844202 
+     0.0166992045 2031362851 4761843433 9
+     0.0002845284 7243613468 0742489985 325
+     0.0000075639 4435851620 6489487866 93854
+     0.2798971289 4508591575 048431809 E -6
+     0.1357901828 5345310695 2556392593 E -7
+     0.8343596202 0404692558 5610289412 E -9
+     0.6370971727 6402484382 7524337306 E -10
+     0.6007247608 8118612357 608308485 E -11
+     0.7022876174 6797735907 5059216588 E -12
+     0.1018302673 7036876930 9667322152 E -12
+     0.1761812903 4308800404 0656741554 E -13
+     0.3250828614 2353606942 4072007647 E -14
+     0.5071770025 5058186788 1479300685 E -15
+     0.1665177387 0432942985 3520036957 E -16
+    -0.3166753890 7975144007 2410018963 E -16
+    -0.1588403763 6641415154 8423134074 E -16
+    -0.4175513256 1380188308 9626455063 E -17
+    -0.2892347749 7071418820 2868862358 E -18
+     0.2800625903 3966080728 9978777339 E -18
+     0.1322938639 5392708914 0532005364 E -18
+     0.1804447444 1773019958 5334811191 E -19
+    -0.7905384086 5226165620 2021080364 E -20
+    -0.4435711366 3695734471 8167314045 E -20
+    -0.4264103994 9781026176 0579779746 E -21
+     0.3920101766 9371439072 5625388636 E -21
+     0.1527378051 3439636447 2804486402 E -21
+    -0.1024849527 0494906078 6953149788 E -22
+    -0.2134907874 7710893794 8904287231 E -22
+    -0.3239139475 1602368761 4279789345 E -23
+     0.2142183762 2964597029 6249355934 E -23
+     0.8234609419 6189955316 9207838151 E -24
+    -0.1524652829 6206721081 1495038147 E -24
+    -0.1378208282 4882440129 0438126477 E -24
+     0.2131311201 4287370679 1513005998 E -26
+     0.2012649651 8713266585 9213006507 E -25
+     0.1995535662 0563740232 0607178286 E -26
+    -0.2798995812 2017971142 6020884464 E -26
+    -0.5534511830 5070025094 978494256 E -27
+     0.3884995422 6845525312 9749000696 E -27
+     0.1121304407 2330701254 0043264712 E -27
+    -0.5566568286 7445948805 7823816866 E -28
+    -0.2045482612 4651357628 8865878722 E -28
+     0.8453814064 4893808943 7361193598 E -29
+     0.3565755151 2015152659 0791715785 E -29
+    -0.1383652423 4779775181 0195772006 E -29
+    -0.6062142653 2093450576 7865286306 E -30
+
+\end{verbatim}
+
 In the following table there are 4 columns. The first column
 is the argument of Ei(x) shown in Table 4 in \cite{1}. The second
 column is the exact value shown in the table. Column 3 is the
@@ -993,7 +1892,10 @@ value returned by Axiom and column 4 is the difference.
 See special.spad.dvi for details.
 
 \begin{chunk}{*}
+
 --S 13 of 20
+t6:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[32,1.03341356421624104943493552567,_
   Ei6(32.0),Ei6(32.0)-1.03341356421624104943493552567],_
 [34+2/15,1.03118521236465926355875784663,_
@@ -1025,79 +1927,156 @@ See special.spad.dvi for details.
 [256,1.00393713090569862788009078297,_
   Ei6(256.0),Ei6(256.0)-1.00393713090569862788009078297],_
 [512,1.00196079945071192531337468473,_
-  Ei6(512.0),Ei6(512.0)-1.00196079945071192531337468473],_
-[infinity(),1.00000000000000000000000000001,_
-  Ei6(infinity()),Ei6(infinity())-1.00000000000000000000000000001]]
+  Ei6(512.0),Ei6(512.0)-1.00196079945071192531337468473]]]
 --R 
 --R
 --R   (14)
---R   [[32.,1.033413564216241,1.0334135642162412,2.2204460492503131E-16],
---R
---R      512
---R     [---, 1.0311852123 6465926355 875784663, 1.0311852123646588,
---R       15
---R      - 4.4408920985006262E-16]
---R     ,
---R     256
---R    [---,1.0289774041 0580800863 378435059,1.028977404105808,0.],
---R      7
---R     512
---R    [---,1.0267896837 0902852450 984510823,1.0267896837090285,0.],
---R      13
---R
---R      128
---R     [---, 1.0246216146 8107839101 187804247, 1.0246216146810787,
---R       3
---R      2.2204460492503131E-16]
---R     ,
---R     512
---R    [---,1.0224727784 0542059591 275364791,1.0224727784054206,0.],
---R      11
---R     256
---R    [---,1.0203427729 3078377487 217829808,1.0203427729307837,0.],
---R      5
---R
---R      512
---R     [---, 1.0182312118 8483269682 337017143, 1.0182312118848329,
---R       9
---R      2.2204460492503131E-16]
---R     ,
---R    [64.,1.0161377234943254,1.0161377234943252,- 2.2204460492503131E-16],
---R
---R      512
---R     [---, 1.0140619496 9697133145 942329335, 1.0140619496969712,
---R       7
---R      - 2.2204460492503131E-16]
---R     ,
---R     256
---R    [---,1.0120035453 3298848201 864466702,1.0120035453329885,0.],
---R      3
---R
---R      512
---R     [---, 1.0099621774 0644975574 36754557, 1.0099621774064493,
---R       5
---R      - 4.4408920985006262E-16]
---R     ,
---R    [128.,1.0079375244081401,1.0079375244081401,0.],
---R
---R      512
---R     [---, 1.0059292756 9292911294 663030932, 1.0059292756929286,
---R       3
---R      - 4.4408920985006262E-16]
---R     ,
---R    [256.,1.0039371309056986,1.0039371309056981,- 4.4408920985006262E-16],
---R    [512.,1.001960799450712,1.0019607994507116,- 4.4408920985006262E-16],
---R    [infinity,1.,1.,0.]]
---R                                                          Type: List List Any
+--R        4654080942723879 581760117840485         1
+--R   [[32,----------------,---------------,----------------],
+--R        4503599627370496 562949953421312 4503599627370496
+--R     4803839602528529 4644045338155445 4644045338155443           1
+--R    [----------------,----------------,----------------,- ----------------],
+--R      140737488355328 4503599627370496 4503599627370496   2251799813685248
+--R     2573485501354569 4634102253703577 4634102253703577
+--R    [----------------,----------------,----------------,0],
+--R      70368744177664  4503599627370496 4503599627370496
+--R     1385722962267845 2312124818469925 2312124818469925
+--R    [----------------,----------------,----------------,0],
+--R      35184372088832  2251799813685248 2251799813685248
+--R     6004799503160661 1153621380518365 2307242761036731         1
+--R    [----------------,----------------,----------------,----------------],
+--R      140737488355328 1125899906842624 2251799813685248 2251799813685248
+--R     3275345183542179 4604808023823127 575601002977891         1
+--R    [----------------,----------------,---------------,----------------],
+--R      70368744177664  4503599627370496 562949953421312 4503599627370496
+--R     3602879701896397 574401916495157 574401916495157
+--R    [----------------,---------------,---------------,0],
+--R      70368744177664  562949953421312 562949953421312
+--R     2001599834386887 4585705706421541 2292852853210771         1
+--R    [----------------,----------------,----------------,----------------],
+--R      35184372088832  4503599627370496 2251799813685248 4503599627370496
+--R        4576277472886147 4576277472886147
+--R    [64,----------------,----------------,0],
+--R        4503599627370496 4503599627370496
+--R     2573485501354569 2283464509392939 2283464509392939
+--R    [----------------,----------------,----------------,0],
+--R      35184372088832  2251799813685248 2251799813685248
+--R     6004799503160661 4557658789659267 1139414697414817         1
+--R    [----------------,----------------,----------------,----------------],
+--R      70368744177664  4503599627370496 1125899906842624 4503599627370496
+--R     3602879701896397 4548465285825981 1137116321456495           1
+--R    [----------------,----------------,----------------,- ----------------],
+--R      35184372088832  4503599627370496 1125899906842624   4503599627370496
+--R         567418382417155 567418382417155
+--R    [128,---------------,---------------,0],
+--R         562949953421312 562949953421312
+--R     6004799503160661 1132575677792937 2265151355585873           1
+--R    [----------------,----------------,----------------,- ----------------],
+--R      35184372088832  1125899906842624 2251799813685248   2251799813685248
+--R         4521330888650309 4521330888650307           1
+--R    [256,----------------,----------------,- ----------------],
+--R         4503599627370496 4503599627370496   2251799813685248
+--R         2256215141523035 4512430283046069           1
+--R    [512,----------------,----------------,- ----------------]]
+--R         2251799813685248 4503599627370496   4503599627370496
+--R                                             Type: List List Fraction Integer
 --E 13
 
 \end{chunk}
-In the following table we show values returned by 
-$(Ei(x)-\log x-\gamma)/x$ where gamma is as shown above.
-Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
-Dover Publications, Inc. New York 1965. p 238
 
+The actual table values from above are:
+\begin{verbatim}
+
+   [[ 32., 1.033413564216241,                 
+           1.0334135642162412,
+           2.2204460492503131E-16],
+
+      512
+     [---, 1.0311852123 6465926355 875784663, 
+       15
+           1.0311852123646588,
+         - 4.4408920985006262E-16]
+     ,
+     256
+    [---,  1.0289774041 0580800863 378435059,
+      7
+           1.028977404105808,
+           0.],
+     512
+    [---,  1.0267896837 0902852450 984510823,
+      13
+           1.0267896837090285,
+           0.],
+
+      128
+     [---, 1.0246216146 8107839101 187804247, 
+       3
+           1.0246216146810787,
+           2.2204460492503131E-16]
+     ,
+     512
+    [---,  1.0224727784 0542059591 275364791,
+      11
+           1.0224727784054206,
+           0.],
+     256
+    [---,  1.0203427729 3078377487 217829808,
+      5
+           1.0203427729307837,
+           0.],
+
+      512
+     [---, 1.0182312118 8483269682 337017143, 
+       9
+           1.0182312118848329,
+           2.2204460492503131E-16]
+     ,
+    [64.,  1.0161377234943254,
+           1.0161377234943252,
+          -2.2204460492503131E-16],
+      512
+     [---, 1.0140619496 9697133145 942329335, 
+       7
+           1.0140619496969712,
+          -2.2204460492503131E-16]
+     ,
+     256
+    [---,  1.0120035453 3298848201 864466702,
+      3
+           1.0120035453329885,
+           0.],
+
+      512
+     [---, 1.0099621774 0644975574 36754557, 
+       5
+           1.0099621774064493,
+          -4.4408920985006262E-16]
+     ,
+    [128., 1.0079375244081401,
+           1.0079375244081401,
+           0.],
+
+      512
+     [---, 1.0059292756 9292911294 663030932, 
+       3
+           1.0059292756929286,
+          -4.4408920985006262E-16]
+     ,
+    [256., 1.0039371309056986,
+           1.0039371309056981,
+          -4.4408920985006262E-16],
+
+    [512., 1.001960799450712,
+           1.0019607994507116,
+          -4.4408920985006262E-16],
+
+    [infinity,1.,
+              1., 
+              0.]]
+
+\end{verbatim}
 \begin{chunk}{*}
+
 --S 14 of 20
 h(x:DFLOAT):DFLOAT==
   x=0.0::DFLOAT => 1.0 
@@ -1109,7 +2088,18 @@ h(x:DFLOAT):DFLOAT==
 --R                                                                   Type: Void
 --E 14
 
+\end{chunk}
+
+In the following table we show values returned by 
+$(Ei(x)-\log x-\gamma)/x$ where gamma is as shown above.
+Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. p 238
+
+\begin{chunk}{*}
+
 --S 15 of 20
+t7:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[0.00,1.000000000,h(0.00),h(0.00)-1.000000000],_
  [0.01,1.002505566,h(0.01),h(0.01)-1.002505566],_
  [0.02,1.005022306,h(0.02),h(0.02)-1.005022306],_
@@ -1160,157 +2150,335 @@ h(x:DFLOAT):DFLOAT==
  [0.47,1.130940671,h(0.47),h(0.47)-1.130940671],_
  [0.48,1.134046738,h(0.48),h(0.48)-1.134046738],_
  [0.49,1.137167432,h(0.49),h(0.49)-1.137167432],_
- [0.50,1.140302841,h(0.50),h(0.50)-1.140302841]]
+ [0.50,1.140302841,h(0.50),h(0.50)-1.140302841]]]
 --R 
 --R   Compiling function h with type DoubleFloat -> DoubleFloat 
 --R
 --R   (16)
---R   [[0.,1.,1.,0.],
---R    [1.0E-2,1.002505566,1.002505565988876,- 1.1123990617534218E-11],
---R    [2.0E-2,1.0050223060000001,1.0050223058229502,- 1.7704993027223281E-10],
---R
---R     [2.9999999999999999E-2, 1.007550283, 1.0075502826056368,
---R      - 3.9436320875552155E-10]
---R     ,
---R
---R     [4.0000000000000001E-2, 1.0100895599999999, 1.0100895598460362,
---R      - 1.5396373065357238E-10]
---R     ,
---R
---R     [5.0000000000000003E-2, 1.012640202, 1.0126402014616676,
---R      - 5.3833248969681335E-10]
---R     ,
---R
---R     [5.9999999999999998E-2, 1.015202272, 1.0152022717813329,
---R      - 2.1866708443951666E-10]
---R     ,
---R
---R     [7.0000000000000007E-2, 1.017775836, 1.0177758355479642,
---R      - 4.5203574217111964E-10]
---R     ,
---R
---R     [8.0000000000000002E-2, 1.0203609579999999, 1.0203609579215664,
---R      - 7.8433481931483584E-11]
---R     ,
---R
---R     [8.9999999999999997E-2, 1.0229577050000001, 1.0229577044820872,
---R      - 5.1791282373869763E-10]
---R     ,
---R
---R     [0.10000000000000001, 1.0255661410000001, 1.0255661412323602,
---R      2.3236013113603349E-10]
---R     ,
---R    [0.11,1.028186335,1.0281863346010778,- 3.989222285838423E-10],
---R    [0.12,1.030818352,1.0308183514457605,- 5.5423954314903767E-10],
---R    [0.13,1.033462259,1.0334622590557541,5.5754068029045811E-11],
---R    [0.14000000000000001,1.036118125,1.0361181251552536,1.5525358776358189E-10],
---R
---R     [0.14999999999999999, 1.0387860179999999, 1.0387860179063644,
---R      - 9.3635543763070928E-11]
---R     ,
---R    [0.16,1.0414660060000001,1.0414660059121499,- 8.7850171581749237E-11],
---R
---R     [0.17000000000000001, 1.0441581579999999, 1.0441581582197257,
---R      2.1972579311579921E-10]
---R     ,
---R
---R     [0.17999999999999999, 1.0468625439999999, 1.0468625443233892,
---R      3.233893153264944E-10]
---R     ,
---R    [0.19,1.0495792340000001,1.0495792341677359,1.6773582522944253E-10],
---R    [0.20000000000000001,1.052308298,1.0523082981508358,1.5083578830399347E-10],
---R
---R     [0.20999999999999999, 1.0550498070000001, 1.055049807127405,
---R      1.2740497545848939E-10]
---R     ,
---R    [0.22,1.0578038329999999,1.0578038324120198,- 5.8798010904581588E-10],
---R
---R     [0.23000000000000001, 1.0605704460000001, 1.0605704457823433,
---R      - 2.1765678148710776E-10]
---R     ,
---R
---R     [0.23999999999999999, 1.0633497190000001, 1.0633497194823853,
---R      4.8238524286148277E-10]
---R     ,
---R    [0.25,1.0661417259999999,1.0661417262257755,2.2577562042158661E-10],
---R
---R     [0.26000000000000001, 1.0689465389999999, 1.0689465391990731,
---R      1.9907320236711712E-10]
---R     ,
---R    [0.27000000000000002,1.071764232,1.0717642320650853,6.5085270506415327E-11],
---R
---R     [0.28000000000000003, 1.0745948789999999, 1.0745948789662336,
---R      - 3.3766323070949511E-11]
---R     ,
---R
---R     [0.28999999999999998, 1.0774385550000001, 1.0774385545279166,
---R      - 4.7208348341598594E-10]
---R     ,
---R
---R     [0.29999999999999999, 1.0802953340000001, 1.0802953338619241,
---R      - 1.3807599508197654E-10]
---R     ,
---R    [0.31,1.083165293,1.0831652925698594,- 4.3014058981327707E-10],
---R
---R     [0.32000000000000001, 1.0860485070000001, 1.0860485067465939,
---R      - 2.5340618492464273E-10]
---R     ,
---R
---R     [0.33000000000000002, 1.088945053, 1.0889450529837443,
---R      - 1.6255663481956617E-11]
---R     ,
---R    [0.34000000000000002,1.091855008,1.0918550083731842,3.7318415024856222E-10],
---R
---R     [0.34999999999999998, 1.094778451, 1.0947784505105673,
---R      - 4.8943271657719833E-10]
---R     ,
---R
---R     [0.35999999999999999, 1.0977154579999999, 1.0977154574988892,
---R      - 5.0111070848402051E-10]
---R     ,
---R    [0.37,1.100666108,1.1006661079520708,- 4.7929216151487708E-11],
---R    [0.38,1.1036304809999999,1.1036304809985678,- 1.4321877017664519E-12],
---R
---R     [0.39000000000000001, 1.1066086559999999, 1.1066086562850108,
---R      2.8501090376664706E-10]
---R     ,
---R
---R     [0.40000000000000002, 1.1096007139999999, 1.1096007139798676,
---R      - 2.0132340239342739E-11]
---R     ,
---R    [0.40999999999999998,1.112606735,1.1126067347771349,- 2.228650597402293E-10]
---R     ,
---R    [0.41999999999999998,1.1156268,1.1156267999000615,- 9.9938501918472866E-11],
---R    [0.42999999999999999,1.118660991,1.1186609911048895,1.0488943047448629E-10],
---R    [0.44,1.121709391,1.1217093906846374,- 3.1536262490305944E-10],
---R
---R     [0.45000000000000001, 1.124772082, 1.1247720814728976,
---R      - 5.2710236175812497E-10]
---R     ,
---R
---R     [0.46000000000000002, 1.1278491470000001, 1.1278491468476701,
---R      - 1.52329926450534E-10]
---R     ,
---R
---R     [0.46999999999999997, 1.1309406710000001, 1.1309406707352239,
---R      - 2.6477620096443388E-10]
---R     ,
---R
---R     [0.47999999999999998, 1.1340467380000001, 1.134046737613986,
---R      - 3.8601410956573545E-10]
---R     ,
---R    [0.48999999999999999,1.137167432,1.1371674325184589,5.1845883142220828E-10],
---R    [0.5,1.140302841,1.1403028410431715,4.3171466401759062E-11]]
---R                                                  Type: List List DoubleFloat
+--R   [[0,1,1,0],
+--R      2882303761517117  282180230842153 4514883693424401         50047
+--R    [------------------,---------------,----------------,- ----------------],
+--R     288230376151711744 281474976710656 4503599627370496   4503599627370496
+--R      2882303761517117  1131554520700159 4526218082003301        797335
+--R    [------------------,----------------,----------------,- ----------------],
+--R     144115188075855872 1125899906842624 4503599627370496   4503599627370496
+--R      1080863910568919 4537603079075837 567200384662475        1776037
+--R    [-----------------,----------------,---------------,- ----------------],
+--R     36028797018963968 4503599627370496 562949953421312   4503599627370496
+--R      2882303761517117 1137259741506707 4549038965333451        693377
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     72057594037927936 1125899906842624 4503599627370496   4503599627370496
+--R      7205759403792793  4560526036387583 570065754245395        2424423
+--R    [------------------,----------------,---------------,- ----------------],
+--R     144115188075855872 4503599627370496 562949953421312   4503599627370496
+--R      1080863910568919 285754035867805 4572064572900067        984813
+--R    [-----------------,---------------,----------------,- ----------------],
+--R     18014398509481984 281474976710656 4503599627370496   4503599627370496
+--R      5044031582654955 4583654875756295 4583654873720515        508945
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     72057594037927936 4503599627370496 4503599627370496   1125899906842624
+--R      2882303761517117 2297648615116101 71801519216859        176613
+--R    [-----------------,----------------,--------------,- ----------------],
+--R     36028797018963968 2251799813685248 70368744177664   2251799813685248
+--R      3242591731706757 4606991939053777 4606991936721311        1166233
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     36028797018963968 4503599627370496 4503599627370496   2251799813685248
+--R      7205759403792793 4618739290451397 1154684822874465      1046463
+--R    [-----------------,----------------,----------------,----------------],
+--R     72057594037927936 4503599627370496 1125899906842624 4503599627370496
+--R      990791918021509 4630539595173435 4630539593376855        449145
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 4503599627370496 4503599627370496   1125899906842624
+--R     1080863910568919 1160598286488467 580299142932225        624017
+--R    [----------------,----------------,---------------,- ----------------],
+--R     9007199254740992 1125899906842624 562949953421312   1125899906842624
+--R      4683743612465315 4654300244533871 4654300244784955       62771
+--R    [-----------------,----------------,----------------,----------------],
+--R     36028797018963968 4503599627370496 4503599627370496 1125899906842624
+--R      5044031582654955 583282650207727 2333130601180511      349603
+--R    [-----------------,---------------,----------------,----------------],
+--R     36028797018963968 562949953421312 2251799813685248 2251799813685248
+--R      5404319552844595 4678276323582481 4678276323160787        210847
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     36028797018963968 4503599627370496 4503599627370496   2251799813685248
+--R      2882303761517117 2345172958270319 1172586479036247        197825
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     18014398509481984 2251799813685248 1125899906842624   2251799813685248
+--R      3062447746611937 4702470291284663 2351235146137109      989555
+--R    [-----------------,----------------,----------------,----------------],
+--R     18014398509481984 4503599627370496 2251799813685248 4503599627370496
+--R      3242591731706757 4714649763066529 4714649764522945      45513
+--R    [-----------------,----------------,----------------,---------------],
+--R     18014398509481984 4503599627370496 4503599627370496 140737488355328
+--R      6845471433603153 2363442323569105 4726884647893627      755417
+--R    [-----------------,----------------,----------------,----------------],
+--R     36028797018963968 2251799813685248 4503599627370496 4503599627370496
+--R      7205759403792793 74049613417995 4739175259430985      679305
+--R    [-----------------,--------------,----------------,----------------],
+--R     36028797018963968 70368744177664 4503599627370496 4503599627370496
+--R      7566047373982433 4751521917662513 4751521918236295      286891
+--R    [-----------------,----------------,----------------,----------------],
+--R     36028797018963968 4503599627370496 4503599627370496 2251799813685248
+--R      990791918021509 2381962474064941 4763924945481855        2648027
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 2251799813685248 4503599627370496   4503599627370496
+--R      517913957147607 74631010396965 2388192332212761        490119
+--R    [----------------,--------------,----------------,- ----------------],
+--R     2251799813685248 70368744177664 2251799813685248   2251799813685248
+--R     1080863910568919 4788901398252921 299306337526587      2172471
+--R    [----------------,----------------,---------------,----------------],
+--R     4503599627370496 4503599627370496 281474976710656 4503599627370496
+--R     1 4801475479937737 1200368870238635      1016803
+--R    [-,----------------,----------------,----------------],
+--R     4 4503599627370496 1125899906842624 4503599627370496
+--R      4683743612465315 4814107234719381 1203526808903981      896543
+--R    [-----------------,----------------,----------------,----------------],
+--R     18014398509481984 4503599627370496 1125899906842624 4503599627370496
+--R      4863887597560135 4826796995864225 4826796996157345      1145
+--R    [-----------------,----------------,----------------,--------------],
+--R     18014398509481984 4503599627370496 4503599627370496 17592186044416
+--R      5044031582654955 4839545096638643 1209886274121643        152071
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     18014398509481984 4503599627370496 1125899906842624   4503599627370496
+--R      5224175567749775 4852351874812605 4852351872686531        1063037
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     18014398509481984 4503599627370496 4503599627370496   2251799813685248
+--R      5404319552844595 4865217663652485 4865217663030645        38865
+--R    [-----------------,----------------,----------------,- ---------------],
+--R     18014398509481984 4503599627370496 4503599627370496   281474976710656
+--R      5584463537939415 2439071404967727 4878142807998271        1937183
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     18014398509481984 2251799813685248 4503599627370496   4503599627370496
+--R     2882303761517117 4891127651431483 4891127650290241        570621
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 4503599627370496 4503599627370496   2251799813685248
+--R     2972375754064527 4904172534917745 2452086267422267         73211
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 4503599627370496 2251799813685248   4503599627370496
+--R     3062447746611937 4917277807171409 4917277808852083      840337
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 4503599627370496 4503599627370496 2251799813685248
+--R     3152519739159347 308152738998553 154076369430395        137763
+--R    [----------------,---------------,---------------,- ---------------],
+--R     9007199254740992 281474976710656 140737488355328   281474976710656
+--R     3242591731706757 4943670927607633 4943670925350831        1128401
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 4503599627370496 4503599627370496   2251799813685248
+--R     3332663724254167 2478479736924067 4956959473632277        215857
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 2251799813685248 4503599627370496   4503599627370496
+--R      6845471433603153 4970309822986321 4970309822979869         1613
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     18014398509481984 4503599627370496 4503599627370496   1125899906842624
+--R      7025615418697973 4983722330806565 4983722332090139      641787
+--R    [-----------------,----------------,----------------,----------------],
+--R     18014398509481984 4503599627370496 4503599627370496 2251799813685248
+--R      7205759403792793 1249299340525109 624649670251221         22667
+--R    [-----------------,----------------,---------------,- ----------------],
+--R     18014398509481984 1125899906842624 562949953421312   1125899906842624
+--R      7385903388887613 78292738705561 313170954759513        62731
+--R    [-----------------,--------------,---------------,- ---------------],
+--R     18014398509481984 70368744177664 281474976710656   281474976710656
+--R      7566047373982433 2512168220382269 5024336440314455        450083
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     18014398509481984 2251799813685248 4503599627370496   4503599627370496
+--R      7746191359077253 5038001222221509 5038001222693891      236191
+--R    [-----------------,----------------,----------------,----------------],
+--R     18014398509481984 4503599627370496 4503599627370496 2251799813685248
+--R      990791918021509 5051729995325585 5051729993905319        710133
+--R    [----------------,----------------,----------------,- ----------------],
+--R     2251799813685248 4503599627370496 4503599627370496   2251799813685248
+--R     2026619832316723 158297597792873 2532761563499039        1186929
+--R    [----------------,---------------,----------------,- ----------------],
+--R     4503599627370496 140737488355328 2251799813685248   2251799813685248
+--R      517913957147607 5079380998159331 317461312342081        686035
+--R    [----------------,----------------,---------------,- ----------------],
+--R     1125899906842624 4503599627370496 281474976710656   4503599627370496
+--R     2116691824864133 2546651992246869 2546651991650645        2329
+--R    [----------------,----------------,----------------,- -------------],
+--R     4503599627370496 2251799813685248 2251799813685248   8796093022208
+--R     1080863910568919 2553646233338763 5107292464939073        1738453
+--R    [----------------,----------------,----------------,- ----------------],
+--R     2251799813685248 2251799813685248 4503599627370496   4503599627370496
+--R     2206763817411543 5121346823013063 640168353168499      2334929
+--R    [----------------,----------------,---------------,----------------],
+--R     4503599627370496 4503599627370496 562949953421312 4503599627370496
+--R     1 5135467449817117 641933431251443      194427
+--R    [-,----------------,---------------,----------------]]
+--R     2 4503599627370496 562949953421312 4503599627370496
+--R                                             Type: List List Fraction Integer
 --E 15
 
 \end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+
+   [[0.,                     1.,  
+                             1.,  
+                             0.],  
+    [1.0E-2,                 1.002505566,  
+                             1.002505565988876,  
+                            -1.1123990617534218E-11],  
+    [2.0E-2,                 1.0050223060000001,  
+                             1.0050223058229502,  
+                            -1.7704993027223281E-10],  
+    [2.9999999999999999E-2,  1.007550283,   
+                             1.0075502826056368,  
+                            -3.9436320875552155E-10]
+    [4.0000000000000001E-2,  1.0100895599999999, 
+                             1.0100895598460362,  
+                            -1.5396373065357238E-10]
+    [5.0000000000000003E-2,  1.012640202, 
+                             1.0126402014616676,  
+                            -5.3833248969681335E-10]
+    [5.9999999999999998E-2,  1.015202272,
+                             1.0152022717813329,  
+                            -2.1866708443951666E-10]
+    [7.0000000000000007E-2,  1.017775836,
+                             1.0177758355479642,  
+                            -4.5203574217111964E-10]
+    [8.0000000000000002E-2,  1.0203609579999999, 
+                             1.0203609579215664,  
+                            -7.8433481931483584E-11]
+    [8.9999999999999997E-2,  1.0229577050000001, 
+                             1.0229577044820872,  
+                            -5.1791282373869763E-10]
+    [0.10000000000000001,    1.0255661410000001,
+                             1.0255661412323602,  
+                             2.3236013113603349E-10]
+    [0.11,                   1.028186335,
+                             1.0281863346010778,
+                            -3.989222285838423E-10],  
+    [0.12,                   1.030818352, 
+                             1.0308183514457605,
+                            -5.5423954314903767E-10],  
+    [0.13,                   1.033462259, 
+                             1.0334622590557541,
+                             5.5754068029045811E-11],  
+    [0.14000000000000001,    1.036118125,  
+                             1.0361181251552536,  
+                             1.5525358776358189E-10],  
+    [0.14999999999999999,    1.0387860179999999,
+                             1.0387860179063644,  
+                            -9.3635543763070928E-11]
+    [0.16,                   1.0414660060000001,
+                             1.0414660059121499,
+                            -8.7850171581749237E-11],  
+    [0.17000000000000001,    1.0441581579999999,
+                             1.0441581582197257,  
+                             2.1972579311579921E-10]
+    [0.17999999999999999,    1.0468625439999999,
+                             1.0468625443233892,  
+                             3.233893153264944E-10]
+    [0.19,                   1.0495792340000001,
+                             1.0495792341677359, 
+                             1.6773582522944253E-10],  
+    [0.20000000000000001,    1.052308298, 
+                             1.0523082981508358,
+                             1.5083578830399347E-10],  
+    [0.20999999999999999,    1.0550498070000001,
+                             1.055049807127405,  
+                             1.2740497545848939E-10]
+    [0.22,                   1.0578038329999999, 
+                             1.0578038324120198, 
+                            -5.8798010904581588E-10],  
+    [0.23000000000000001,    1.0605704460000001, 
+                             1.0605704457823433,  
+                            -2.1765678148710776E-10]
+    [0.23999999999999999,    1.0633497190000001,
+                             1.0633497194823853,  
+                             4.8238524286148277E-10]
+    [0.25,                   1.0661417259999999,
+                             1.0661417262257755,
+                             2.2577562042158661E-10],  
+    [0.26000000000000001,    1.0689465389999999, 
+                             1.0689465391990731,  
+                             1.9907320236711712E-10]
+    [0.27000000000000002,    1.071764232, 
+                             1.0717642320650853,
+                             6.5085270506415327E-11],  
+    [0.28000000000000003,    1.0745948789999999, 
+                             1.0745948789662336,  
+                            -3.3766323070949511E-11]
+    [0.28999999999999998,    1.0774385550000001, 
+                             1.0774385545279166,  
+                            -4.7208348341598594E-10]
+    [0.29999999999999999,    1.0802953340000001,
+                             1.0802953338619241,  
+                            -1.3807599508197654E-10]
+    [0.31,                   1.083165293, 
+                             1.0831652925698594,
+                            -4.3014058981327707E-10],  
+    [0.32000000000000001,    1.0860485070000001, 
+                             1.0860485067465939,  
+                            -2.5340618492464273E-10]
+    [0.33000000000000002,    1.088945053,
+                             1.0889450529837443,  
+                            -1.6255663481956617E-11]
+    [0.34000000000000002,    1.091855008, 
+                             1.0918550083731842,
+                             3.7318415024856222E-10],  
+    [0.34999999999999998,    1.094778451,
+                             1.0947784505105673,  
+                            -4.8943271657719833E-10]
+    [0.35999999999999999,    1.0977154579999999,
+                             1.0977154574988892,  
+                            -5.0111070848402051E-10]
+    [0.37,                   1.100666108,
+                             1.1006661079520708,
+                            -4.7929216151487708E-11],  
+    [0.38,                   1.1036304809999999,
+                             1.1036304809985678, 
+                            -1.4321877017664519E-12],  
+    [0.39000000000000001,    1.1066086559999999, 
+                             1.1066086562850108,  
+                             2.8501090376664706E-10]
+    [0.40000000000000002,    1.1096007139999999,
+                             1.1096007139798676,  
+                            -2.0132340239342739E-11]
+    [0.40999999999999998,    1.112606735,  
+                             1.1126067347771349,
+                            -2.228650597402293E-10]
+    [0.41999999999999998,    1.1156268,
+                             1.1156267999000615,
+                            -9.9938501918472866E-11],  
+    [0.42999999999999999,    1.118660991,
+                             1.1186609911048895,
+                             1.0488943047448629E-10],  
+    [0.44,                   1.121709391, 
+                             1.1217093906846374,
+                            -3.1536262490305944E-10],  
+    [0.45000000000000001,    1.124772082,
+                             1.1247720814728976,  
+                            -5.2710236175812497E-10]
+    [0.46000000000000002,    1.1278491470000001, 
+                             1.1278491468476701,  
+                            -1.52329926450534E-10]
+    [0.46999999999999997,    1.1309406710000001, 
+                             1.1309406707352239,  
+                            -2.6477620096443388E-10]
+    [0.47999999999999998,    1.1340467380000001,
+                             1.134046737613986,  
+                            -3.8601410956573545E-10]
+    [0.48999999999999999,    1.137167432, 
+                             1.1371674325184589, 
+                             5.1845883142220828E-10],  
+    [0.5,                    1.140302841,
+                             1.1403028410431715,
+                             4.3171466401759062E-11]]
+
+\end{verbatim}
+
 In the following table we show values returned by Ei(x).
 Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
 Dover Publications, Inc. New York 1965. pp 239-241
 
 \begin{chunk}{*}
+
 --S 16 of 20
+t8:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[0.50,0.454219905,Ei(0.50),Ei(0.50)-0.454219905],_
  [0.51,0.487032167,Ei(0.51),Ei(0.51)-0.487032167],_
  [0.52,0.519530633,Ei(0.52),Ei(0.52)-0.519530633],_
@@ -1461,439 +2629,946 @@ Dover Publications, Inc. New York 1965. pp 239-241
  [1.97,4.844221501,Ei(1.97),Ei(1.97)-4.844221501],_
  [1.98,4.880710791,Ei(1.98),Ei(1.98)-4.880710791],_
  [1.99,4.917381131,Ei(1.99),Ei(1.99)-4.917381131],_
- [2.00,4.954234356,Ei(2.00),Ei(2.00)-4.954234356]]
+ [2.00,4.954234356,Ei(2.00),Ei(2.00)-4.954234356]]]
 --R 
 --R
 --R   (17)
---R   [[0.5,0.45421990499999998,0.45421990486317332,- 1.3682666111236585E-10],
---R
---R     [0.51000000000000001, 0.48703216700000002, 0.48703216680456007,
---R      - 1.9543994200788006E-10]
---R     ,
---R
---R     [0.52000000000000002, 0.51953063300000002, 0.51953063245569719,
---R      - 5.443028250340376E-10]
---R     ,
---R
---R     [0.53000000000000003, 0.55173044500000001, 0.55173044523266401,
---R      2.3266399917787339E-10]
---R     ,
---R
---R     [0.54000000000000004, 0.58364593099999995, 0.58364593072977955,
---R      - 2.7022040161028826E-10]
---R     ,
---R
---R     [0.55000000000000004, 0.61529065699999996, 0.61529065706218644,
---R      6.2186478189119043E-11]
---R     ,
---R
---R     [0.56000000000000005, 0.64667748999999997, 0.64667748977430584,
---R      - 2.2569413005157912E-10]
---R     ,
---R
---R     [0.56999999999999995, 0.67781864199999997, 0.67781864189137597,
---R      - 1.0862399868472039E-10]
---R     ,
---R
---R     [0.57999999999999996, 0.70872572, 0.70872571962101083,
---R      - 3.7898917337741977E-10]
---R     ,
---R
---R     [0.58999999999999997, 0.73940976400000002, 0.73940976415103654,
---R      1.510365166268457E-10]
---R     ,
---R
---R     [0.59999999999999998, 0.76988129000000005, 0.76988128993735938,
---R      - 6.2640670428493195E-11]
---R     ,
---R
---R     [0.60999999999999999, 0.80015031999999997, 0.80015031983004981,
---R      - 1.699501650520574E-10]
---R     ,
---R    [0.62,0.83022641699999999,0.83022641734618519,3.4618519162421535E-10],
---R    [0.63,0.86011871600000001,0.86011871636343917,3.6343916764991491E-10],
---R
---R     [0.64000000000000001, 0.88983594899999996, 0.88983594847818637,
---R      - 5.2181359233571811E-10]
---R     ,
---R
---R     [0.65000000000000002, 0.91938646800000001, 0.91938646824544334,
---R      2.4544333232512372E-10]
---R     ,
---R
---R     [0.66000000000000003, 0.94877827699999995, 0.94877827649472835,
---R      - 5.0527160233571067E-10]
---R     ,
---R
---R     [0.67000000000000004, 0.97801904200000001, 0.97801904189549682,
---R      - 1.045031838842192E-10]
---R     ,
---R
---R     [0.68000000000000005, 1.0071161209999999, 1.0071161209277915,
---R      - 7.2208461432410331E-11]
---R     ,
---R
---R     [0.68999999999999995, 1.0360765759999999, 1.0360765763978435,
---R      3.978435358931165E-10]
---R     ,
---R    [0.69999999999999996,1.064907195,1.0649071946242905,- 3.757094635403746E-10]
---R     ,
---R    [0.70999999999999996,1.093614501,1.0936145014081782,4.0817815794014223E-10],
---R
---R     [0.71999999999999997, 1.1222047770000001, 1.1222047768888612,
---R      - 1.111388758801013E-10]
---R     ,
---R    [0.72999999999999998,1.150684069,1.1506840693780345,3.780344925985446E-10],
---R
---R     [0.73999999999999999, 1.1790582080000001, 1.1790582082553465,
---R      2.5534641068247765E-10]
---R     ,
---R    [0.75,1.2073328160000001,1.2073328160012218,1.2216894162975223E-12],
---R
---R     [0.76000000000000001, 1.2355133190000001, 1.2355133194354742,
---R      4.3547410122357633E-10]
---R     ,
---R
---R     [0.77000000000000002, 1.2636049600000001, 1.2636049602240513,
---R      2.2405122201973882E-10]
---R     ,
---R
---R     [0.78000000000000003, 1.291612805, 1.2916128047105979,
---R      - 2.8940205787364448E-10]
---R     ,
---R    [0.79000000000000004,1.319541753,1.3195417531244753,1.2447531894110853E-10],
---R
---R     [0.80000000000000004, 1.3473965480000001, 1.3473965482123258,
---R      2.1232571256746269E-10]
---R     ,
---R
---R     [0.81000000000000005, 1.3751817829999999, 1.3751817833361941,
---R      3.361941836033111E-10]
---R     ,
---R    [0.81999999999999995,1.40290191,1.4029019100774811,7.7481132620960125E-11],
---R    [0.82999999999999996,1.430561245,1.4305612453827297,3.8272962576968439E-10],
---R    [0.83999999999999997,1.458163978,1.4581639782841678,2.8416780040174672E-10],
---R
---R     [0.84999999999999998, 1.4857141760000001, 1.4857141762252541,
---R      2.2525403764461771E-10]
---R     ,
---R
---R     [0.85999999999999999, 1.5132157909999999, 1.5132157910189581,
---R      1.8958168368499173E-11]
---R     ,
---R    [0.87,1.5406726639999999,1.5406726644642923,4.6429238231837644E-10],
---R    [0.88,1.5680885339999999,1.5680885336445423,- 3.5545766330358219E-10],
---R
---R     [0.89000000000000001, 1.5954670360000001, 1.5954670359288246,
---R      - 7.1175509930299086E-11]
---R     ,
---R
---R     [0.90000000000000002, 1.622811714, 1.6228117136968674,
---R      - 3.0313263010839364E-10]
---R     ,
---R
---R     [0.91000000000000003, 1.650126019, 1.6501260188054063,
---R      - 1.9459367450735954E-10]
---R     ,
---R
---R     [0.92000000000000004, 1.6774133170000001, 1.677413316813162,
---R      - 1.8683810054653804E-10]
---R     ,
---R
---R     [0.93000000000000005, 1.7046768910000001, 1.7046768909800791,
---R      - 1.9920953775454109E-11]
---R     ,
---R
---R     [0.93999999999999995, 1.7319199460000001, 1.7319199460553549,
---R      5.5354831829390605E-11]
---R     ,
---R
---R     [0.94999999999999996, 1.759145612, 1.7591456118676905,
---R      - 1.3230949669207348E-10]
---R     ,
---R
---R     [0.95999999999999996, 1.786356947, 1.7863569467301943,
---R      - 2.6980573331059077E-10]
---R     ,
---R
---R     [0.96999999999999997, 1.8135569410000001, 1.8135569406715355,
---R      - 3.2846458886126584E-10]
---R     ,
---R
---R     [0.97999999999999998, 1.8407485189999999, 1.8407485185040211,
---R      - 4.9597881357499318E-10]
---R     ,
---R
---R     [0.98999999999999999, 1.8679345430000001, 1.8679345427385856,
---R      - 2.6141444564586891E-10]
---R     ,
---R    [1.,1.895117816,1.8951178163559361,3.5593616942719564E-10],
---R    [1.01,1.922301085,1.9223010854424856,4.4248560371329404E-10],
---R    [1.02,1.9494870419999999,1.9494870416990668,- 3.0093305625200628E-10],
---R    [1.03,1.976678325,1.976678324829928,- 1.7007195651785878E-10],
---R    [1.04,2.003877525,2.0038775248189595,- 1.8104051591194548E-10],
---R    [1.05,2.031087184,2.0310871840996643,9.9664276831390453E-11],
---R    [1.0600000000000001,2.0583098,2.0583097996249284,- 3.7507152939042498E-10],
---R
---R     [1.0700000000000001, 2.0855478249999999, 2.085547824842283,
---R      - 1.5771695061062019E-10]
---R     ,
---R
---R     [1.0800000000000001, 2.1128036720000001, 2.1128036715799325,
---R      - 4.2006753631085303E-10]
---R     ,
---R
---R     [1.0900000000000001, 2.1400797119999999, 2.1400797118485424,
---R      - 1.5145751319778356E-10]
---R     ,
---R
---R     [1.1000000000000001, 2.1673782799999999, 2.1673782795634038,
---R      - 4.3659609261226251E-10]
---R     ,
---R
---R     [1.1100000000000001, 2.1947016719999999, 2.1947016721913277,
---R      1.9132784245812218E-10]
---R     ,
---R
---R     [1.1200000000000001, 2.2220521519999998, 2.2220521523263717,
---R      3.2637181845984742E-10]
---R     ,
---R
---R     [1.1299999999999999, 2.2494319489999999, 2.2494319491981756,
---R      1.9817569807401014E-10]
---R     ,
---R
---R     [1.1399999999999999, 2.2768432600000001, 2.2768432601165496,
---R      1.1654943676830953E-10]
---R     ,
---R
---R     [1.1499999999999999, 2.3042882520000001, 2.304288251855628,
---R      - 1.4437206985462581E-10]
---R     ,
---R
---R     [1.1599999999999999, 2.3317690619999998, 2.3317690619808027,
---R      - 1.9197088363398507E-11]
---R     ,
---R
---R     [1.1699999999999999, 2.3592878000000002, 2.3592878001213737,
---R      1.2137357785491076E-10]
---R     ,
---R
---R     [1.1799999999999999, 2.3868465489999999, 2.3868465491917359,
---R      1.9173596044197438E-10]
---R     ,
---R
---R     [1.1899999999999999, 2.4144473670000002, 2.4144473665637345,
---R      - 4.3626569024013406E-10]
---R     ,
---R    [1.2,2.4420922850000002,2.4420922851926514,1.9265122830347536E-10],
---R    [1.21,2.4697833149999999,2.4697833146991774,- 3.0082247803875362E-10],
---R    [1.22,2.4975224420000002,2.497522442409561,4.095608296950104E-10],
---R    [1.23,2.5253116339999999,2.5253116343560089,3.5600900005761105E-10],
---R    [1.24,2.5531528360000002,2.5531528362393039,2.3930368797664414E-10],
---R    [1.25,2.5810479740000001,2.5810479743554762,3.5547609300579097E-10],
---R    [1.26,2.6089989560000002,2.6089989564882825,4.8828230347908175E-10],
---R    [1.27,2.6370076729999998,2.6370076727691485,- 2.308513380455679E-10],
---R    [1.28,2.6650759970000002,2.6650759965061086,- 4.9389159428869789E-10],
---R    [1.29,2.693205785,2.6932057849832494,- 1.6750600906334512E-11],
---R    [1.3,2.7213988800000002,2.7213988802320226,2.3202240129194251E-10],
---R
---R     [1.3100000000000001, 2.7496571099999998, 2.7496571097757787,
---R      - 2.2422108614250646E-10]
---R     ,
---R
---R     [1.3200000000000001, 2.7779822869999999, 2.777982287348725,
---R      3.4872504883765032E-10]
---R     ,
---R
---R     [1.3300000000000001, 2.8063762140000001, 2.8063762135905539,
---R      - 4.0944625467886908E-10]
---R     ,
---R
---R     [1.3400000000000001, 2.8348406769999999, 2.8348406767178056,
---R      - 2.8219426795317304E-10]
---R     ,
---R    [1.3500000000000001,2.863377453,2.8633774531730753,1.7307533184407475E-10],
---R
---R     [1.3600000000000001, 2.8919883080000002, 2.8919883082530298,
---R      2.5302959727468988E-10]
---R     ,
---R
---R     [1.3700000000000001, 2.9206749969999999, 2.9206749967162473,
---R      - 2.8375257699053691E-10]
---R     ,
---R
---R     [1.3799999999999999, 2.9494392629999999, 2.9494392633717355,
---R      3.7173553124603131E-10]
---R     ,
---R
---R     [1.3899999999999999, 2.9782828440000002, 2.9782828436490232,
---R      - 3.5097702522079999E-10]
---R     ,
---R
---R     [1.3999999999999999, 3.0072074639999999, 3.0072074641506457,
---R      1.5064571812217764E-10]
---R     ,
---R
---R     [1.4099999999999999, 3.0362148430000002, 3.0362148431877847,
---R      1.8778445465272853E-10]
---R     ,
---R    [1.4199999999999999,3.065306691,3.065306691299837,2.9983704408209633E-10],
---R
---R     [1.4299999999999999, 3.0944847119999999, 3.0944847117585681,
---R      - 2.4143176347024564E-10]
---R     ,
---R
---R     [1.4399999999999999, 3.1237506009999998, 3.1237506010575933,
---R      5.7593485536244771E-11]
---R     ,
---R    [1.45,3.1531060489999998,3.1531060493877443,3.8774450317191622E-10],
---R    [1.46,3.1825527409999999,3.1825527410990038,9.9003916176343409E-11],
---R    [1.47,3.2120923549999998,3.2120923551495331,1.4953327465150323E-10],
---R    [1.48,3.2417265660000001,3.2417265655423857,- 4.5761439082525612E-10],
---R    [1.49,3.2714570420000002,3.2714570417503985,- 2.4960167266385724E-10],
---R    [1.5,3.3012854489999999,3.3012854491297974,1.297975060765566E-10],
---R    [1.51,3.3312134489999998,3.3312134493229739,3.2297409191528459E-10],
---R    [1.52,3.3612427010000001,3.3612427006508958,- 3.4910430102286227E-10],
---R    [1.53,3.3913748579999998,3.3913748584955847,4.9558490644585618E-10],
---R    [1.54,3.4216115760000001,3.4216115756731122,- 3.2688785012169319E-10],
---R    [1.55,3.4519545030000001,3.4519545027974381,- 2.0256196719969921E-10],
---R
---R     [1.5600000000000001, 3.4824052889999999, 3.4824052886355643,
---R      - 3.6443559281451599E-10]
---R     ,
---R
---R     [1.5700000000000001, 3.5129655799999999, 3.5129655804542947,
---R      4.5429482398162691E-10]
---R     ,
---R
---R     [1.5800000000000001, 3.5436370240000001, 3.5436370243589819,
---R      3.5898173322834737E-10]
---R     ,
---R
---R     [1.5900000000000001, 3.5744212659999999, 3.5744212656246064,
---R      - 3.7539349406756628E-10]
---R     ,
---R
---R     [1.6000000000000001, 3.6053199490000001, 3.6053199490194707,
---R      1.9470647316666145E-11]
---R     ,
---R
---R     [1.6100000000000001, 3.6363347190000002, 3.6363347191218383,
---R      1.2183809516841393E-10]
---R     ,
---R
---R     [1.6200000000000001, 3.6674672209999999, 3.6674672206298222,
---R      - 3.7017766629787729E-10]
---R     ,
---R
---R     [1.6299999999999999, 3.6987190989999998, 3.6987190986647667,
---R      - 3.3523317455319557E-10]
---R     ,
---R
---R     [1.6399999999999999, 3.7300919989999999, 3.7300919990684158,
---R      6.8415939580290797E-11]
---R     ,
---R    [1.6499999999999999,3.761587569,3.7615875686941349,- 3.0586511101660108E-10]
---R     ,
---R
---R     [1.6599999999999999, 3.7932074560000002, 3.7932074556923925,
---R      - 3.0760771707605272E-10]
---R     ,
---R
---R     [1.6699999999999999, 3.8249533100000002, 3.824953309790788,
---R      - 2.092122031172039E-10]
---R     ,
---R
---R     [1.6799999999999999, 3.8568267829999998, 3.8568267825688243,
---R      - 4.3117553971683265E-10]
---R     ,
---R    [1.6899999999999999,3.888829528,3.8888295277276339,- 2.723661296499813E-10],
---R    [1.7,3.9209632010000002,3.9209632013549038,3.5490366201429424E-10],
---R    [1.71,3.9532294619999999,3.953229462185158,1.8515811106567526E-10],
---R    [1.72,3.9856299719999999,3.985629971855627,- 1.4437295803304551E-10],
---R    [1.73,4.0181663949999997,4.0181663951578672,1.5786749685275936E-10],
---R    [1.74,4.0508404000000002,4.0508404002853169,2.8531665918762883E-10],
---R    [1.75,4.0836536590000003,4.0836536590769557,7.6955330996497651E-11],
---R    [1.76,4.116607847,4.1166078472572494,2.5724933294668517E-10],
---R    [1.77,4.1497046449999999,4.1497046446724992,- 3.2750069323128628E-10],
---R    [1.78,4.1829457359999997,4.1829457355238073,- 4.7619241883012364E-10],
---R    [1.79,4.2163328089999998,4.2163328085967509,- 4.0324898975541146E-10],
---R    [1.8,4.249867557,4.2498675574879341,4.879341375385593E-10],
---R
---R     [1.8100000000000001, 4.2835516809999996, 4.2835516808285554,
---R      - 1.7144419217629547E-10]
---R     ,
---R
---R     [1.8200000000000001, 4.3173868830000002, 4.3173868825051116,
---R      - 4.9488857456481128E-10]
---R     ,
---R
---R     [1.8300000000000001, 4.3513748720000001, 4.3513748718773684,
---R      - 1.2263168258641599E-10]
---R     ,
---R    [1.8400000000000001,4.385517364,4.3855173639937215,- 6.2785332488601853E-12]
---R     ,
---R
---R     [1.8500000000000001, 4.4198160800000004, 4.4198160798040753,
---R      - 1.9592505395849003E-10]
---R     ,
---R    [1.8600000000000001,4.454272746,4.4542727463703349,3.7033487387816422E-10],
---R
---R     [1.8700000000000001, 4.4888890970000004, 4.4888890970746314,
---R      7.4630968072142423E-11]
---R     ,
---R
---R     [1.8799999999999999, 4.5236668719999997, 4.523666871825391,
---R      - 1.7460877188568702E-10]
---R     ,
---R
---R     [1.8899999999999999, 4.5586078170000004, 4.5586078172613478,
---R      2.6134738817518155E-10]
---R     ,
---R
---R     [1.8999999999999999, 4.5937136870000002, 4.5937136869535857,
---R      - 4.6414427856689144E-11]
---R     ,
---R
---R     [1.9099999999999999, 4.6289862419999999, 4.6289862416057304,
---R      - 3.9426950593224319E-10]
---R     ,
---R
---R     [1.9199999999999999, 4.6644272490000001, 4.6644272492523706,
---R      2.5237056888727238E-10]
---R     ,
---R
---R     [1.9299999999999999, 4.7000384850000003, 4.7000384854557851,
---R      4.5578474328067387E-10]
---R     ,
---R
---R     [1.9399999999999999, 4.7358217339999999, 4.7358217335010897,
---R      - 4.9891024644921345E-10]
---R     ,
---R    [1.95,4.7717787850000004,4.7717787845898787,- 4.1012171436705103E-10],
---R    [1.96,4.8079114379999996,4.8079114380324146,3.241495960537577E-11],
---R    [1.97,4.8442215009999998,4.8442215014384944,4.3849457398437153E-10],
---R    [1.98,4.8807107910000003,4.8807107909070337,- 9.2966523368431808E-11],
---R    [1.99,4.917381131,4.9173811312144435,2.1444357400923764E-10],
---R    [2.,4.9542343559999997,4.9542343560018924,1.8927082123809669E-12]]
---R                               Type: List List OnePointCompletion DoubleFloat
+--R     1 1022812297451131  63925768571439        308107
+--R   [[-,----------------,---------------,- ----------------],
+--R     2 2251799813685248 140737488355328   2251799813685248
+--R     4593671619917905 2193397885818645  548349471234615        880185
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 4503599627370496 1125899906842624   4503599627370496
+--R     4683743612465315 4679515930372715 2339757962735033        4902649
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 9007199254740992 4503599627370496   9007199254740992
+--R     4773815605012725 4969546053021915 2484773027558781      2095647
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 9007199254740992 4503599627370496 9007199254740992
+--R     4863887597560135 1314253798683953 5257015192301879        2433933
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 2251799813685248 9007199254740992   9007199254740992
+--R     4953959590107545 5542045547179495 5542045547739617      280061
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 9007199254740992 9007199254740992 4503599627370496
+--R     5044031582654955 5824753005985775 2912376501976449        2032877
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 9007199254740992 4503599627370496   9007199254740992
+--R     5134103575202365 6105247567071951 6105247566093551        30575
+--R    [----------------,----------------,----------------,- ---------------],
+--R     9007199254740992 9007199254740992 9007199254740992   281474976710656
+--R     5224175567749775 1595908444249943 1595908443396535        26669
+--R    [----------------,----------------,----------------,- --------------],
+--R     9007199254740992 2251799813685248 2251799813685248   70368744177664
+--R     5314247560297185 1665002768812253 6660011076609427      1360415
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 2251799813685248 9007199254740992 9007199254740992
+--R     5404319552844595 6934474181527033 6934474180962815        282109
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 9007199254740992 9007199254740992   4503599627370496
+--R     5494391545392005 3603556682992383 7207113364453989        1530777
+--R    [----------------,----------------,----------------,- ----------------],
+--R     9007199254740992 4503599627370496 9007199254740992   9007199254740992
+--R     5584463537939415 1869503691117171 3739007383793421      1559079
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 2251799813685248 4503599627370496 4503599627370496
+--R      709316941310853 3873630328871989  968407582627193      1636783
+--R    [----------------,----------------,----------------,----------------],
+--R     1125899906842624 4503599627370496 1125899906842624 4503599627370496
+--R     2882303761517117 8014929696674543 8014929691974459        1175021
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 9007199254740992 9007199254740992   2251799813685248
+--R     1463669878895411 1035137138673569 4140548555799653      1105377
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248 1125899906842624 4503599627370496 4503599627370496
+--R     2972375754064527 4272917494754421 8545834984957751        4551091
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 4503599627370496 9007199254740992   9007199254740992
+--R     377176468792279 4404606193112449 4404606192641807        235321
+--R    [---------------,----------------,----------------,- ----------------],
+--R     562949953421312 4503599627370496 4503599627370496   2251799813685248
+--R     3062447746611937 4535647787254419 4535647786929219        20325
+--R    [----------------,----------------,----------------,- ---------------],
+--R     4503599627370496 4503599627370496 4503599627370496   281474976710656
+--R     1553741871442821 4666074081600899 2333037041696313      1791727
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248 4503599627370496 2251799813685248 4503599627370496
+--R     3152519739159347 299744727911635 2397957822447057        846023
+--R    [----------------,---------------,----------------,- ----------------],
+--R     4503599627370496 281474976710656 2251799813685248   2251799813685248
+--R      799388933858263 2462600929595285 2462600930514421      28723
+--R    [----------------,----------------,----------------,--------------],
+--R     1125899906842624 2251799813685248 2251799813685248 70368744177664
+--R     3242591731706757 2526980507765295 2526980507515033        125131
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 2251799813685248 2251799813685248   1125899906842624
+--R     1643813863990231 2591110172184783 5182220346072081      1702515
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248 2251799813685248 4503599627370496 4503599627370496
+--R     3332663724254167 1327501526549231 2655003053673451      574989
+--R    [----------------,----------------,----------------,----------------],
+--R     4503599627370496 1125899906842624 2251799813685248 2251799813685248
+--R     3 5437343620249771 5437343620255273       2751
+--R    [-,----------------,----------------,----------------],
+--R     4 4503599627370496 4503599627370496 2251799813685248
+--R     6845471433603153 1391064330764921 1391064331255221      122575
+--R    [----------------,----------------,----------------,---------------],
+--R     9007199254740992 1125899906842624 1125899906842624 281474976710656
+--R     6935543426150563 2845385413499755 2845385414004273      252259
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 2251799813685248 2251799813685248 1125899906842624
+--R     7025615418697973 5816906947304961 727113368250201        1303353
+--R    [----------------,----------------,---------------,- ----------------],
+--R     9007199254740992 4503599627370496 562949953421312   4503599627370496
+--R     7115687411245383 5942687747110611 5942687747671195      70073
+--R    [----------------,----------------,----------------,---------------],
+--R     9007199254740992 4503599627370496 4503599627370496 562949953421312
+--R     7205759403792793 1517033647873273 3034067296224661      478115
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 1125899906842624 2251799813685248 2251799813685248
+--R     7295831396340203 3096634082742747 6193268166999577      1514083
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 2251799813685248 4503599627370496 4503599627370496
+--R     7385903388887613 6318108519113357 1579527129865575      348943
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 4503599627370496 1125899906842624 4503599627370496
+--R     7475975381435023 201333596559771 1610668772909083      430915
+--R    [----------------,---------------,----------------,----------------],
+--R     9007199254740992 140737488355328 1125899906842624 1125899906842624
+--R     7566047373982433 820873343495735 6566986749245657      1279777
+--R    [----------------,---------------,----------------,----------------],
+--R     9007199254740992 562949953421312 4503599627370496 4503599627370496
+--R     7656119366529843 6691061809412663 1672765452606779      1014453
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 4503599627370496 1125899906842624 4503599627370496
+--R     7746191359077253 3407459036239375 3407459036282065       21345
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 2251799813685248 2251799813685248 1125899906842624
+--R     7836263351624663 6938572835490309 6938572837581295      1045493
+--R    [----------------,----------------,----------------,----------------],
+--R     9007199254740992 4503599627370496 4503599627370496 2251799813685248
+--R      990791918021509 7062042937406347 110344420871961        1600843
+--R    [----------------,----------------,---------------,- ----------------],
+--R     1125899906842624 4503599627370496  70368744177664   4503599627370496
+--R     4008203668359741 7185344748811509 7185344748490961         80137
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 4503599627370496 4503599627370496   1125899906842624
+--R     2026619832316723 7308494230462875 7308494229097687        341297
+--R    [----------------,----------------,----------------,- ----------------],
+--R     2251799813685248 4503599627370496 4503599627370496   1125899906842624
+--R     4098275660907151 928938365535345 3715753461703193        438187
+--R    [----------------,---------------,----------------,- ----------------],
+--R     4503599627370496 562949953421312 2251799813685248   2251799813685248
+--R     517913957147607 7554397989387507 472149874284129        841443
+--R    [---------------,----------------,---------------,- ----------------],
+--R     562949953421312 4503599627370496 281474976710656   4503599627370496
+--R     4188347653454561 7677182211094695 479823888187811         89719
+--R    [----------------,----------------,---------------,- ----------------],
+--R     4503599627370496 4503599627370496 281474976710656   4503599627370496
+--R     2116691824864133 7799874023441129 3899937011845213      249297
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248 4503599627370496 2251799813685248 4503599627370496
+--R     4278419646001971 7922487522693643 1980621880524443        595871
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 4503599627370496 1125899906842624   4503599627370496
+--R     1080863910568919 1005629560107487 8045036479644799        1215097
+--R    [----------------,----------------,----------------,- ----------------],
+--R     1125899906842624  562949953421312 4503599627370496   4503599627370496
+--R     4368491638549381 1020941795462847 8167534362223503        1479273
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496  562949953421312 4503599627370496   4503599627370496
+--R     2206763817411543 1036249293031399 8289994342017501        2233691
+--R    [----------------,----------------,----------------,- ----------------],
+--R     2251799813685248  562949953421312 4503599627370496   4503599627370496
+--R     4458563631096791 8412429311807277 8412429310629973        147163
+--R    [----------------,----------------,----------------,- ---------------],
+--R     4503599627370496 4503599627370496 4503599627370496   562949953421312
+--R       2133712972490197 4267425945781891      801497
+--R    [1,----------------,----------------,----------------],
+--R       1125899906842624 2251799813685248 2251799813685248
+--R     568579452955525 2164318612524975 8657274452092675      1992775
+--R    [---------------,----------------,----------------,----------------],
+--R     562949953421312 1125899906842624 4503599627370496 4503599627370496
+--R     4593671619917905 4389854557957405 4389854557279763        338821
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 2251799813685248 2251799813685248   1125899906842624
+--R     2319353808095805 1112770970987667 8902167767135397        765939
+--R    [----------------,----------------,----------------,- ----------------],
+--R     2251799813685248  562949953421312 4503599627370496   4503599627370496
+--R     4683743612465315 4512331037443055 1128082759258847        407667
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 2251799813685248  562949953421312   2251799813685248
+--R     1182194902184755 4573601742509695 2286800871367059      224423
+--R    [----------------,----------------,----------------,----------------],
+--R     1125899906842624 2251799813685248 1125899906842624 2251799813685248
+--R     4773815605012725 579362703018315 1158725405825483        211147
+--R    [----------------,---------------,----------------,- ---------------],
+--R     4503599627370496 281474976710656  562949953421312   562949953421312
+--R     2409425800643215 2348118101883337 2348118101705763        88787
+--R    [----------------,----------------,----------------,- ---------------],
+--R     2251799813685248 1125899906842624 1125899906842624   562949953421312
+--R     4863887597560135 4757610914963107 2378805457008599        945909
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 2251799813685248 1125899906842624   2251799813685248
+--R     306807724614615 4819031096753179 4819031096412125        170527
+--R    [---------------,----------------,----------------,- ----------------],
+--R     281474976710656 2251799813685248 2251799813685248   1125899906842624
+--R     4953959590107545 4880502007089453 4880502006106323        491565
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 2251799813685248 2251799813685248   1125899906842624
+--R     2499497793190625 2471014408052151 1235507204133783      215415
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248 1125899906842624  562949953421312 1125899906842624
+--R     5044031582654955 625452077734063 2501808311303713      367461
+--R    [----------------,---------------,----------------,----------------],
+--R     4503599627370496 281474976710656 1125899906842624 1125899906842624
+--R     1272266894732165 1266317610913961 5065270444102095      446251
+--R    [----------------,----------------,----------------,----------------],
+--R     1125899906842624  562949953421312 2251799813685248 2251799813685248
+--R     5134103575202365 320437201791157 2563497614460479      131223
+--R    [----------------,---------------,----------------,----------------],
+--R     4503599627370496 140737488355328 1125899906842624 1125899906842624
+--R     2589569785738035 5188795856530705 648599482025701        325097
+--R    [----------------,----------------,---------------,- ----------------],
+--R     2251799813685248 2251799813685248 281474976710656   2251799813685248
+--R     5224175567749775 5250677139368625 1312669284831349         43229
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 2251799813685248  562949953421312   2251799813685248
+--R     658651445502935 2656321914234939 1328160957185797      136655
+--R    [---------------,----------------,----------------,----------------],
+--R     562949953421312 1125899906842624  562949953421312 1125899906842624
+--R     5314247560297185 5374700614333477 1343675153691307      431751
+--R    [----------------,----------------,----------------,----------------],
+--R     4503599627370496 2251799813685248  562949953421312 2251799813685248
+--R     2679641778285445 5436852131163437 5436852130181055        491191
+--R    [----------------,----------------,----------------,- ----------------],
+--R     2251799813685248 2251799813685248 2251799813685248   1125899906842624
+--R     5404319552844595 5499102952365181 2749551476399497      433813
+--R    [----------------,----------------,----------------,----------------],
+--R     4503599627370496 2251799813685248 1125899906842624 2251799813685248
+--R     1362338887279575 2780728804279967 5561457607882541        677393
+--R    [----------------,----------------,----------------,- ----------------],
+--R     1125899906842624 1125899906842624 2251799813685248   2251799813685248
+--R     5494391545392005 5623920569570325 2811960285246287      922249
+--R    [----------------,----------------,----------------,----------------],
+--R     4503599627370496 2251799813685248 1125899906842624 2251799813685248
+--R     2769713770832855 5686496266938389 355406016733753      801659
+--R    [----------------,----------------,---------------,----------------],
+--R     2251799813685248 2251799813685248 140737488355328 2251799813685248
+--R     5584463537939415 2874594540207381 2874594540476813      33679
+--R    [----------------,----------------,----------------,---------------],
+--R     4503599627370496 1125899906842624 1125899906842624 140737488355328
+--R     5 2906001673482943 2906001673883173      200115
+--R    [-,----------------,----------------,---------------],
+--R     4 1125899906842624 1125899906842624 562949953421312
+--R     709316941310853 2937471681512903 5874943364125319      1099513
+--R    [---------------,----------------,----------------,----------------],
+--R     562949953421312 1125899906842624 2251799813685248 2251799813685248
+--R     5719571526760529 5938013386747969 742251673278517        519833
+--R    [----------------,----------------,---------------,- ----------------],
+--R     4503599627370496 2251799813685248 281474976710656   2251799813685248
+--R     2882303761517117 3000608816750813 750152204048685        556073
+--R    [----------------,----------------,---------------,- ----------------],
+--R     2251799813685248 1125899906842624 281474976710656   1125899906842624
+--R     5809643519307939 758070035609879 189517508901291         4715
+--R    [----------------,---------------,---------------,- ---------------],
+--R     4503599627370496 281474976710656  70368744177664   281474976710656
+--R     1463669878895411 3064022745473621 6128045491469711      522469
+--R    [----------------,----------------,----------------,----------------],
+--R     1125899906842624 1125899906842624 2251799813685248 2251799813685248
+--R     5899715511855349 6191677367996317 6191677367491413        63113
+--R    [----------------,----------------,----------------,- ---------------],
+--R     4503599627370496 2251799813685248 2251799813685248   281474976710656
+--R     2972375754064527 6255459996287519 6255459997072775      98157
+--R    [----------------,----------------,----------------,---------------],
+--R     2251799813685248 2251799813685248 2251799813685248 281474976710656
+--R     5989787504402759 6319397435815911 197481169840435        921991
+--R    [----------------,----------------,---------------,- ----------------],
+--R     4503599627370496 2251799813685248  70368744177664   2251799813685248
+--R     377176468792279 3191746854147981 6383493707660515        635447
+--R    [---------------,----------------,----------------,- ----------------],
+--R     281474976710656 1125899906842624 2251799813685248   2251799813685248
+--R     6079859496950169 6447752815175939 6447752815565667      12179
+--R    [----------------,----------------,----------------,--------------],
+--R     4503599627370496 2251799813685248 2251799813685248 70368744177664
+--R     3062447746611937 6512178733134315 3256089366852043      569771
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248 2251799813685248 1125899906842624 2251799813685248
+--R     6169931489497579 3288387707039881 6576775413440807        638955
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624 2251799813685248   2251799813685248
+--R     1553741871442821 6641546782899355 1660386695934107      837073
+--R    [----------------,----------------,----------------,----------------],
+--R     1125899906842624 2251799813685248  562949953421312 2251799813685248
+--R     6260003482044989 3353248376610585 6706496752430841        790329
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624 2251799813685248   2251799813685248
+--R     3152519739159347 6771629207148087 6771629207487311      42403
+--R    [----------------,----------------,----------------,---------------],
+--R     2251799813685248 2251799813685248 2251799813685248 281474976710656
+--R     6350075474592399 854618502221973 3418474009099319      211427
+--R    [----------------,---------------,----------------,----------------],
+--R     4503599627370496 281474976710656 1125899906842624 1125899906842624
+--R     799388933858263 862807129460243 6902457036357117      675173
+--R    [---------------,---------------,----------------,----------------],
+--R     562949953421312 281474976710656 2251799813685248 2251799813685248
+--R     6440147467139809 871020012241681 217755003043431        67957
+--R    [----------------,---------------,---------------,- ---------------],
+--R     4503599627370496 281474976710656  70368744177664   281474976710656
+--R     3242591731706757 7034061021330981 3517030510730335      129689
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248 2251799813685248 1125899906842624 2251799813685248
+--R     6530219459687219 1775040903417007 3550081807270575      436561
+--R    [----------------,----------------,----------------,----------------],
+--R     4503599627370496  562949953421312 1125899906842624 1125899906842624
+--R     1643813863990231 7166471669227275 1791617917362553      222937
+--R    [----------------,----------------,----------------,----------------],
+--R     1125899906842624 2251799813685248  562949953421312 2251799813685248
+--R     6620291452234629 7232988966528809 904123620858191      336719
+--R    [----------------,----------------,---------------,----------------],
+--R     4503599627370496 2251799813685248 281474976710656 2251799813685248
+--R     3332663724254167 3649859638668659 3649859638153431        128807
+--R    [----------------,----------------,----------------,- ---------------],
+--R     2251799813685248 1125899906842624 1125899906842624   281474976710656
+--R     6710363444782039 1841666589413723 3683333178546419        281027
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496  562949953421312 1125899906842624   1125899906842624
+--R     3 1858458489745005 929229244909037      73069
+--R    [-,----------------,---------------,---------------],
+--R     2  562949953421312 281474976710656 562949953421312
+--R     850054429666181 937653227975499 117206653508301      90909
+--R    [---------------,---------------,---------------,---------------],
+--R     562949953421312 281474976710656  35184372088832 281474976710656
+--R     6845471433603153 7568845687862699 946105710884573        786115
+--R    [----------------,----------------,---------------,- ----------------],
+--R     4503599627370496 2251799813685248 281474976710656   2251799813685248
+--R     3445253714938429 3818348636690617 954587159312149      557979
+--R    [----------------,----------------,---------------,----------------],
+--R     2251799813685248 1125899906842624 281474976710656 1125899906842624
+--R     6935543426150563 7704784309340087 3852392154301999        736089
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 2251799813685248 1125899906842624   2251799813685248
+--R     1745144855606067 971638813338169 7773110506249221        456131
+--R    [----------------,---------------,----------------,- ----------------],
+--R     1125899906842624 281474976710656 2251799813685248   2251799813685248
+--R     7025615418697973 3920839790473361 7841679580126083        820639
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624 2251799813685248   2251799813685248
+--R     3535325707485839 7910495238526689 3955247619774833      1022977
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248 2251799813685248 1125899906842624 2251799813685248
+--R     7115687411245383 3989780595205673 1994890297804925      404177
+--R    [----------------,----------------,----------------,----------------],
+--R     4503599627370496 1125899906842624  562949953421312 1125899906842624
+--R     447545212969943 2012220285202847 8048881139966077        845311
+--R    [---------------,----------------,----------------,- ----------------],
+--R     281474976710656  562949953421312 2251799813685248   2251799813685248
+--R     7205759403792793 8118458789433907 2029614697369437       43841
+--R    [----------------,----------------,----------------,----------------],
+--R     4503599627370496 2251799813685248  562949953421312 2251799813685248
+--R     3625397700033249 4094148921370699 4094148921507875      17147
+--R    [----------------,----------------,----------------,---------------],
+--R     2251799813685248 1125899906842624 1125899906842624 140737488355328
+--R     7295831396340203 4129201002472277 8258402004110987        833567
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624 2251799813685248   2251799813685248
+--R     1835216848153477 2082193744500567 8328774977247389        754879
+--R    [----------------,----------------,----------------,- ----------------],
+--R     1125899906842624  562949953421312 2251799813685248   2251799813685248
+--R     7385903388887613 4199710234188517 8399420468531093      154059
+--R    [----------------,----------------,----------------,----------------],
+--R     4503599627370496 1125899906842624 2251799813685248 2251799813685248
+--R     3715469692580659 132349096672421 2117585546586549        172187
+--R    [----------------,---------------,----------------,- ---------------],
+--R     2251799813685248  35184372088832  562949953421312   562949953421312
+--R     7475975381435023 8541543842690293 8541543841997621        10823
+--R    [----------------,----------------,----------------,- --------------],
+--R     4503599627370496 2251799813685248 2251799813685248   35184372088832
+--R     940126422213591 2153257287703193 8613029150341669        471103
+--R    [---------------,----------------,----------------,- ----------------],
+--R     562949953421312  562949953421312 2251799813685248   2251799813685248
+--R     7566047373982433 4342400915687837 8684801830404751        970923
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624 2251799813685248   2251799813685248
+--R     3805541685128069 4378432803302045 4378432802995389        9583
+--R    [----------------,----------------,----------------,- --------------],
+--R     2251799813685248 1125899906842624 1125899906842624   35184372088832
+--R     7656119366529843 8829224205478513 8829224206277685      199793
+--R    [----------------,----------------,----------------,---------------],
+--R     4503599627370496 2251799813685248 2251799813685248 562949953421312
+--R     1925288840700887 8901881365986633 8901881366403569      52117
+--R    [----------------,----------------,----------------,---------------],
+--R     1125899906842624 2251799813685248 2251799813685248 281474976710656
+--R     7746191359077253 2243710207091985 8974840828042839        325101
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496  562949953421312 2251799813685248   2251799813685248
+--R     3895613677675479 2262026584904331 1131013292496601      88871
+--R    [----------------,----------------,----------------,---------------],
+--R     2251799813685248  562949953421312  281474976710656 562949953421312
+--R     7836263351624663 4560840828994337 570105103664447      321239
+--R    [----------------,----------------,---------------,----------------],
+--R     4503599627370496 1125899906842624 140737488355328 1125899906842624
+--R     7 574723159280705 1149446318583071      21661
+--R    [-,---------------,----------------,---------------],
+--R     4 140737488355328  281474976710656 281474976710656
+--R     990791918021509 2317444195722457 4634888391734551      289637
+--R    [---------------,----------------,----------------,----------------],
+--R     562949953421312  562949953421312 1125899906842624 1125899906842624
+--R     7971371340445777 292009504576869 4672152072861169        368735
+--R    [----------------,---------------,----------------,- ----------------],
+--R     4503599627370496  70368744177664 1125899906842624   1125899906842624
+--R     4008203668359741 4709578214490151 4709578213954005        268073
+--R    [----------------,----------------,----------------,- ---------------],
+--R     2251799813685248 1125899906842624 1125899906842624   562949953421312
+--R     8061443332993187 4747168716870599 1186792179104145        454019
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624  281474976710656   1125899906842624
+--R     2026619832316723 2392462743259895 2392462743534577      137341
+--R    [----------------,----------------,----------------,---------------],
+--R     1125899906842624  562949953421312  562949953421312 281474976710656
+--R     8151515325540597 4822850438593465 1205712609600109        193029
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624  281474976710656   1125899906842624
+--R     4098275660907151 2430472744686633 607618186102009        278597
+--R    [----------------,----------------,---------------,- ---------------],
+--R     2251799813685248  562949953421312 140737488355328   562949953421312
+--R     8241587318088007 2449606281511067 4899212562884063        138071
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496  562949953421312 1125899906842624   1125899906842624
+--R     517913957147607 4937653591584309 4937653591577239         3535
+--R    [---------------,----------------,----------------,- ---------------],
+--R     281474976710656 1125899906842624 1125899906842624   562949953421312
+--R     8331659310635417 4976270512733531 1244067628128235        220591
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624  281474976710656   1125899906842624
+--R     4188347653454561 2507532634886519 5015065270189997      416959
+--R    [----------------,----------------,----------------,----------------],
+--R     2251799813685248  562949953421312 1125899906842624 1125899906842624
+--R     8421731303182827 2527019908069585 1263509954055799      42013
+--R    [----------------,----------------,----------------,---------------],
+--R     4503599627370496  562949953421312  281474976710656 562949953421312
+--R     2116691824864133 636649513721483 5093196109575271        196593
+--R    [----------------,---------------,----------------,- ----------------],
+--R     1125899906842624 140737488355328 1125899906842624   1125899906842624
+--R     8511803295730237 5132536116492357 5132536116786609      73563
+--R    [----------------,----------------,----------------,---------------],
+--R     4503599627370496 1125899906842624 1125899906842624 281474976710656
+--R     4278419646001971 2586030906127493 5172061812202729         52257
+--R    [----------------,----------------,----------------,- ----------------],
+--R     2251799813685248  562949953421312 1125899906842624   1125899906842624
+--R     8601875288277647 1302943794660897 5211775178199679        443909
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496  281474976710656 1125899906842624   1125899906842624
+--R     1080863910568919 164114943910103 5251678205407441      284145
+--R    [----------------,---------------,----------------,----------------],
+--R      562949953421312  35184372088832 1125899906842624 1125899906842624
+--R     8691947280825057 5291772892418247 5291772892931415      32073
+--R    [----------------,----------------,----------------,--------------],
+--R     4503599627370496 1125899906842624 1125899906842624 70368744177664
+--R     4368491638549381 2666030624566937 666507656071519        280861
+--R    [----------------,----------------,---------------,- ---------------],
+--R     2251799813685248  562949953421312 140737488355328   562949953421312
+--R     8782019273372467 5372545289505109 2686272644521677        461755
+--R    [----------------,----------------,----------------,- ----------------],
+--R     4503599627370496 1125899906842624  562949953421312   1125899906842624
+--R     2206763817411543 2706613520075893 5413227040188281       36495
+--R    [----------------,----------------,----------------,----------------],
+--R     1125899906842624  562949953421312 1125899906842624 1125899906842624
+--R     8872091265919877 681763567087617 2727054268597319      246851
+--R    [----------------,---------------,----------------,---------------],
+--R     4503599627370496 140737488355328  562949953421312 562949953421312
+--R     4458563631096791 5495191824912689 5495191824808017        3271
+--R    [----------------,----------------,----------------,- --------------],
+--R     2251799813685248 1125899906842624 1125899906842624   35184372088832
+--R     8962163258467287 5536478957302577 5536478957544019      120721
+--R    [----------------,----------------,----------------,---------------],
+--R     4503599627370496 1125899906842624 1125899906842624 562949953421312
+--R       5577971999896927 5577971999899057       1065
+--R    [2,----------------,----------------,---------------]]
+--R       1125899906842624 1125899906842624 562949953421312
+--R                                             Type: List List Fraction Integer
 --E 16
 
 \end{chunk}
-In the following table we show values returned by
-$xe^{-x}Ei(x)$, chosen to keep the values in a reasonable range.
-Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
-Dover Publications, Inc. New York 1965. pp 242-243
 
+The actual table values from above are:
+\begin{verbatim}
+
+  [0.5,                 0.45421990499999998,
+                        0.45421990486317332,
+                       -1.3682666111236585E-10]
+  [0.51000000000000001, 0.48703216700000002, 
+                        0.48703216680456007,
+                       -1.9543994200788006E-10]
+  [0.52000000000000002, 0.51953063300000002, 
+                        0.51953063245569719,
+                       -5.443028250340376E-10]
+  [0.53000000000000003, 0.55173044500000001, 
+                        0.55173044523266401,
+                        2.3266399917787339E-10]
+  [0.54000000000000004, 0.58364593099999995, 
+                        0.58364593072977955,
+                       -2.7022040161028826E-10]
+  [0.55000000000000004, 0.61529065699999996, 
+                        0.61529065706218644,
+                        6.2186478189119043E-11]
+  [0.56000000000000005, 0.64667748999999997, 
+                        0.64667748977430584,
+                       -2.2569413005157912E-10]
+  [0.56999999999999995, 0.67781864199999997, 
+                        0.67781864189137597,
+                       -1.0862399868472039E-10]
+  [0.57999999999999996, 0.70872572, 
+                        0.70872571962101083,
+                       -3.7898917337741977E-10]
+  [0.58999999999999997, 0.73940976400000002, 
+                        0.73940976415103654,
+                        1.510365166268457E-10]
+  [0.59999999999999998, 0.76988129000000005, 
+                        0.76988128993735938,
+                       -6.2640670428493195E-11]
+  [0.60999999999999999, 0.80015031999999997, 
+                        0.80015031983004981,
+                       -1.699501650520574E-10]
+  [0.62,                0.83022641699999999,
+                        0.83022641734618519,
+                        3.4618519162421535E-10]
+  [0.63,                0.86011871600000001,
+                        0.86011871636343917,
+                        3.6343916764991491E-10]
+  [0.64000000000000001, 0.88983594899999996, 
+                        0.88983594847818637,
+                       -5.2181359233571811E-10]
+  [0.65000000000000002, 0.91938646800000001, 
+                        0.91938646824544334,
+                        2.4544333232512372E-10]
+  [0.66000000000000003, 0.94877827699999995, 
+                        0.94877827649472835,
+                       -5.0527160233571067E-10]
+  [0.67000000000000004, 0.97801904200000001, 
+                        0.97801904189549682,
+                       -1.045031838842192E-10]
+  [0.68000000000000005, 1.0071161209999999, 
+                        1.0071161209277915,
+                       -7.2208461432410331E-11]
+  [0.68999999999999995, 1.0360765759999999, 
+                        1.0360765763978435,
+                        3.978435358931165E-10]
+  [0.69999999999999996, 1.064907195,
+                        1.0649071946242905,
+                       -3.757094635403746E-10]
+  [0.70999999999999996, 1.093614501,
+                        1.0936145014081782,
+                        4.0817815794014223E-10]
+  [0.71999999999999997, 1.1222047770000001, 
+                        1.1222047768888612,
+                       -1.111388758801013E-10]
+  [0.72999999999999998, 1.150684069,
+                        1.1506840693780345,
+                        3.780344925985446E-10]
+  [0.73999999999999999, 1.1790582080000001, 
+                        1.1790582082553465,
+                        2.5534641068247765E-10]
+  [0.75,                1.2073328160000001,
+                        1.2073328160012218,
+                        1.2216894162975223E-12]
+  [0.76000000000000001, 1.2355133190000001, 
+                        1.2355133194354742,
+                        4.3547410122357633E-10]
+  [0.77000000000000002, 1.2636049600000001, 
+                        1.2636049602240513,
+                        2.2405122201973882E-10]
+  [0.78000000000000003, 1.291612805, 
+                        1.2916128047105979,
+                       -2.8940205787364448E-10]
+  [0.79000000000000004, 1.319541753,
+                        1.3195417531244753,
+                        1.2447531894110853E-10]
+  [0.80000000000000004, 1.3473965480000001, 
+                        1.3473965482123258,
+                        2.1232571256746269E-10]
+  [0.81000000000000005, 1.3751817829999999, 
+                        1.3751817833361941,
+                        3.361941836033111E-10]
+  [0.81999999999999995, 1.40290191,
+                        1.4029019100774811,
+                        7.7481132620960125E-11]
+  [0.82999999999999996, 1.430561245,
+                        1.4305612453827297,
+                        3.8272962576968439E-10]
+  [0.83999999999999997, 1.458163978,
+                        1.4581639782841678,
+                        2.8416780040174672E-10]
+  [0.84999999999999998, 1.4857141760000001, 
+                        1.4857141762252541,
+                        2.2525403764461771E-10]
+  [0.85999999999999999, 1.5132157909999999, 
+                        1.5132157910189581,
+                        1.8958168368499173E-11]
+  [0.87,                1.5406726639999999,
+                        1.5406726644642923,
+                        4.6429238231837644E-10]
+  [0.88,                1.5680885339999999,
+                        1.5680885336445423,
+                       -3.5545766330358219E-10]
+  [0.89000000000000001, 1.5954670360000001, 
+                        1.5954670359288246,
+                       -7.1175509930299086E-11]
+  [0.90000000000000002, 1.622811714, 
+                        1.6228117136968674,
+                       -3.0313263010839364E-10]
+  [0.91000000000000003, 1.650126019, 
+                        1.6501260188054063,
+                       -1.9459367450735954E-10]
+  [0.92000000000000004, 1.6774133170000001, 
+                        1.677413316813162,
+                       -1.8683810054653804E-10]
+  [0.93000000000000005, 1.7046768910000001, 
+                        1.7046768909800791,
+                       -1.9920953775454109E-11]
+  [0.93999999999999995, 1.7319199460000001, 
+                        1.7319199460553549,
+                        5.5354831829390605E-11]
+  [0.94999999999999996, 1.759145612, 
+                        1.7591456118676905,
+                       -1.3230949669207348E-10]
+  [0.95999999999999996, 1.786356947, 
+                        1.7863569467301943,
+                       -2.6980573331059077E-10]
+  [0.96999999999999997, 1.8135569410000001, 
+                        1.8135569406715355,
+                       -3.2846458886126584E-10]
+  [0.97999999999999998, 1.8407485189999999, 
+                        1.8407485185040211,
+                       -4.9597881357499318E-10]
+  [0.98999999999999999, 1.8679345430000001, 
+                        1.8679345427385856,
+                       -2.6141444564586891E-10]
+  [1.,                  1.895117816,
+                        1.8951178163559361,
+                        3.5593616942719564E-10]
+  [1.01,                1.922301085,
+                        1.9223010854424856,
+                        4.4248560371329404E-10]
+  [1.02,                1.9494870419999999,
+                        1.9494870416990668,
+                       -3.0093305625200628E-10]
+  [1.03,                1.976678325,
+                        1.976678324829928,
+                       -1.7007195651785878E-10]
+  [1.04,                2.003877525,
+                        2.0038775248189595,
+                       -1.8104051591194548E-10]
+  [1.05,                2.031087184,
+                        2.0310871840996643,
+                        9.9664276831390453E-11]
+  [1.0600000000000001,  2.0583098,
+                        2.0583097996249284,
+                       -3.7507152939042498E-10]
+  [1.0700000000000001,  2.0855478249999999, 
+                        2.085547824842283,
+                       -1.5771695061062019E-10]
+  [1.0800000000000001,  2.1128036720000001, 
+                        2.1128036715799325,
+                       -4.2006753631085303E-10]
+  [1.0900000000000001,  2.1400797119999999,
+                        2.1400797118485424,
+                       -1.5145751319778356E-10]
+  [1.1000000000000001,  2.1673782799999999, 
+                        2.1673782795634038,
+                       -4.3659609261226251E-10]
+  [1.1100000000000001,  2.1947016719999999, 
+                        2.1947016721913277,
+                        1.9132784245812218E-10]
+  [1.1200000000000001,  2.2220521519999998, 
+                        2.2220521523263717,
+                        3.2637181845984742E-10]
+  [1.1299999999999999,  2.2494319489999999, 
+                        2.2494319491981756,
+                        1.9817569807401014E-10]
+  [1.1399999999999999,  2.2768432600000001, 
+                        2.2768432601165496,
+                        1.1654943676830953E-10]
+  [1.1499999999999999,  2.3042882520000001, 
+                        2.304288251855628,
+                       -1.4437206985462581E-10]
+  [1.1599999999999999,  2.3317690619999998, 
+                        2.3317690619808027,
+                       -1.9197088363398507E-11]
+  [1.1699999999999999,  2.3592878000000002, 
+                        2.3592878001213737,
+                        1.2137357785491076E-10]
+  [1.1799999999999999,  2.3868465489999999, 
+                        2.3868465491917359,
+                        1.9173596044197438E-10]
+  [1.1899999999999999,  2.4144473670000002, 
+                        2.4144473665637345,
+                       -4.3626569024013406E-10]
+  [1.2,                 2.4420922850000002,
+                        2.4420922851926514,
+                        1.9265122830347536E-10]
+  [1.21,                2.4697833149999999,
+                        2.4697833146991774,
+                       -3.0082247803875362E-10]
+  [1.22,                2.4975224420000002,
+                        2.497522442409561,
+                        4.095608296950104E-10]
+  [1.23,                2.5253116339999999,
+                        2.5253116343560089,
+                        3.5600900005761105E-10]
+  [1.24,                2.5531528360000002,
+                        2.5531528362393039,
+                        2.3930368797664414E-10]
+  [1.25,                2.5810479740000001,
+                        2.5810479743554762,
+                        3.5547609300579097E-10]
+  [1.26,                2.6089989560000002,
+                        2.6089989564882825,
+                        4.8828230347908175E-10]
+  [1.27,                2.6370076729999998,
+                        2.6370076727691485,
+                       -2.308513380455679E-10]
+  [1.28,                2.6650759970000002,
+                        2.6650759965061086,
+                       -4.9389159428869789E-10]
+  [1.29,                2.693205785,
+                        2.6932057849832494,
+                       -1.6750600906334512E-11]
+  [1.3,                 2.7213988800000002,
+                        2.7213988802320226,
+                        2.3202240129194251E-10]
+  [1.3100000000000001,  2.7496571099999998, 
+                        2.7496571097757787,
+                       -2.2422108614250646E-10]
+  [1.3200000000000001,  2.7779822869999999, 
+                        2.777982287348725,
+                        3.4872504883765032E-10]
+  [1.3300000000000001,  2.8063762140000001, 
+                        2.8063762135905539,
+                       -4.0944625467886908E-10]
+  [1.3400000000000001,  2.8348406769999999, 
+                        2.8348406767178056,
+                       -2.8219426795317304E-10]
+  [1.3500000000000001,  2.863377453,
+                        2.8633774531730753,
+                        1.7307533184407475E-10]
+  [1.3600000000000001,  2.8919883080000002, 
+                        2.8919883082530298,
+                        2.5302959727468988E-10]
+  [1.3700000000000001,  2.9206749969999999, 
+                        2.9206749967162473,
+                       -2.8375257699053691E-10]
+  [1.3799999999999999,  2.9494392629999999, 
+                        2.9494392633717355,
+                        3.7173553124603131E-10]
+  [1.3899999999999999,  2.9782828440000002, 
+                        2.9782828436490232,
+                       -3.5097702522079999E-10]
+  [1.3999999999999999,  3.0072074639999999, 
+                        3.0072074641506457,
+                        1.5064571812217764E-10]
+  [1.4099999999999999,  3.0362148430000002, 
+                        3.0362148431877847,
+                        1.8778445465272853E-10]
+  [1.4199999999999999,  3.065306691,
+                        3.065306691299837,
+                        2.9983704408209633E-10]
+  [1.4299999999999999,  3.0944847119999999, 
+                        3.0944847117585681,
+                       -2.4143176347024564E-10]
+  [1.4399999999999999,  3.1237506009999998,
+                        3.1237506010575933,
+                        5.7593485536244771E-11]
+  [1.45,                3.1531060489999998,
+                        3.1531060493877443,
+                        3.8774450317191622E-10]
+  [1.46,                3.1825527409999999,
+                        3.1825527410990038,
+                        9.9003916176343409E-11]
+  [1.47,                3.2120923549999998,
+                        3.2120923551495331,
+                        1.4953327465150323E-10]
+  [1.48,                3.2417265660000001,
+                        3.2417265655423857,
+                       -4.5761439082525612E-10]
+  [1.49,                3.2714570420000002,
+                        3.2714570417503985,
+                       -2.4960167266385724E-10]
+  [1.5,                 3.3012854489999999,
+                        3.3012854491297974,
+                        1.297975060765566E-10]
+  [1.51,                3.3312134489999998,
+                        3.3312134493229739,
+                        3.2297409191528459E-10]
+  [1.52,                3.3612427010000001,
+                        3.3612427006508958,
+                       -3.4910430102286227E-10]
+  [1.53,                3.3913748579999998,
+                        3.3913748584955847,
+                        4.9558490644585618E-10]
+  [1.54,                3.4216115760000001,
+                        3.4216115756731122,
+                       -3.2688785012169319E-10]
+  [1.55,                3.4519545030000001,
+                        3.4519545027974381,
+                       -2.0256196719969921E-10]
+  [1.5600000000000001,  3.4824052889999999, 
+                        3.4824052886355643,
+                       -3.6443559281451599E-10]
+  [1.5700000000000001,  3.5129655799999999, 
+                        3.5129655804542947,
+                        4.5429482398162691E-10]
+  [1.5800000000000001,  3.5436370240000001, 
+                        3.5436370243589819,
+                        3.5898173322834737E-10]
+  [1.5900000000000001,  3.5744212659999999, 
+                        3.5744212656246064,
+                       -3.7539349406756628E-10]
+  [1.6000000000000001,  3.6053199490000001, 
+                        3.6053199490194707,
+                        1.9470647316666145E-11]
+  [1.6100000000000001,  3.6363347190000002, 
+                        3.6363347191218383,
+                        1.2183809516841393E-10]
+  [1.6200000000000001,  3.6674672209999999, 
+                        3.6674672206298222,
+                       -3.7017766629787729E-10]
+  [1.6299999999999999,  3.6987190989999998, 
+                        3.6987190986647667,
+                       -3.3523317455319557E-10]
+  [1.6399999999999999,  3.7300919989999999, 
+                        3.7300919990684158,
+                        6.8415939580290797E-11]
+  [1.6499999999999999,  3.761587569,
+                        3.7615875686941349,
+                       -3.0586511101660108E-10]
+  [1.6599999999999999,  3.7932074560000002, 
+                        3.7932074556923925,
+                       -3.0760771707605272E-10]
+  [1.6699999999999999,  3.8249533100000002, 
+                        3.824953309790788,
+                       -2.092122031172039E-10]
+  [1.6799999999999999,  3.8568267829999998, 
+                        3.8568267825688243,
+                       -4.3117553971683265E-10]
+  [1.6899999999999999,  3.888829528,
+                        3.8888295277276339,
+                       -2.723661296499813E-10]
+  [1.7,                 3.9209632010000002,
+                        3.9209632013549038,
+                        3.5490366201429424E-10]
+  [1.71,                3.9532294619999999,
+                        3.953229462185158,
+                        1.8515811106567526E-10]
+  [1.72,                3.9856299719999999,
+                        3.985629971855627,
+                       -1.4437295803304551E-10]
+  [1.73,                4.0181663949999997,
+                        4.0181663951578672,
+                        1.5786749685275936E-10]
+  [1.74,                4.0508404000000002,
+                        4.0508404002853169,
+                        2.8531665918762883E-10]
+  [1.75,                4.0836536590000003,
+                        4.0836536590769557,
+                        7.6955330996497651E-11]
+  [1.76,                4.116607847,
+                        4.1166078472572494,
+                        2.5724933294668517E-10]
+  [1.77,                4.1497046449999999,
+                        4.1497046446724992,
+                       -3.2750069323128628E-10]
+  [1.78,                4.1829457359999997,
+                        4.1829457355238073,
+                       -4.7619241883012364E-10]
+  [1.79,                4.2163328089999998,
+                        4.2163328085967509,
+                       -4.0324898975541146E-10]
+  [1.8,                 4.249867557,
+                        4.2498675574879341,
+                        4.879341375385593E-10]
+  [1.8100000000000001,  4.2835516809999996, 
+                        4.2835516808285554,
+                       -1.7144419217629547E-10]
+  [1.8200000000000001,  4.3173868830000002, 
+                        4.3173868825051116,
+                       -4.9488857456481128E-10]
+  [1.8300000000000001,  4.3513748720000001, 
+                        4.3513748718773684,
+                       -1.2263168258641599E-10]
+  [1.8400000000000001,  4.385517364,
+                        4.3855173639937215,
+                       -6.2785332488601853E-12]
+  [1.8500000000000001,  4.4198160800000004, 
+                        4.4198160798040753,
+                       -1.9592505395849003E-10]
+  [1.8600000000000001,  4.454272746,
+                        4.4542727463703349,
+                        3.7033487387816422E-10]
+  [1.8700000000000001,  4.4888890970000004, 
+                        4.4888890970746314,
+                        7.4630968072142423E-11]
+  [1.8799999999999999,  4.5236668719999997, 
+                        4.523666871825391,
+                       -1.7460877188568702E-10]
+  [1.8899999999999999,  4.5586078170000004, 
+                        4.5586078172613478,
+                        2.6134738817518155E-10]
+  [1.8999999999999999,  4.5937136870000002, 
+                        4.5937136869535857,
+                       -4.6414427856689144E-11]
+  [1.9099999999999999,  4.6289862419999999, 
+                        4.6289862416057304,
+                       -3.9426950593224319E-10]
+  [1.9199999999999999,  4.6644272490000001, 
+                        4.6644272492523706,
+                        2.5237056888727238E-10]
+  [1.9299999999999999,  4.7000384850000003, 
+                        4.7000384854557851,
+                        4.5578474328067387E-10]
+  [1.9399999999999999,  4.7358217339999999, 
+                        4.7358217335010897,
+                       -4.9891024644921345E-10]
+  [1.95,                4.7717787850000004,
+                        4.7717787845898787,
+                       -4.1012171436705103E-10]
+  [1.96,                4.8079114379999996,
+                        4.8079114380324146,
+                        3.241495960537577E-11]
+  [1.97,                4.8442215009999998,
+                        4.8442215014384944,
+                        4.3849457398437153E-10]
+  [1.98,                4.8807107910000003,
+                        4.8807107909070337,
+                       -9.2966523368431808E-11]
+  [1.99,                4.917381131,
+                        4.9173811312144435,
+                        2.1444357400923764E-10]
+  [2.,                  4.9542343559999997,
+                        4.9542343560018924,
+                        1.8927082123809669E-12]
+
+\end{verbatim}
 \begin{chunk}{*}
+
 --S 17 of 20
 f(x)==x/10.0*exp(-x/10.0)*Ei(x/10.0)
 --R 
 --R                                                                   Type: Void
 --E 17
 
+\end{chunk}
+
+In the following table we show values returned by
+$xe^{-x}Ei(x)$, chosen to keep the values in a reasonable range.
+Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. pp 242-243
+
+\begin{chunk}{*}
+
 --S 18 of 20
+t9:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[2.0,1.340965420,f(2.0),f(2.0)-1.340965420],_
  [2.1,1.371486802,f(2.1),f(2.1)-1.371486802],_
  [2.2,1.397421992,f(2.2),f(2.2)-1.397421992],_
@@ -1974,242 +3649,528 @@ f(x)==x/10.0*exp(-x/10.0)*Ei(x/10.0)
  [9.7,1.137209523,f(9.7),f(9.7)-1.137209523],_
  [9.8,1.135241130,f(9.8),f(9.8)-1.135241130],_
  [9.9,1.133328746,f(9.9),f(9.9)-1.133328746],_
- [10.0,1.131470205,f(10.0),f(10.0)-1.131470205]]
+ [10.0,1.131470205,f(10.0),f(10.0)-1.131470205]]]
 --R 
 --R   Compiling function f with type Float -> OnePointCompletion 
 --R      DoubleFloat 
 --R
 --R   (19)
---R   [[2.,1.3409654200000001,- 0.13456013299662745,- 1.4755255529966276],
---R
---R     [2.1000000000000001, 1.3714868019999999, - 0.12968783850914051,
---R      - 1.5011746405091404]
---R     ,
---R
---R     [2.2000000000000002, 1.3974219919999999, - 0.12432857913849607,
---R      - 1.521750571138496]
---R     ,
---R    [2.2999999999999998,1.419171534,- 0.11851397777493734,- 1.5376855117749373],
---R    [2.3999999999999999,1.437118315,- 0.1122732093067646,- 1.5493915243067646],
---R    [2.5,1.451625159,- 0.10563327984220373,- 1.5572584388422037],
---R
---R     [2.6000000000000001, 1.463033397, - 9.8619263183169451E-2,
---R      - 1.5616526601831695]
---R     ,
---R
---R     [2.7000000000000002, 1.471662153, - 9.1254502584207586E-2,
---R      - 1.5629166555842076]
---R     ,
---R
---R     [2.7999999999999998, 1.4778081869999999, - 8.3560784069182492E-2,
---R      - 1.5613689710691825]
---R     ,
---R
---R     [2.8999999999999999, 1.4817461620000001, - 7.5558486253840138E-2,
---R      - 1.5573046482538402]
---R     ,
---R    [3.,1.4837292040000001,- 6.7266710614573164E-2,- 1.5509959146145733],
---R
---R     [3.1000000000000001, 1.4839896910000001, - 5.8703395368669309E-2,
---R      - 1.5426930863686694]
---R     ,
---R
---R     [3.2000000000000002, 1.482740191, - 4.9885415529372513E-2,
---R      - 1.5326256065293724]
---R     ,
---R
---R     [3.2999999999999998, 1.4801744910000001, - 4.0828671227296824E-2,
---R      - 1.5210031622272968]
---R     ,
---R
---R     [3.3999999999999999, 1.4764687059999999, - 3.1548166016793916E-2,
---R      - 1.5080168720167939]
---R     ,
---R    [3.5,1.4717823889999999,- 2.2058076588733416E-2,- 1.4938404655887334],
---R
---R     [3.6000000000000001, 1.4662596590000001, - 1.2371815072632724E-2,
---R      - 1.4786314740726327]
---R     ,
---R
---R     [3.7000000000000002, 1.4600303130000001, - 2.5020849182828334E-3,
---R      - 1.4625323979182829]
---R     ,
---R
---R     [3.7999999999999998, 1.4532109019999999, 7.5390688098497787E-3,
---R      - 1.4456718331901501]
---R     ,
---R    [3.8999999999999999,1.445905765,1.774021402057336E-2,- 1.4281655509794267],
---R    [4.,1.4382080319999999,2.8090490467135878E-2,- 1.4101175415328639],
---R    [4.0999999999999996,1.430200557,3.8579572390008463E-2,- 1.3916209846099916],
---R    [4.2000000000000002,1.421956813,4.9197634492545148E-2,- 1.3727591785074549],
---R
---R     [4.2999999999999998, 1.4135417189999999, 5.9935320871702981E-2,
---R      - 1.3536063981282969]
---R     ,
---R
---R     [4.4000000000000004, 1.4050124239999999, 7.0783716577210318E-2,
---R      - 1.3342287074227897]
---R     ,
---R    [4.5,1.3964190299999999,8.1734321515770605E-2,- 1.3146847084842292],
---R    [4.5999999999999996,1.387805263,9.2779026453518668E-2,- 1.2950262365464813],
---R
---R     [4.7000000000000002, 1.3792090930000001, 0.10391009090110491,
---R      - 1.2752990020988952]
---R     ,
---R
---R     [4.7999999999999998, 1.3706633130000001, 0.11512012269240564,
---R      - 1.2555431903075944]
---R     ,
---R    [4.9000000000000004,1.362196054,0.12640205909068003,- 1.23579399490932],
---R    [5.,1.3538312779999999,0.13774914927563506,- 1.2160821287243648],
---R
---R     [5.0999999999999996, 1.3455892119999999, 0.14915493808180313,
---R      - 1.1964342739181968]
---R     ,
---R    [5.2000000000000002,1.337486755,0.16061325087332862,- 1.1768735041266714],
---R
---R     [5.2999999999999998, 1.3295378449999999, 0.17211817945300276,
---R      - 1.1574196655469973]
---R     ,
---R
---R     [5.4000000000000004, 1.3217537880000001, 0.1836640689145036,
---R      - 1.1380897190854964]
---R     ,
---R    [5.5,1.314143566,0.19524550535650245,- 1.1188980606434975],
---R
---R     [5.5999999999999996, 1.3067141069999999, 0.20685730438580638,
---R      - 1.0998568026141935]
---R     ,
---R
---R     [5.7000000000000002, 1.2994705360000001, 0.21849450034417656,
---R      - 1.0809760356558236]
---R     ,
---R
---R     [5.7999999999999998, 1.2924163950000001, 0.23015233620004197,
---R      - 1.0622640587999581]
---R     ,
---R    [5.9000000000000004,1.285553849,0.24182625405213551,- 1.0437275949478646],
---R    [6.,1.2788838600000001,0.25351188619722104,- 1.0253719738027791],
---R
---R     [6.0999999999999996, 1.2724063569999999, 0.26520504671863687,
---R      - 1.0072013102813631]
---R     ,
---R
---R     [6.2000000000000002, 1.2661203729999999, 0.27690172355643178,
---R      - 0.98921864944356819]
---R     ,
---R
---R     [6.2999999999999998, 1.2600241839999999, 0.28859807102347912,
---R      - 0.97142611297652082]
---R     ,
---R    [6.4000000000000004,1.254115417,0.30029040273517321,- 0.9538250142648268],
---R    [6.5,1.248391155,0.31197518492319382,- 0.93641597007680621],
---R
---R     [6.5999999999999996, 1.2428480319999999, 0.32364903010640295,
---R      - 0.91919900189359693]
---R     ,
---R    [6.7000000000000002,1.237482309,0.33530869109425609,- 0.90217361790574391],
---R
---R     [6.7999999999999998, 1.2322899519999999, 0.34695105530018927,
---R      - 0.88533889669981058]
---R     ,
---R
---R     [6.9000000000000004, 1.2272666839999999, 0.3585731393443225,
---R      - 0.86869354465567739]
---R     ,
---R    [7.,1.2224080530000001,0.37017208392651269,- 0.85223596907348742],
---R
---R     [7.0999999999999996, 1.2177094719999999, 0.38174514895231304,
---R      - 0.83596432304768686]
---R     ,
---R    [7.2000000000000002,1.213166264,0.39328970889579112,- 0.81987655510420887],
---R    [7.2999999999999998,1.208773699,0.40480324838440268,- 0.80397045061559735],
---R
---R     [7.4000000000000004, 1.2045270260000001, 0.4162833579922634,
---R      - 0.78824366800773671]
---R     ,
---R    [7.5,1.2004215,0.42772773022919919,- 0.77269376977080084],
---R
---R     [7.5999999999999996, 1.1964524009999999, 0.43913415571389103,
---R      - 0.75731824528610892]
---R     ,
---R
---R     [7.7000000000000002, 1.1926150630000001, 0.45050051952030151,
---R      - 0.74211454347969852]
---R     ,
---R    [7.7999999999999998,1.188904881,0.46182479768734747,- 0.7270800833126525],
---R
---R     [7.9000000000000004, 1.1853173340000001, 0.47310505388250573,
---R      - 0.71221228011749438]
---R     ,
---R    [8.,1.181847987,0.48433943621069148,- 0.69750855078930862],
---R    [8.0999999999999996,1.178492509,0.49552617416036354,- 0.68296633483963642],
---R    [8.1999999999999993,1.175246676,0.50666357567934228,- 0.66858310032065771],
---R
---R     [8.3000000000000007, 1.1721063759999999, 0.51775002437336082,
---R      - 0.65435635162663908]
---R     ,
---R
---R     [8.4000000000000004, 1.1690676170000001, 0.52878397682080924,
---R      - 0.64028364017919082]
---R     ,
---R    [8.5,1.166126526,0.53976395999758919,- 0.6263625660024108],
---R
---R     [8.5999999999999996, 1.1632793539999999, 0.5506885688063663,
---R      - 0.61259078519363364]
---R     ,
---R
---R     [8.6999999999999993, 1.1605224759999999, 0.56155646370489876,
---R      - 0.59896601229510116]
---R     ,
---R    [8.8000000000000007,1.15785239,0.57236636842843447,- 0.58548602157156548],
---R    [8.9000000000000004,1.155265719,0.58311706780150541,- 0.57214865119849456],
---R    [9.,1.1527592090000001,0.59380740563471446,- 0.5589518033652856],
---R
---R     [9.0999999999999996, 1.1503297240000001, 0.60443628270239691,
---R      - 0.5458934412976032]
---R     ,
---R
---R     [9.1999999999999993, 1.1479742509999999, 0.61500265479727367,
---R      - 0.53297159620272627]
---R     ,
---R    [9.3000000000000007,1.145689889,0.62550553085845151,- 0.52018435814154851],
---R
---R     [9.4000000000000004, 1.1434738550000001, 0.63594397116933887,
---R      - 0.50752988383066122]
---R     ,
---R    [9.5,1.1413234759999999,0.6463170856222451,- 0.49500639037775485],
---R
---R     [9.5999999999999996, 1.1392361849999999, 0.65662403204660502,
---R      - 0.48261215295339488]
---R     ,
---R
---R     [9.6999999999999993, 1.1372095230000001, 0.66686401459797295,
---R      - 0.47034550840202716]
---R     ,
---R    [9.8000000000000007,1.13524113,0.6770362822050533,- 0.45820484779494675],
---R
---R     [9.9000000000000004, 1.1333287460000001, 0.68714012707221583,
---R      - 0.44618861892778428]
---R     ,
---R    [10.,1.1314702050000001,0.69717488323506582,- 0.43429532176493424]]
---R                               Type: List List OnePointCompletion DoubleFloat
+--R       377448210364295    75750620602817   830647041331407
+--R   [[2,---------------,- ---------------,- ---------------],
+--R       281474976710656   562949953421312   562949953421312
+--R     1182194902184755 6176627450430753    2336248404737001   6760689551615003
+--R    [----------------,----------------,- -----------------,- ----------------],
+--R      562949953421312 4503599627370496   18014398509481984   4503599627370496
+--R     4953959590107545 786678645306317    4479409141437075   3426677652565085
+--R    [----------------,---------------,- -----------------,- ----------------],
+--R     2251799813685248 562949953421312   36028797018963968   2251799813685248
+--R     2589569785738035 6391380391697215    8539832098326451   3462559948921309
+--R    [----------------,----------------,- -----------------,- ----------------],
+--R     1125899906842624 4503599627370496   72057594037927936   2251799813685248
+--R     5404319552844595 6472205507921315    8090137337562157   3488919545759475
+--R    [----------------,----------------,- -----------------,- ----------------],
+--R     2251799813685248 4503599627370496   72057594037927936   2251799813685248
+--R     5 6537538525154037    3805839997882177   7013268524889309
+--R    [-,----------------,- -----------------,- ----------------],
+--R     2 4503599627370496   36028797018963968   4503599627370496
+--R     1463669878895411 3294458330779895    1776566707693101   7033058338483065
+--R    [----------------,----------------,- -----------------,- ----------------],
+--R      562949953421312 2251799813685248   18014398509481984   4503599627370496
+--R     6079859496950169 6627777123866061    6575579901345881   7038750867700179
+--R    [----------------,----------------,- -----------------,- ----------------],
+--R     2251799813685248 4503599627370496   72057594037927936   4503599627370496
+--R     3152519739159347 1663864100074567    6021189055948115   7031780716295025
+--R    [----------------,----------------,- -----------------,- ----------------],
+--R     1125899906842624 1125899906842624   72057594037927936   4503599627370496
+--R     6530219459687219 3336595731520431    1361140682149893   7013476633578335
+--R    [----------------,----------------,- -----------------,- ----------------],
+--R     2251799813685248 2251799813685248   18014398509481984   4503599627370496
+--R       3341061145126561    4847077325731695   6985064623111353
+--R    [3,----------------,- -----------------,- ----------------],
+--R       2251799813685248   72057594037927936   4503599627370496
+--R     1745144855606067 6683295419409257    8460050864247111    6947672008916979
+--R    [----------------,----------------,- ------------------,- ----------------],
+--R      562949953421312 4503599627370496   144115188075855872   4503599627370496
+--R     7205759403792793 3338834085837429    224663938789305   6902332110464163
+--R    [----------------,----------------,- ----------------,- ----------------],
+--R     2251799813685248 2251799813685248   4503599627370496   4503599627370496
+--R     3715469692580659 6666113286110913    2942015816404593   856248659329525
+--R    [----------------,----------------,- -----------------,- ---------------],
+--R     1125899906842624 4503599627370496   72057594037927936   562949953421312
+--R     7656119366529843 3324711957082899    4546569878958591    3395752111441627
+--R    [----------------,----------------,- ------------------,- ----------------],
+--R     2251799813685248 2251799813685248   144115188075855872   2251799813685248
+--R     7 3314159309335429    3178903856176953    1681914841044097
+--R    [-,----------------,- ------------------,- ----------------],
+--R     2 2251799813685248   144115188075855872   1125899906842624
+--R     2026619832316723 3301723226950395    7131865824128711    1664791038912949
+--R    [----------------,----------------,- ------------------,- ----------------],
+--R      562949953421312 2251799813685248   576460752303423488   1125899906842624
+--R     8331659310635417 1643847993394107    1442353754320421    823332545285257
+--R    [----------------,----------------,- ------------------,- ---------------],
+--R     2251799813685248 1125899906842624   576460752303423488   562949953421312
+--R     4278419646001971 3272340038368971   8691954555586423    6510727129255183
+--R    [----------------,----------------,-------------------,- ----------------],
+--R     1125899906842624 2251799813685248 1152921504606846976   4503599627370496
+--R     8782019273372467 6511780664466851  5113268560161703    1607971460803581
+--R    [----------------,----------------,------------------,- ----------------],
+--R     2251799813685248 4503599627370496 288230376151711744   1125899906842624
+--R       3238556578498227  8096532633628621    6350604834596007
+--R    [4,----------------,------------------,- ----------------],
+--R       2251799813685248 288230376151711744   4503599627370496
+--R     2308094809027379 6441050695570275  2779951165436079   783412968466315
+--R    [----------------,----------------,-----------------,- ---------------],
+--R      562949953421312 4503599627370496 72057594037927936   562949953421312
+--R     1182194902184755 3201962086581869  7090126347780349    3091178862397801
+--R    [----------------,----------------,------------------,- ----------------],
+--R      281474976710656 2251799813685248 144115188075855872   2251799813685248
+--R     4841369599423283 3183012979480525  8637590039812239    3048050635108459
+--R    [----------------,----------------,------------------,- ----------------],
+--R     1125899906842624 2251799813685248 144115188075855872   2251799813685248
+--R     4953959590107545 6327613429177317  5100504313616363   3004415954788147
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 4503599627370496 72057594037927936   2251799813685248
+--R     9 6288912223161069  2944789279374435   5920813563239265
+--R    [-,----------------,-----------------,- ----------------],
+--R     2 4503599627370496 36028797018963968   4503599627370496
+--R     2589569785738035 6250119265309613  3342716711710909   5832279676345749
+--R    [----------------,----------------,-----------------,- ----------------],
+--R      562949953421312 4503599627370496 36028797018963968   4503599627370496
+--R     1322932390540083 6211405557300799  233984723331125   5743436110638549
+--R    [----------------,----------------,----------------,- ----------------],
+--R      281474976710656 4503599627370496 2251799813685248   4503599627370496
+--R     5404319552844595 6172918785677209  4147639533282907   2827231922008423
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 4503599627370496 36028797018963968   2251799813685248
+--R     5516909543528857 766848205149995  4554114129757197   2782760687490155
+--R    [----------------,---------------,-----------------,- ----------------],
+--R     1125899906842624 562949953421312 36028797018963968   2251799813685248
+--R       3048557019561661  2481468069393409   2738373510887485
+--R    [5,----------------,-----------------,- ----------------],
+--R       2251799813685248 18014398509481984   2251799813685248
+--R     2871044762448691 6059995073756959  5373872988525419   2694130475095641
+--R    [----------------,----------------,-----------------,- ----------------],
+--R      562949953421312 4503599627370496 36028797018963968   2251799813685248
+--R     1463669878895411 6023504851430973  2893351107135543   5300167074647087
+--R    [----------------,----------------,-----------------,- ----------------],
+--R      281474976710656 4503599627370496 18014398509481984   4503599627370496
+--R     5967269506265907 1496926535829243  6201210950785843   2606277387234371
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 1125899906842624 36028797018963968   2251799813685248
+--R     6079859496950169 5952649867112341  6617195458597655   2562750217393817
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 4503599627370496 36028797018963968   2251799813685248
+--R     11 2959188237074467  219826896292327   2519534444489813
+--R    [--,----------------,----------------,- ----------------],
+--R      2 2251799813685248 1125899906842624   2251799813685248
+--R     3152519739159347 2942458582682485  7452819831606255   1238328671603547
+--R    [----------------,----------------,-----------------,- ----------------],
+--R      562949953421312 2251799813685248 36028797018963968   1125899906842624
+--R     1604407367250739 2926147510854269  7872094002660287   2434141635688001
+--R    [----------------,----------------,-----------------,- ----------------],
+--R      281474976710656 2251799813685248 36028797018963968   2251799813685248
+--R     6530219459687219 5820525994929519  8292111804391663   4784012019380561
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 4503599627370496 36028797018963968   4503599627370496
+--R     6642809450371481 2894809917660553  8712709021100801   2350265603841753
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 2251799813685248 36028797018963968   2251799813685248
+--R       5759580875346141  285429009052949   4617864839134345
+--R    [6,----------------,----------------,- ----------------],
+--R       4503599627370496 1125899906842624   4503599627370496
+--R     3433994715870003 2865204397624525 2388754699157655   2268015722835111
+--R    [----------------,----------------,----------------,- ----------------],
+--R      562949953421312 2251799813685248 9007199254740992   2251799813685248
+--R     1745144855606067 5702099240048993  623527249513497   4455044741021999
+--R    [----------------,----------------,----------------,- ----------------],
+--R      281474976710656 4503599627370496 2251799813685248   4503599627370496
+--R     7093169413108531 5674644445540213  5198920660484735   4374914280419029
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 4503599627370496 18014398509481984   4503599627370496
+--R     7205759403792793 2824016862340397 2704775491722123   8591291957639465
+--R    [----------------,----------------,----------------,- ----------------],
+--R     1125899906842624 2251799813685248 9007199254740992   9007199254740992
+--R     13 5622253940470623  5620045306275745   4217242613901687
+--R    [--,----------------,-----------------,- ----------------],
+--R      2 4503599627370496 18014398509481984   4503599627370496
+--R     3715469692580659 2798644966896677 1457585651386017   4139704282407337
+--R    [----------------,----------------,----------------,- ----------------],
+--R      562949953421312 2251799813685248 4503599627370496   4503599627370496
+--R     1885882343961395 1393281216422495 3020192192532359   8126057538847601
+--R    [----------------,----------------,----------------,- ----------------],
+--R      281474976710656 1125899906842624 9007199254740992   9007199254740992
+--R     7656119366529843 2774870284319803  6250114573462927   1993605962636937
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 2251799813685248 18014398509481984   2251799813685248
+--R     7768709357214105 43180607662083  6459479426944637   3912247924010465
+--R    [----------------,--------------,-----------------,- ----------------],
+--R     1125899906842624 35184372088832 18014398509481984   4503599627370496
+--R       5505236451985493  833553429617201   3838129592751091
+--R    [7,----------------,----------------,- ----------------],
+--R       4503599627370496 2251799813685248   4503599627370496
+--R     3996944669291315 5484075924344723  6876909242288525   235303038360787
+--R    [----------------,----------------,-----------------,- ---------------],
+--R      562949953421312 4503599627370496 18014398509481984   281474976710656
+--R     2026619832316723 682951891811107 3542438772863471   7384791496114241
+--R    [----------------,---------------,----------------,- ----------------],
+--R      281474976710656 562949953421312 9007199254740992   9007199254740992
+--R     8219069319951155 680479097548957  7292287034329447   1810380510904647
+--R    [----------------,---------------,-----------------,- ----------------],
+--R     1125899906842624 562949953421312 18014398509481984   2251799813685248
+--R     8331659310635417 5424707465451291  7499094303737983   3549933889516795
+--R    [----------------,----------------,-----------------,- ----------------],
+--R     1125899906842624 4503599627370496 18014398509481984   4503599627370496
+--R     15 5406217820087531 1926314446476249   1739951686805641
+--R    [--,----------------,----------------,- ----------------],
+--R      2 4503599627370496 4503599627370496   2251799813685248
+--R     4278419646001971 5388342587310135  7910737680154945   3410658167271399
+--R    [----------------,----------------,-----------------,- ----------------],
+--R      562949953421312 4503599627370496 18014398509481984   4503599627370496
+--R     2167357320672051 671382594165405  8115495887367375    835546695370349
+--R    [----------------,---------------,-----------------,- ----------------],
+--R      281474976710656 562949953421312 18014398509481984   1125899906842624
+--R     8782019273372467 5354351579050563 259984248346899   3274477592275371
+--R    [----------------,----------------,---------------,- ----------------],
+--R     1125899906842624 4503599627370496 562949953421312   4503599627370496
+--R     8894609264056729 5338194703718189 1065337872186175   3207518959345839
+--R    [----------------,----------------,----------------,- ----------------],
+--R     1125899906842624 4503599627370496 2251799813685248   4503599627370496
+--R       2661285076930885  8725083617757223   24541400386113
+--R    [8,----------------,-----------------,- --------------],
+--R       2251799813685248 18014398509481984   35184372088832
+--R     4559894622712627 663432303048915  557912873325235    768951732772595
+--R    [----------------,---------------,----------------,- ----------------],
+--R      562949953421312 562949953421312 1125899906842624   1125899906842624
+--R     2308094809027379 2646420246051007 4563619781263377   6022061202940651
+--R    [----------------,----------------,----------------,- ----------------],
+--R      281474976710656 2251799813685248 9007199254740992   9007199254740992
+--R     4672484613396889 2639348919096091 4663477633677863   5893918042706501
+--R    [----------------,----------------,----------------,- ----------------],
+--R      562949953421312 2251799813685248 9007199254740992   9007199254740992
+--R     1182194902184755 5265012484292113 4762862641939371   5767162326644855
+--R    [----------------,----------------,----------------,- ----------------],
+--R      140737488355328 4503599627370496 9007199254740992   9007199254740992
+--R     17 5251766987960451 2430880769113165   1410443109423643
+--R    [--,----------------,----------------,- ----------------],
+--R      2 4503599627370496 4503599627370496   2251799813685248
+--R     4841369599423283 5238944465202191 2480080833273543   344857953991081
+--R    [----------------,----------------,----------------,- ---------------],
+--R      562949953421312 4503599627370496 4503599627370496   562949953421312
+--R     2448832297382707 5226528590468685 2529025480688875   1348751554889905
+--R    [----------------,----------------,----------------,- ----------------],
+--R      281474976710656 4503599627370496 4503599627370496   2251799813685248
+--R     4953959590107545 2607251796077019 5155417927147399   5273589257160677
+--R    [----------------,----------------,----------------,- ----------------],
+--R      562949953421312 2251799813685248 9007199254740992   9007199254740992
+--R     1252563646362419 1300713565400577 5252251618528469   5153456904676147
+--R    [----------------,----------------,----------------,- ----------------],
+--R      140737488355328 1125899906842624 9007199254740992   9007199254740992
+--R       5191565944100307 2674270810746341   1258647566676983
+--R    [9,----------------,----------------,- ----------------],
+--R       4503599627370496 4503599627370496   2251799813685248
+--R     5122844576133939 5180624516359605 2722139017547721    614621374702971
+--R    [----------------,----------------,----------------,- ----------------],
+--R      562949953421312 4503599627370496 4503599627370496   1125899906842624
+--R     2589569785738035 1292504102258631 2769725726976867   2400290682057657
+--R    [----------------,----------------,----------------,- ----------------],
+--R      281474976710656 1125899906842624 4503599627370496   4503599627370496
+--R     5235434566818201 322483034823909 2817026475692305   2342702081490239
+--R    [----------------,---------------,----------------,- ----------------],
+--R      562949953421312 281474976710656 4503599627370496   4503599627370496
+--R     1322932390540083 321859276705369  716009257896687    571427848924789
+--R    [----------------,---------------,----------------,- ----------------],
+--R      140737488355328 281474976710656 1125899906842624   1125899906842624
+--R     19 5140063981222799 2910753385971527   278663824406409
+--R    [--,----------------,----------------,- ---------------],
+--R      2 4503599627370496 4503599627370496   562949953421312
+--R     5404319552844595 5130663658252985 1478585873023801   2173491912205383
+--R    [----------------,----------------,----------------,- ----------------],
+--R      562949953421312 4503599627370496 2251799813685248   4503599627370496
+--R     2730307274093363 5121536384024979 6006577055300447   4236495712749511
+--R    [----------------,----------------,----------------,- ----------------],
+--R      281474976710656 4503599627370496 9007199254740992   9007199254740992
+--R     5516909543528857 1278167882510915 6098200696509967   4127142363577353
+--R    [----------------,----------------,----------------,- ----------------],
+--R      562949953421312 1125899906842624 9007199254740992   9007199254740992
+--R     1393301134717747 5104058918173871 6189208040467493   4018909795880249
+--R    [----------------,----------------,----------------,- ----------------],
+--R      140737488355328 4503599627370496 9007199254740992   9007199254740992
+--R        2547844396809409 3139796544349511   1955892249269307
+--R    [10,----------------,----------------,- ----------------]]
+--R        2251799813685248 4503599627370496   4503599627370496
+--R                                             Type: List List Fraction Integer
 --E 18
 
 \end{chunk}
-In the following table we show the values returned for large
-arguments to the Ei function. See 
-Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
-Dover Publications, Inc. New York 1965. p 243
 
+The actual table values from above are:
+\begin{verbatim}
+
+ [2.,                  1.3409654200000001,
+                      -0.13456013299662745,
+                      -1.4755255529966276],
+ [2.1000000000000001,  1.3714868019999999, 
+                      -0.12968783850914051,
+                      -1.5011746405091404]
+ [2.2000000000000002,  1.3974219919999999, 
+                      -0.12432857913849607,
+                      -1.521750571138496]
+ [2.2999999999999998,  1.419171534,
+                      -0.11851397777493734,
+                      -1.5376855117749373],
+ [2.3999999999999999,  1.437118315,
+                      -0.1122732093067646,
+                      -1.5493915243067646],
+ [2.5,                 1.451625159,
+                      -0.10563327984220373,
+                      -1.5572584388422037],
+ [2.6000000000000001,  1.463033397, 
+                      -9.8619263183169451E-2,
+                      -1.5616526601831695]
+ [2.7000000000000002,  1.471662153, 
+                      -9.1254502584207586E-2,
+                      -1.5629166555842076]
+ [2.7999999999999998,  1.4778081869999999, 
+                      -8.3560784069182492E-2,
+                      -1.5613689710691825]
+ [2.8999999999999999,  1.4817461620000001, 
+                      -7.5558486253840138E-2,
+                      -1.5573046482538402]
+ [3.,                  1.4837292040000001,
+                      -6.7266710614573164E-2,
+                      -1.5509959146145733],
+ [3.1000000000000001,  1.4839896910000001, 
+                      -5.8703395368669309E-2,
+                      -1.5426930863686694]
+ [3.2000000000000002,  1.482740191, 
+                      -4.9885415529372513E-2,
+                      -1.5326256065293724]
+ [3.2999999999999998,  1.4801744910000001, 
+                      -4.0828671227296824E-2,
+                      -1.5210031622272968]
+ [3.3999999999999999,  1.4764687059999999, 
+                      -3.1548166016793916E-2,
+                      -1.5080168720167939]
+ [3.5,                 1.4717823889999999,
+                      -2.2058076588733416E-2,
+                      -1.4938404655887334],
+ [3.6000000000000001,  1.4662596590000001, 
+                      -1.2371815072632724E-2,
+                      -1.4786314740726327]
+ [3.7000000000000002,  1.4600303130000001, 
+                      -2.5020849182828334E-3,
+                      -1.4625323979182829]
+ [3.7999999999999998,  1.4532109019999999, 
+                       7.5390688098497787E-3,
+                       -1.4456718331901501]
+ [3.8999999999999999,  1.445905765,
+                       1.774021402057336E-2,
+                      -1.4281655509794267],
+ [4.,                  1.4382080319999999,
+                       2.8090490467135878E-2,
+                      -1.4101175415328639],
+ [4.0999999999999996,  1.430200557,
+                       3.8579572390008463E-2,
+                      -1.3916209846099916],
+ [4.2000000000000002,  1.421956813,
+                       4.9197634492545148E-2,
+                      -1.3727591785074549],
+ [4.2999999999999998,  1.4135417189999999, 
+                       5.9935320871702981E-2,
+                      -1.3536063981282969]
+ [4.4000000000000004,  1.4050124239999999, 
+                       7.0783716577210318E-2,
+                      -1.3342287074227897]
+ [4.5,                 1.3964190299999999,
+                       8.1734321515770605E-2,
+                      -1.3146847084842292],
+ [4.5999999999999996,  1.387805263,
+                       9.2779026453518668E-2,
+                      -1.2950262365464813],
+ [4.7000000000000002,  1.3792090930000001, 
+                       0.10391009090110491,
+                      -1.2752990020988952]
+ [4.7999999999999998,  1.3706633130000001, 
+                       0.11512012269240564,
+                      -1.2555431903075944]
+ [4.9000000000000004,  1.362196054,
+                       0.12640205909068003,
+                      -1.23579399490932],
+ [5.,                  1.3538312779999999,
+                       0.13774914927563506,
+                      -1.2160821287243648],
+ [5.0999999999999996,  1.3455892119999999, 
+                       0.14915493808180313,
+                      -1.1964342739181968]
+ [5.2000000000000002,  1.337486755,
+                       0.16061325087332862,
+                      -1.1768735041266714],
+ [5.2999999999999998,  1.3295378449999999, 
+                       0.17211817945300276,
+                      -1.1574196655469973]
+ [5.4000000000000004,  1.3217537880000001, 
+                       0.1836640689145036,
+                      -1.1380897190854964]
+ [5.5,                 1.314143566,
+                       0.19524550535650245,
+                      -1.1188980606434975],
+ [5.5999999999999996,  1.3067141069999999, 
+                       0.20685730438580638,
+                      -1.0998568026141935]
+ [5.7000000000000002,  1.2994705360000001, 
+                       0.21849450034417656,
+                      -1.0809760356558236]
+ [5.7999999999999998,  1.2924163950000001, 
+                       0.23015233620004197,
+                      -1.0622640587999581]
+ [5.9000000000000004,  1.285553849,
+                       0.24182625405213551,
+                      -1.0437275949478646],
+ [6.,                  1.2788838600000001,
+                       0.25351188619722104,
+                      -1.0253719738027791],
+ [6.0999999999999996,  1.2724063569999999, 
+                       0.26520504671863687,
+                      -1.0072013102813631]
+ [6.2000000000000002,  1.2661203729999999, 
+                       0.27690172355643178,
+                      -0.98921864944356819]
+ [6.2999999999999998,  1.2600241839999999, 
+                       0.28859807102347912,
+                      -0.97142611297652082]
+ [6.4000000000000004,  1.254115417,
+                       0.30029040273517321,
+                      -0.9538250142648268],
+ [6.5,                 1.248391155,
+                       0.31197518492319382,
+                      -0.93641597007680621],
+ [6.5999999999999996,  1.2428480319999999, 
+                       0.32364903010640295,
+                      -0.91919900189359693]
+ [6.7000000000000002,  1.237482309,
+                       0.33530869109425609,
+                      -0.90217361790574391],
+ [6.7999999999999998,  1.2322899519999999, 
+                       0.34695105530018927,
+                      -0.88533889669981058]
+ [6.9000000000000004,  1.2272666839999999, 
+                       0.3585731393443225,
+                      -0.86869354465567739]
+ [7.,                  1.2224080530000001,
+                       0.37017208392651269,
+                      -0.85223596907348742],
+ [7.0999999999999996,  1.2177094719999999, 
+                       0.38174514895231304,
+                      -0.83596432304768686]
+ [7.2000000000000002,  1.213166264,
+                       0.39328970889579112,
+                      -0.81987655510420887],
+ [7.2999999999999998,  1.208773699,
+                       0.40480324838440268,
+                      -0.80397045061559735],
+ [7.4000000000000004,  1.2045270260000001, 
+                       0.4162833579922634,
+                      -0.78824366800773671]
+ [7.5,                 1.2004215,
+                       0.42772773022919919,
+                      -0.77269376977080084],
+ [7.5999999999999996,  1.1964524009999999, 
+                       0.43913415571389103,
+                      -0.75731824528610892]
+ [7.7000000000000002,  1.1926150630000001, 
+                       0.45050051952030151,
+                      -0.74211454347969852]
+ [7.7999999999999998,  1.188904881,
+                       0.46182479768734747,
+                      -0.7270800833126525],
+ [7.9000000000000004,  1.1853173340000001, 
+                       0.47310505388250573,
+                      -0.71221228011749438]
+ [8.,                  1.181847987,
+                       0.48433943621069148,
+                      -0.69750855078930862],
+ [8.0999999999999996,  1.178492509,
+                       0.49552617416036354,
+                      -0.68296633483963642],
+ [8.1999999999999993,  1.175246676,
+                       0.50666357567934228,
+                      -0.66858310032065771],
+ [8.3000000000000007,  1.1721063759999999, 
+                       0.51775002437336082,
+                      -0.65435635162663908]
+ [8.4000000000000004,  1.1690676170000001, 
+                       0.52878397682080924,
+                      -0.64028364017919082]
+ [8.5,                 1.166126526,
+                       0.53976395999758919,
+                      -0.6263625660024108],
+ [8.5999999999999996,  1.1632793539999999, 
+                       0.5506885688063663,
+                      -0.61259078519363364]
+ [8.6999999999999993,  1.1605224759999999, 
+                       0.56155646370489876,
+                      -0.59896601229510116]
+ [8.8000000000000007,  1.15785239,
+                       0.57236636842843447,
+                      -0.58548602157156548],
+ [8.9000000000000004,  1.155265719,
+                       0.58311706780150541,
+                      -0.57214865119849456],
+ [9.,                  1.1527592090000001,
+                       0.59380740563471446,
+                      -0.5589518033652856],
+ [9.0999999999999996,  1.1503297240000001, 
+                       0.60443628270239691,
+                      -0.5458934412976032]
+ [9.1999999999999993,  1.1479742509999999, 
+                       0.61500265479727367,
+                      -0.53297159620272627]
+ [9.3000000000000007,  1.145689889,
+                       0.62550553085845151,
+                      -0.52018435814154851],
+ [9.4000000000000004,  1.1434738550000001, 
+                       0.63594397116933887,
+                      -0.50752988383066122]
+ [9.5,                 1.1413234759999999,
+                       0.6463170856222451,
+                      -0.49500639037775485],
+ [9.5999999999999996,  1.1392361849999999, 
+                       0.65662403204660502,
+                      -0.48261215295339488]
+ [9.6999999999999993,  1.1372095230000001, 
+                       0.66686401459797295,
+                      -0.47034550840202716]
+ [9.8000000000000007,  1.13524113,
+                       0.6770362822050533,
+                      -0.45820484779494675],
+ [9.9000000000000004,  1.1333287460000001, 
+                       0.68714012707221583,
+                      -0.44618861892778428]
+ [10.,                 1.1314702050000001,
+                       0.69717488323506582,
+                      -0.43429532176493424]]
+
+\end{verbatim}
 \begin{chunk}{*}
+
 --S 19 of 20
 g(y)==(y=0 => 1 ; (x:DFLOAT:=y^-1) ; x*exp(-x)*Ei(x))
 --R 
 --R                                                                   Type: Void
 --E 19
 
+\end{chunk}
+
+In the following table we show the values returned for large
+arguments to the Ei function. See 
+Abramowitz and Stegun, ``Handbook of Mathematical Functions'',
+Dover Publications, Inc. New York 1965. p 243
+
+\begin{chunk}{*}
+
 --S 20 of 20
+t10:List List Fraction Integer:= [[machineFraction (x::DFLOAT) for x in line]_
+ for line in _
 [[0.100,1.13147021,g(0.100),g(0.100)-1.13147021],_
  [0.095,1.12249671,g(0.095),g(0.095)-1.12249671],_
  [0.090,1.11389377,g(0.090),g(0.090)-1.11389377],_
@@ -2230,72 +4191,147 @@ g(y)==(y=0 => 1 ; (x:DFLOAT:=y^-1) ; x*exp(-x)*Ei(x))
  [0.015,1.01547157,g(0.015),g(0.015)-1.01547157],_
  [0.010,1.01020625,g(0.010),g(0.010)-1.01020625],_
  [0.005,1.00505077,g(0.005),g(0.005)-1.00505077],_
- [0.000,1.00000000,g(0.000),g(0.000)-1.00000000]]
+ [0.000,1.00000000,g(0.000),g(0.000)-1.00000000]]]
 --R 
 --R   Compiling function g with type Float -> OnePointCompletion 
 --R      DoubleFloat 
 --R
 --R   (21)
---R   [[0.10000000000000001,1.13147021,1.1314702047341079,- 5.2658921667614322E-9],
---R
---R     [9.5000000000000001E-2, 1.1224967100000001, 1.1224967463528539,
---R      3.6352853838295118E-8]
---R     ,
---R    [8.9999999999999997E-2,1.11389377,1.1138937808537757,1.0853775656016751E-8],
---R
---R     [8.5000000000000006E-2, 1.1056473899999999, 1.1056473901733923,
---R      1.733924115399077E-10]
---R     ,
---R
---R     [8.0000000000000002E-2, 1.0977377500000001, 1.0977377526473173,
---R      2.647317254300674E-9]
---R     ,
---R
---R     [7.4999999999999997E-2, 1.0901408699999999, 1.0901408684282585,
---R      - 1.5717414036942046E-9]
---R     ,
---R    [7.0000000000000007E-2,1.08283054,1.0828305423224371,2.3224371314967129E-9],
---R
---R     [6.5000000000000002E-2, 1.0757803800000001, 1.0757803749062493,
---R      - 5.0937507545256722E-9]
---R     ,
---R
---R     [5.9999999999999998E-2, 1.0689654799999999, 1.0689654755715123,
---R      - 4.4284875766464893E-9]
---R     ,
---R    [5.5E-2,1.06236365,1.0623636462639567,- 3.7360432525446186E-9],
---R
---R     [5.0000000000000003E-2, 1.05595591, 1.0559559055929626,
---R      - 4.4070374016769165E-9]
---R     ,
---R
---R     [4.4999999999999998E-2, 1.0497263999999999, 1.0497264028491122,
---R      2.8491122794349621E-9]
---R     ,
---R
---R     [4.0000000000000001E-2, 1.04366194, 1.0436619362666135,
---R      - 3.7333864888466906E-9]
---R     ,
---R    [3.5000000000000003E-2,1.03775135,1.0377513519241477,1.924147730036907E-9],
---R
---R     [2.9999999999999999E-2, 1.03198503, 1.0319850279857541,
---R      - 2.0142458811989172E-9]
---R     ,
---R    [2.5000000000000001E-2,1.02635451,1.026354511439006,1.4390060254498849E-9],
---R    [2.0E-2,1.0208522799999999,1.0208522777971993,- 2.2028006085861307E-9],
---R
---R     [1.4999999999999999E-2, 1.0154715700000001, 1.0154715653071829,
---R      - 4.6928172459104189E-9]
---R     ,
---R    [1.0E-2,1.01020625,1.0102062527748354,2.7748354725076751E-9],
---R
---R     [5.0000000000000001E-3, 1.00505077, 1.0050507653866605,
---R      - 4.6133394882019729E-9]
---R     ,
---R    [0.,1.,1.,0.]]
---R                               Type: List List OnePointCompletion DoubleFloat
+--R      7205759403792793 318480551008551 5095688792421347       23715469
+--R   [[-----------------,---------------,----------------,- ----------------],
+--R     72057594037927936 281474976710656 4503599627370496   4503599627370496
+--R      6845471433603153 5055275764880607 1263818982149827     163718701
+--R    [-----------------,----------------,----------------,----------------],
+--R     72057594037927936 4503599627370496 1125899906842624 4503599627370496
+--R      3242591731706757 1254132891875579 5016531616383377     48881061
+--R    [-----------------,----------------,----------------,----------------],
+--R     36028797018963968 1125899906842624 4503599627370496 4503599627370496
+--R      3062447746611937 4979393173607161 4979393174388051      390445
+--R    [-----------------,----------------,----------------,----------------],
+--R     36028797018963968 4503599627370496 4503599627370496 2251799813685248
+--R      2882303761517117 2471885660925263 617971416721623      5961229
+--R    [-----------------,----------------,---------------,----------------],
+--R     36028797018963968 2251799813685248 562949953421312 2251799813685248
+--R      5404319552844595 1227389503978337 2454779004417427        3539247
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     72057594037927936 1125899906842624 2251799813685248   2251799813685248
+--R      5044031582654955 304789701028087 304789701681795     163427
+--R    [-----------------,---------------,---------------,--------------],
+--R     72057594037927936 281474976710656 281474976710656 70368744177664
+--R      4683743612465315 2422442059250245 4844884095560277       22940213
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     72057594037927936 2251799813685248 4503599627370496   4503599627370496
+--R      1080863910568919 4814192537399923 1203548129363947       19944135
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     18014398509481984 4503599627370496 1125899906842624   4503599627370496
+--R      990791918021509  598057567283995 4784460521446317       16825643
+--R    [-----------------,---------------,----------------,- ----------------],
+--R     18014398509481984 562949953421312 4503599627370496   4503599627370496
+--R      7205759403792793  4755602642795673 4755602622948141        4961883
+--R    [------------------,----------------,----------------,- ----------------],
+--R     144115188075855872 4503599627370496 4503599627370496   1125899906842624
+--R      3242591731706757 1181886855970243 4727547436712233     12831261
+--R    [-----------------,----------------,----------------,----------------],
+--R     72057594037927936 1125899906842624 4503599627370496 4503599627370496
+--R      2882303761517117 146882360127649 4700235507271091       16813677
+--R    [-----------------,---------------,----------------,- ----------------],
+--R     72057594037927936 140737488355328 4503599627370496   4503599627370496
+--R      5044031582654955  4673616593163229 1168404150457205      8665591
+--R    [------------------,----------------,----------------,----------------],
+--R     144115188075855872 4503599627370496 1125899906842624 4503599627370496
+--R      1080863910568919 2323823698279965 4647647387488573        9071357
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     36028797018963968 2251799813685248 4503599627370496   4503599627370496
+--R      7205759403792793  1155572447196507 4622289795266735      6480707
+--R    [------------------,----------------,----------------,----------------],
+--R     288230376151711744 1125899906842624 4503599627370496 4503599627370496
+--R      2882303761517117  4597509947808321 4597509937887789        2480133
+--R    [------------------,----------------,----------------,- ----------------],
+--R     144115188075855872 4503599627370496 4503599627370496   1125899906842624
+--R      1080863910568919 1143319346064333 4573277363122763       21134569
+--R    [-----------------,----------------,----------------,- ----------------],
+--R     72057594037927936 1125899906842624 4503599627370496   4503599627370496
+--R      2882303761517117  2274782245533673 2274782251782047      3124187
+--R    [------------------,----------------,----------------,----------------],
+--R     288230376151711744 2251799813685248 2251799813685248 1125899906842624
+--R      2882303761517117  2263173136630215 1131586563120949       10388317
+--R    [------------------,----------------,----------------,- ----------------],
+--R     576460752303423488 2251799813685248 1125899906842624   2251799813685248
+--R    [0,1,1,0]]
+--R                                             Type: List List Fraction Integer
 --E 20
 
+\end{chunk}
+
+The actual table values from above are:
+\begin{verbatim}
+ [0.10000000000000001,   1.13147021,
+                         1.1314702047341079,
+                        -5.2658921667614322E-9],
+ [9.5000000000000001E-2, 1.1224967100000001, 
+                         1.1224967463528539,
+                         3.6352853838295118E-8]
+ [8.9999999999999997E-2, 1.11389377,
+                         1.1138937808537757,
+                         1.0853775656016751E-8],
+ [8.5000000000000006E-2, 1.1056473899999999, 
+                         1.1056473901733923,
+                         1.733924115399077E-10]
+ [8.0000000000000002E-2, 1.0977377500000001, 
+                         1.0977377526473173,
+                         2.647317254300674E-9]
+ [7.4999999999999997E-2, 1.0901408699999999, 
+                         1.0901408684282585,
+                        -1.5717414036942046E-9]
+ [7.0000000000000007E-2, 1.08283054,
+                         1.0828305423224371,
+                         2.3224371314967129E-9],
+ [6.5000000000000002E-2, 1.0757803800000001, 
+                         1.0757803749062493,
+                        -5.0937507545256722E-9]
+ [5.9999999999999998E-2, 1.0689654799999999, 
+                         1.0689654755715123,
+                        -4.4284875766464893E-9]
+ [5.5E-2,                1.06236365,
+                         1.0623636462639567,
+                        -3.7360432525446186E-9],
+ [5.0000000000000003E-2, 1.05595591, 
+                         1.0559559055929626,
+                        -4.4070374016769165E-9]
+ [4.4999999999999998E-2, 1.0497263999999999, 
+                         1.0497264028491122,
+                         2.8491122794349621E-9]
+ [4.0000000000000001E-2, 1.04366194, 
+                         1.0436619362666135,
+                        -3.7333864888466906E-9]
+ [3.5000000000000003E-2, 1.03775135,
+                         1.0377513519241477,
+                         1.924147730036907E-9],
+ [2.9999999999999999E-2, 1.03198503, 
+                         1.0319850279857541,
+                        -2.0142458811989172E-9]
+ [2.5000000000000001E-2, 1.02635451,
+                         1.026354511439006,
+                         1.4390060254498849E-9],
+ [2.0E-2,                1.0208522799999999,
+                         1.0208522777971993,
+                        -2.2028006085861307E-9],
+ [1.4999999999999999E-2, 1.0154715700000001, 
+                         1.0154715653071829,
+                        -4.6928172459104189E-9]
+ [1.0E-2,                1.01020625,
+                         1.0102062527748354,
+                         2.7748354725076751E-9],
+ [5.0000000000000001E-3, 1.00505077, 
+                         1.0050507653866605,
+                        -4.6133394882019729E-9]
+ [0.,                    1.,
+                         1.,
+                         0.]]
+
+\end{verbatim}
+\begin{chunk}{*}
+
 )spool 
 )lisp (bye)
  
@@ -2310,3 +4346,4 @@ Dover Publications, Inc. New York 1965. pp238-243
 \end{thebibliography}
 \end{document}
 
+ 
